@@ -49,6 +49,11 @@ import org.eclipse.jst.j2ee.project.facet.IJ2EEModuleFacetInstallDataModelProper
 import org.eclipse.jst.j2ee.project.facet.UtilityFacetInstallDataModelProvider;
 import org.eclipse.jst.j2ee.web.project.facet.WebFacetInstallDataModelProvider;
 import org.eclipse.jst.server.core.FacetUtil;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.internal.Workbench;
+import org.eclipse.ui.navigator.CommonViewer;
+import org.eclipse.ui.navigator.INavigatorContentService;
 import org.eclipse.wst.common.componentcore.datamodel.FacetProjectCreationDataModelProvider;
 import org.eclipse.wst.common.componentcore.datamodel.properties.IFacetDataModelProperties;
 import org.eclipse.wst.common.componentcore.datamodel.properties.IFacetProjectCreationDataModelProperties;
@@ -61,6 +66,7 @@ import org.eclipse.wst.common.componentcore.internal.StructureEdit;
 import org.eclipse.wst.common.componentcore.internal.WorkbenchComponent;
 import org.eclipse.wst.common.frameworks.datamodel.DataModelFactory;
 import org.eclipse.wst.common.frameworks.datamodel.IDataModel;
+import org.eclipse.wst.common.frameworks.internal.SimpleValidateEdit;
 import org.eclipse.wst.project.facet.SimpleWebFacetInstallDataModelProvider;
 import org.eclipse.wst.server.core.IRuntime;
 import org.eclipse.wst.server.core.ServerCore;
@@ -72,6 +78,16 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 	private static final String WEB_LIB_PATH = "/WEB-INF/lib";
 	private static final String OLD_DEPLOYABLES_PATH = ".deployables";
 	private IProject project;
+	
+	private static final String[] J2EE_CONTENT_EXTENSION_IDS = new String[] {
+		"org.eclipse.jst.navigator.j2ee.ui.EARDDContent", //$NON-NLS-1$
+		"org.eclipse.jst.navigator.j2ee.ui.WebDDContent", //$NON-NLS-1$
+		"org.eclipse.jst.navigator.j2ee.ui.EJBDDContent", //$NON-NLS-1$
+		"org.eclipse.jst.navigator.j2ee.ui.ConnectorDDContent" //$NON-NLS-1$
+	};
+	
+	private static final String PROJECT_EXPLORER = "org.eclipse.ui.navigator.ProjectExplorer"; //$NON-NLS-1$
+	
 	public J2EEComponentProjectMigrator() {
 		super();
 		// TODO Auto-generated constructor stub
@@ -79,16 +95,50 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 
 	public void migrateProject(IProject aProject) {
 		if (aProject.isAccessible()) {
-			project = aProject;
-			removeComponentBuilders(project);
-			if (multipleComponentsDetected())
-				createNewProjects();
-			String facetid = getFacetFromProject(project);
-			if (facetid.length() == 0)
-				addFacets(project);
-			J2EEComponentClasspathUpdater.getInstance().queueUpdate(project);
+			final List files = new ArrayList();
+			files.add(aProject.getFile(J2EEProjectUtilities.DOT_PROJECT));
+			files.add(aProject.getFile(J2EEProjectUtilities.DOT_CLASSPATH));
+			if(SimpleValidateEdit.validateEdit(files)){
+				project = aProject;
+				removeComponentBuilders(project);
+				if (multipleComponentsDetected())
+					createNewProjects();
+				String facetid = getFacetFromProject(project);
+				if (facetid.length() == 0)
+					addFacets(project);
+				J2EEComponentClasspathUpdater.getInstance().queueUpdate(project);
+			}
+		}
+		ensureJ2EEContentExtensionsEnabled();
+	}
+	
+	/**
+	 * Ensure the J2EE content extension ids are enabled on the project explorer 
+	 * for the projects being migrated.
+	 */
+	private void ensureJ2EEContentExtensionsEnabled() {
+		IViewPart view = null;
+		try {
+			view = Workbench.getInstance().getWorkbenchWindows()[0].getActivePage().findView(PROJECT_EXPLORER);
+		} catch (Exception e) { 
+			//Just bail and return if there is no view
+		}
+		if (view == null)
+			return;
+		
+		INavigatorContentService contentService = (INavigatorContentService) view.getAdapter(INavigatorContentService.class);
+		CommonViewer viewer = (CommonViewer) view.getAdapter(CommonViewer.class);
+		
+		// Set the J2EE content extensions as enabled now that we have set the J2EE facets
+		if (contentService != null)
+			contentService.getActivationService().activateExtensions(J2EE_CONTENT_EXTENSION_IDS, false);
+		
+		// Update the viewer if we are in the current UI thread
+		if (viewer != null) {
+			Display display = viewer.getControl().getDisplay();
+			if (display!=null && Thread.currentThread().equals(display.getThread()))
+				viewer.refresh();
 		}
-
 	}
 
 		private void createNewProjects() {
@@ -237,6 +287,7 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 			try {
 				edit = StructureEdit.getStructureEditForWrite(aProject);
 				if (edit == null) return;  // Not a component project....
+				edit.getModuleStructuralModel().setUseOldFormat(true);
 				if (edit.getComponent() == null) return; // Can't migrate
 				ComponentType type = edit.getComponent().getComponentType();
 				if (type == null) return;  // Can't migrate
@@ -248,6 +299,7 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 			finally {
 				if (edit != null) {
 					edit.save(null);
+					edit.getModuleStructuralModel().setUseOldFormat(false);
 					edit.dispose();
 				}
 			}
@@ -486,6 +538,7 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 
 			IJavaProject jproj = JemProjectUtilities.getJavaProject(proj);
 			final IClasspathEntry[] current;
+			boolean deployablesFound = false;
 			try {
 				current = jproj.getRawClasspath();
 				List updatedList = new ArrayList();
@@ -495,13 +548,16 @@ public class J2EEComponentProjectMigrator implements IComponentProjectMigrator {
 					if ((entry.getEntryKind() == IClasspathEntry.CPE_SOURCE) && (entry.getOutputLocation() != null && entry.getOutputLocation().toString().indexOf(OLD_DEPLOYABLES_PATH) != -1)) {
 						sourcePath = entry.getPath();
 						updatedList.add(JavaCore.newSourceEntry(sourcePath));
+						deployablesFound = true;
 					}
 					else
 						updatedList.add(entry);
 				}
-				IClasspathEntry[] updated = (IClasspathEntry[])updatedList.toArray(new IClasspathEntry[updatedList.size()]);
-				jproj.setRawClasspath(updated, null);
-				jproj.save(null, true);
+				if (deployablesFound) {
+					IClasspathEntry[] updated = (IClasspathEntry[])updatedList.toArray(new IClasspathEntry[updatedList.size()]);
+					jproj.setRawClasspath(updated, null);
+					jproj.save(null, true);
+				}
 			} catch (JavaModelException e) {
 				// TODO Auto-generated catch block
 				e.printStackTrace();
