@@ -40,7 +40,6 @@ import org.eclipse.jface.preference.IPreferencePage;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
 import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.TableLayout;
-import org.eclipse.jface.viewers.ViewerSorter;
 import org.eclipse.jst.j2ee.application.internal.operations.ClassPathSelection;
 import org.eclipse.jst.j2ee.application.internal.operations.ClasspathElement;
 import org.eclipse.jst.j2ee.commonarchivecore.internal.helpers.ArchiveManifest;
@@ -335,7 +334,9 @@ public class JARDependencyPropertiesPage implements IJ2EEDependenciesControl, IC
 		table.setLayout(tableLayout);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
-		availableJARsViewer.setSorter(new ViewerSorter());
+		
+		// do not create sorter otherwise order will go wrong
+		//availableJARsViewer.setSorter(new ViewerSorter());
 
 		// table columns
 		TableColumn fileNameColumn = new TableColumn(table, SWT.NONE, 0);
@@ -549,11 +550,12 @@ public class JARDependencyPropertiesPage implements IJ2EEDependenciesControl, IC
 					ClasspathElement j2eeElement = (ClasspathElement) j2eeIterator.next();
 					String text = j2eeElement.getText();
 					int index = text.indexOf(".jar");
-					text = text.substring(0, index);
-
-					if (element.getText().equals(text)) {
-						found = true;
-						break;
+					if( index != -1 ){
+						text = text.substring(0, index);
+						if (element.getText().equals(text)) {
+							found = true;
+							break;
+						}
 					}
 				}
 				if (!found) {
