@@ -286,7 +286,7 @@ public class NewJavaClassDataModelProvider extends ArtifactEditOperationDataMode
 				return WTPCommonPlugin.createErrorStatus(msg);
 			} else if (javaStatus.getSeverity() == IStatus.WARNING) {
 				String msg = J2EECommonMessages.ERR_JAVA_PACKAGE_NAME_WARNING + javaStatus.getMessage();
-				return WTPCommonPlugin.createErrorStatus(msg);
+				return WTPCommonPlugin.createWarningStatus(msg);
 			}
 		}
 		// java package name is valid
@@ -420,7 +420,20 @@ public class NewJavaClassDataModelProvider extends ArtifactEditOperationDataMode
 		// Retrieve the java project for the cached project
 		IJavaProject javaProject = JemProjectUtilities.getJavaProject(getTargetProject());
 		try {
-			IPath path = new Path(getStringProperty(SOURCE_FOLDER) + "//" + getStringProperty(JAVA_PACKAGE)); //$NON-NLS-1$
+			String folderPath = getStringProperty(SOURCE_FOLDER);
+			String packagePath = getStringProperty(JAVA_PACKAGE);
+			// Replace all "." with "//" in the package path to denote folders
+			if (packagePath.indexOf('.')>-1) {
+				StringBuffer buffer = new StringBuffer(packagePath);
+				for (int i = 0; i < buffer.length(); i++) {
+					if (buffer.charAt(i)=='.') {
+						buffer.deleteCharAt(i);
+						buffer.insert(i, "//"); //$NON-NLS-1$
+					}
+				}
+				packagePath = buffer.toString();
+			}
+			IPath path = new Path(folderPath + "//" + packagePath); //$NON-NLS-1$
 			IPackageFragment pack = javaProject.findPackageFragment(path);
 			if (pack != null) {
 				ICompilationUnit cu = pack.getCompilationUnit(className + ".java"); //$NON-NLS-1$
