@@ -10,9 +10,6 @@
  *******************************************************************************/
 package org.eclipse.jst.j2ee.internal.web.validation;
 
-import java.util.Hashtable;
-
-
 /**
  * Insert the type's description here. Creation date: (10/2/2001 7:06:43 PM)
  * 
@@ -20,19 +17,10 @@ import java.util.Hashtable;
  */
 public class UIWarHelper extends WarHelper {
 
-	Hashtable aWarFileMap = new Hashtable();
-
 	/**
 	 * UIWarHelper constructor comment.
 	 */
 	public UIWarHelper() {
 		super();
 	}
-	
-	public void disposeWarFileMap() {
-		if (warFileMap != null) {
-			warFileMap.clear();
-			warFileMap = null;
-		}
-	}
 }
