@@ -401,13 +401,9 @@ public class EarValidator extends J2EEValidator  {
 					validateAppClientRefs(ref);
 			} catch (ArchiveWrappedException ex) {
 				Exception nested = ex.getNestedException();
-				if (!(nested instanceof NoModuleFileException)) {
-					//Logger.getLogger().logError(ex);
-					String[] params = new String[1];
-					params[0] = ref.getUri();
-					addError(EREF_CATEGORY, ERROR_MODULE_DD_FILE_NOT_FOUND, params);					
-				}
-				//otherwise ignore it; there are other validations for this
+				String[] params = new String[1];
+				params[0] = ref.getUri();
+				addError(EREF_CATEGORY, ERROR_MODULE_DD_FILE_NOT_FOUND, params);					
 			} 
 			
 		}
@@ -955,5 +951,11 @@ public class EarValidator extends J2EEValidator  {
 		_helper = helper;
 		return null;
 	}
+	
+	public void cleanup(IReporter reporter) {
+		earFile = null;
+		appDD = null;
+		super.cleanup(reporter);
+	}	
 
 }// EarValidator
