@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004 IBM Corporation and others.
+ * Copyright (c) 2004, 2007 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -22,8 +22,10 @@ import org.eclipse.jst.jsp.core.internal.Logger;
 import org.eclipse.jst.jsp.core.internal.parser.JSPSourceParser;
 import org.eclipse.jst.jsp.core.internal.provisional.JSP11Namespace;
 import org.eclipse.jst.jsp.core.internal.regions.DOMJSPRegionContexts;
+import org.eclipse.wst.sse.core.internal.document.StructuredDocumentFactory;
 import org.eclipse.wst.sse.core.internal.ltk.parser.BlockMarker;
 import org.eclipse.wst.sse.core.internal.ltk.parser.StructuredDocumentRegionHandler;
+import org.eclipse.wst.sse.core.internal.provisional.text.IStructuredDocument;
 import org.eclipse.wst.sse.core.internal.provisional.text.IStructuredDocumentRegion;
 import org.eclipse.wst.sse.core.internal.provisional.text.ITextRegion;
 import org.eclipse.wst.sse.core.internal.provisional.text.ITextRegionCollection;
@@ -87,17 +89,33 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 
 	/*
 	 * parse an entire file
+	 * 
+	 * @param filename
+	 * @return
 	 */
-	public void parse(String filename) {
+	public boolean parse(String filename) {
+		getLocalParser().removeStructuredDocumentRegionHandler(this);
 		// from outer class
 		List blockMarkers = this.fTranslator.getBlockMarkers();
-		reset(getContents(filename));
+		IStructuredDocument document = StructuredDocumentFactory.getNewStructuredDocumentInstance(getLocalParser());
+		String contents = getContents(filename);
+		if(contents == null)
+			return false;
 		// this adds the current markers from the outer class list
 		// to this parser so parsing works correctly
 		for (int i = 0; i < blockMarkers.size(); i++) {
 			addBlockMarker((BlockMarker) blockMarkers.get(i));
 		}
-		forceParse();
+		reset(contents);
+//		forceParse();
+		document.set(contents);
+		IStructuredDocumentRegion cursor = document.getFirstStructuredDocumentRegion();
+		while(cursor != null) {
+			nodeParsed(cursor);
+			cursor = cursor.getNext();
+		}
+		getLocalParser().addStructuredDocumentRegionHandler(this);
+		return true;
 	}
 
 
@@ -112,8 +130,23 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 			
 			handleScopingIfNecessary(sdRegion);
 			
-			if (isJSPStartRegion(sdRegion)) {
+			if (isJSPEndRegion(sdRegion)) {
+				fTagname = null;
 				String nameStr = getRegionName(sdRegion);
+				if (isPossibleCustomTag(nameStr)) {
+					// this custom tag may define variables
+					this.fTranslator.addTaglibVariables(nameStr, sdRegion);
+				}
+			}
+			else if (isJSPStartRegion(sdRegion)) {
+				String nameStr = getRegionName(sdRegion);
+				if (sdRegion.getFirstRegion().getType() == DOMRegionContext.XML_TAG_OPEN) {
+					if (isPossibleCustomTag(nameStr)) {
+						// this custom tag may define variables
+						this.fTranslator.addTaglibVariables(nameStr, sdRegion);
+					}
+				}
+
 				if (isJSPRegion(nameStr))
 					fTagname = nameStr;
 				else
@@ -127,6 +160,7 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 				if(fTagname != null && sdRegion.getFirstRegion().getType() == DOMJSPRegionContexts.JSP_DIRECTIVE_OPEN) {
 					processOtherRegions(sdRegion);	
 				}
+
 				// handle jsp:useBean
 				if(fTagname != null && fTagname.equals(JSP11Namespace.ElementName.USEBEAN)) {
 					processUseBean(sdRegion);
@@ -167,7 +201,10 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 		}
 	}
 
+
 	private void handleScopingIfNecessary(IStructuredDocumentRegion sdRegion) {
+		if(true)
+			return;
 
 		// fix to make sure custom tag block have their own scope
 		// we add '{' for custom tag open and '}' for custom tag close
@@ -316,7 +353,7 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 		else if (isTaglibDirective(fTagname)) {
 			// also add the ones created here to the parent document
 			String prefix = getAttributeValue("prefix", sdRegion); //$NON-NLS-1$
-			List docs = this.fTranslator.getTLDCMDocumentManager().getCMDocumentTrackers(prefix, this.fTranslator.getCurrentNode().getEnd());
+			List docs = this.fTranslator.getTLDCMDocumentManager().getCMDocumentTrackers(prefix, this.fTranslator.getCurrentNode().getStartOffset());
 			Iterator it = docs.iterator();
 			Iterator elements = null;
 			CMNode node = null;
@@ -387,6 +424,10 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 	/*
 	 * return true for elements whose contents we might want to add to the java file we are building
 	 */
+	private boolean isJSPEndRegion(IStructuredDocumentRegion sdRegion) {
+		return (sdRegion.getFirstRegion().getType() == DOMRegionContext.XML_END_TAG_OPEN);
+	}
+
 	protected boolean isJSPStartRegion(IStructuredDocumentRegion sdRegion) {
 		return (sdRegion.getFirstRegion().getType() == DOMRegionContext.XML_TAG_OPEN || sdRegion.getFirstRegion().getType() == DOMJSPRegionContexts.JSP_DIRECTIVE_OPEN);
 	}
@@ -441,8 +482,11 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 		return nameStr.trim();
 	}
 
-	/*
+	/**
 	 * get the contents of a file as a String
+	 * 
+	 * @param fileName
+	 * @return the contents, null if the file could not be found
 	 */
 	protected String getContents(String fileName) {
 		StringBuffer s = new StringBuffer();
@@ -461,6 +505,10 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
     				count++;
     				s.append((char) c);
     			}
+            }
+            else {
+            	// error condition, file could not be found
+            	return null;
             }
 		}
 		catch (Exception e) {
@@ -479,4 +527,4 @@ class XMLJSPRegionHelper implements StructuredDocumentRegionHandler {
 		}
 		return s.toString();
 	}
-}
\ No newline at end of file
+}
