@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005 IBM Corporation and others.
+ * Copyright (c) 2005,2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,12 +11,14 @@
  *******************************************************************************/
 package org.eclipse.jst.jsp.core.taglib;
 
+import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Hashtable;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Stack;
+import java.util.zip.CRC32;
 
 import org.eclipse.core.filebuffers.FileBuffers;
 import org.eclipse.core.resources.IFile;
@@ -25,6 +27,7 @@ import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IResourceChangeEvent;
 import org.eclipse.core.resources.IResourceChangeListener;
 import org.eclipse.core.resources.IResourceDelta;
+import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
@@ -38,9 +41,9 @@ import org.eclipse.jdt.core.IJavaElementDelta;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jst.jsp.core.internal.JSPCorePlugin;
 import org.eclipse.jst.jsp.core.internal.Logger;
 import org.eclipse.jst.jsp.core.internal.contentmodel.tld.TLDCMDocumentManager;
-import org.eclipse.wst.sse.core.utils.StringUtils;
 import org.osgi.framework.Bundle;
 
 /**
@@ -48,16 +51,16 @@ import org.osgi.framework.Bundle;
  * ITaglibRegistry but lacking any ties to project natures. Each record
  * returned from the index represents a single tag library descriptor.
  * 
- * Indexing is not persisted between sessions, so new ADD events will be sent
- * to ITaglibIndexListeners during each workbench session. REMOVE events are
- * not fired on workbench shutdown. The record's contents should be examined
- * for any further information.
+ * Indexing is only persisted between sessions for entries on the Java Build
+ * Path. New ADD events will be sent to ITaglibIndexListeners during each
+ * workbench session for both cached and newly found records. REMOVE events
+ * are not fired on workbench shutdown. The record's contents should be
+ * examined for any further information.
  * 
  * @since 1.0
  */
 public final class TaglibIndex {
 	class ClasspathChangeListener implements IElementChangedListener {
-		Stack classpathStack = new Stack();
 		List projectsIndexed = new ArrayList(1);
 
 		public void elementChanged(ElementChangedEvent event) {
@@ -65,74 +68,109 @@ public final class TaglibIndex {
 				return;
 			try {
 				LOCK.acquire();
-				classpathStack.clear();
 				projectsIndexed.clear();
-				elementChanged(event.getDelta());
+				elementChanged(event.getDelta(), true);
 			}
 			finally {
 				LOCK.release();
 			}
 		}
 
-		private void elementChanged(IJavaElementDelta delta) {
+		private void elementChanged(IJavaElementDelta delta, boolean forceUpdate) {
 			if (frameworkIsShuttingDown())
 				return;
 
-			if (delta.getElement().getElementType() == IJavaElement.JAVA_MODEL) {
-				IJavaElementDelta[] changed = delta.getChangedChildren();
+			IJavaElement element = delta.getElement();
+			if (element.getElementType() == IJavaElement.JAVA_MODEL) {
+				IJavaElementDelta[] changed = delta.getAffectedChildren();
 				for (int i = 0; i < changed.length; i++) {
-					elementChanged(changed[i]);
+					elementChanged(changed[i], forceUpdate);
 				}
 			}
-			else if (delta.getElement().getElementType() == IJavaElement.JAVA_PROJECT) {
+			// Handle any changes at the project level
+			else if (element.getElementType() == IJavaElement.JAVA_PROJECT) {
 				if ((delta.getFlags() & IJavaElementDelta.F_CLASSPATH_CHANGED) != 0) {
-					IJavaElement proj = delta.getElement();
-					handleClasspathChange((IJavaProject) proj);
+					IJavaElement proj = element;
+					handleClasspathChange((IJavaProject) proj, forceUpdate);
+				}
+				else {
+					IJavaElementDelta[] deltas = delta.getAffectedChildren();
+					if (deltas.length == 0) {
+						/*
+						 * If project is being deleted or closed, remove the
+						 * stored description
+						 */
+						if (delta.getKind() == IJavaElementDelta.REMOVED || (delta.getFlags() & IJavaElementDelta.F_CLOSED) != 0) {
+							IProject project = ((IJavaProject) element).getProject();
+							removeDescription(project);
+						}
+						/*
+						 * (else) Without the classpath changing, there's
+						 * nothing else to do
+						 */
+					}
+					else {
+						for (int i = 0; i < deltas.length; i++) {
+							elementChanged(deltas[i], false);
+						}
+					}
+				}
+			}
+			/*
+			 * Other modification to the classpath (such as within a classpath
+			 * container like "Web App Libraries") go to the description
+			 * itself
+			 */
+			else if ((delta.getFlags() & IJavaElementDelta.F_ADDED_TO_CLASSPATH) != 0 || (delta.getFlags() & IJavaElementDelta.F_REMOVED_FROM_CLASSPATH) != 0) {
+				IJavaProject affectedProject = element.getJavaProject();
+				if (affectedProject != null) {
+					/*
+					 * If the affected project has an index on-disk, it's
+					 * going to be invalid--we need to create/load the
+					 * description so it will be up to date [loading now and
+					 * updating is usually faster than regenerating the entire
+					 * index]. If there is no index on disk, do nothing more.
+					 */
+					File indexFile = new File(computeIndexLocation(affectedProject.getProject().getFullPath()));
+					if (indexFile.exists()) {
+						ProjectDescription affectedDescription = createDescription(affectedProject.getProject());
+						if (affectedDescription != null) {
+							affectedDescription.handleElementChanged(delta);
+						}
+					}
+					projectsIndexed.add(affectedProject.getProject());
 				}
 			}
 		}
 
-		private void handleClasspathChange(IJavaProject project) {
+		private void handleClasspathChange(IJavaProject project, boolean forceUpdate) {
 			if (frameworkIsShuttingDown())
 				return;
 
-			/*
-			 * Loops in the build paths could cause us to pop more than we
-			 * push
-			 */
-			if (classpathStack.contains(project.getElementName()))
-				return;
-
-			classpathStack.push(project.getElementName());
 			try {
-				/* Handle changes to this project's build path */
+				/* Handle large changes to this project's build path */
 				IResource resource = project.getCorrespondingResource();
 				if (resource.getType() == IResource.PROJECT && !projectsIndexed.contains(resource)) {
-					ProjectDescription description = getDescription((IProject) resource);
+					/*
+					 * Use get instead of create since the downstream
+					 * (upstream?) project wasn't itself modified.
+					 */
+					ProjectDescription description = null;
+					if (forceUpdate) {
+						description = createDescription((IProject) resource);
+					}
+					else {
+						description = getDescription((IProject) resource);
+					}
 					if (description != null && !frameworkIsShuttingDown()) {
 						projectsIndexed.add(resource);
-						description.indexClasspath();
-					}
-				}
-				/*
-				 * Update indeces for projects who include this project in
-				 * their build path (e.g. toggling the "exportation" of a
-				 * taglib JAR in this project affects the JAR's visibility in
-				 * other projects)
-				 */
-				IJavaProject[] projects = project.getJavaModel().getJavaProjects();
-				for (int i = 0; i < projects.length; i++) {
-					IJavaProject otherProject = projects[i];
-					if (StringUtils.contains(otherProject.getRequiredProjectNames(), project.getElementName(), false) && !classpathStack.contains(otherProject.getElementName()) && !frameworkIsShuttingDown()) {
-						handleClasspathChange(otherProject);
+						description.setBuildPathIsDirty();
 					}
 				}
 			}
 			catch (JavaModelException e) {
 				Logger.logException(e);
 			}
-			classpathStack.pop();
-
 		}
 	}
 
@@ -181,15 +219,9 @@ public final class TaglibIndex {
 								}
 								for (int i = 0; i < projects.length; i++) {
 									if (_debugIndexCreation) {
-										Logger.log(Logger.INFO_DEBUG, "TaglibIndex noticed " + projects[i].getName() + " is about to be deleted/closed"); //$NON-NLS-1$ //$NON-NLS-2$
-									}
-									ProjectDescription description = (ProjectDescription) fProjectDescriptions.remove(projects[i]);
-									if (description != null) {
-										if (_debugIndexCreation) {
-											Logger.log(Logger.INFO_DEBUG, "removing index of " + description.fProject.getName()); //$NON-NLS-1$
-										}
-										description.clear();
+										Logger.log(Logger.INFO, "TaglibIndex noticed " + projects[i].getName() + " is about to be deleted/closed"); //$NON-NLS-1$ //$NON-NLS-2$
 									}
+									removeDescription(projects[i]);
 								}
 							}
 						}
@@ -242,15 +274,9 @@ public final class TaglibIndex {
 										}
 										if (!projects[i].isAccessible() || (deltas[i] != null && deltas[i].getKind() == IResourceDelta.REMOVED)) {
 											if (_debugIndexCreation) {
-												Logger.log(Logger.INFO_DEBUG, "TaglibIndex noticed " + projects[i].getName() + " was removed or is no longer accessible"); //$NON-NLS-1$ //$NON-NLS-2$
-											}
-											ProjectDescription description = (ProjectDescription) fProjectDescriptions.remove(projects[i]);
-											if (description != null) {
-												if (_debugIndexCreation) {
-													Logger.log(Logger.INFO_DEBUG, "removing index of " + description.fProject.getName()); //$NON-NLS-1$
-												}
-												description.clear();
+												Logger.log(Logger.INFO, "TaglibIndex noticed " + projects[i].getName() + " was removed or is no longer accessible"); //$NON-NLS-1$ //$NON-NLS-2$
 											}
+											removeDescription(projects[i]);
 										}
 									}
 									catch (CoreException e) {
@@ -281,8 +307,13 @@ public final class TaglibIndex {
 
 	static TaglibIndex _instance;
 
+	private static final CRC32 checksumCalculator = new CRC32();
+
+	private static final String CLEAN = "CLEAN";
+	private static final String DIRTY = "DIRTY";
 	static boolean ENABLED = false;
-	static ILock LOCK = null;
+
+	static ILock LOCK = Platform.getJobManager().newLock();
 
 	/**
 	 * NOT API.
@@ -293,7 +324,8 @@ public final class TaglibIndex {
 	public static void addTaglibIndexListener(ITaglibIndexListener listener) {
 		try {
 			LOCK.acquire();
-			_instance.internalAddTaglibIndexListener(listener);
+			if (_instance != null)
+				_instance.internalAddTaglibIndexListener(listener);
 		}
 		finally {
 			LOCK.release();
@@ -302,7 +334,7 @@ public final class TaglibIndex {
 
 	static void fireTaglibRecordEvent(ITaglibRecordEvent event) {
 		if (_debugEvents) {
-			Logger.log(Logger.INFO_DEBUG, "TaglibIndex fired event:" + event); //$NON-NLS-1$
+			Logger.log(Logger.INFO, "TaglibIndex fired event:" + event); //$NON-NLS-1$
 		}
 		/*
 		 * Flush any shared cache entries, the TaglibControllers should handle
@@ -310,14 +342,16 @@ public final class TaglibIndex {
 		 */
 		TLDCMDocumentManager.getSharedDocumentCache().remove(TLDCMDocumentManager.getUniqueIdentifier(event.getTaglibRecord()));
 
-		ITaglibIndexListener[] listeners = _instance.fTaglibIndexListeners;
-		if (listeners != null) {
-			for (int i = 0; i < listeners.length; i++) {
-				try {
-					listeners[i].indexChanged(event);
-				}
-				catch (Exception e) {
-					Logger.log(Logger.WARNING, e.getMessage());
+		if (_instance != null) {
+			ITaglibIndexListener[] listeners = _instance.fTaglibIndexListeners;
+			if (listeners != null) {
+				for (int i = 0; i < listeners.length; i++) {
+					try {
+						listeners[i].indexChanged(event);
+					}
+					catch (Exception e) {
+						Logger.log(Logger.WARNING, e.getMessage());
+					}
 				}
 			}
 		}
@@ -336,8 +370,18 @@ public final class TaglibIndex {
 	 * @return All of the visible ITaglibRecords from the given path.
 	 */
 	public static ITaglibRecord[] getAvailableTaglibRecords(IPath fullPath) {
-		ITaglibRecord[] records = _instance.internalGetAvailableTaglibRecords(fullPath);
-		return records;
+		try {
+			LOCK.acquire();
+			ITaglibRecord[] records = null;
+			if (_instance != null)
+				records = _instance.internalGetAvailableTaglibRecords(fullPath);
+			else
+				records = new ITaglibRecord[0];
+			return records;
+		}
+		finally {
+			LOCK.release();
+		}
 	}
 
 	/**
@@ -361,6 +405,11 @@ public final class TaglibIndex {
 		}
 	}
 
+	private String getState() {
+		String state = JSPCorePlugin.getDefault().getPluginPreferences().getString(TaglibIndex.class.getName());
+		return state;
+	}
+
 	/**
 	 * NOT API.
 	 * 
@@ -370,7 +419,8 @@ public final class TaglibIndex {
 	public static void removeTaglibIndexListener(ITaglibIndexListener listener) {
 		try {
 			LOCK.acquire();
-			_instance.internalRemoveTaglibIndexListener(listener);
+			if (_instance != null)
+				_instance.internalRemoveTaglibIndexListener(listener);
 		}
 		finally {
 			LOCK.release();
@@ -399,25 +449,26 @@ public final class TaglibIndex {
 		ITaglibRecord result = null;
 		try {
 			LOCK.acquire();
-			result = _instance.internalResolve(basePath, reference, crossProjects);
+			if (_instance != null)
+				result = _instance.internalResolve(basePath, reference, crossProjects);
 		}
 		finally {
 			LOCK.release();
 		}
 		if (_debugResolution) {
 			if (result == null) {
-				Logger.log(Logger.INFO_DEBUG, "TaglibIndex could not resolve \"" + reference + "\" from " + basePath); //$NON-NLS-1$ //$NON-NLS-2$
+				Logger.log(Logger.INFO, "TaglibIndex could not resolve \"" + reference + "\" from " + basePath); //$NON-NLS-1$ //$NON-NLS-2$
 			}
 			else {
 				switch (result.getRecordType()) {
 					case (ITaglibRecord.TLD) : {
 						ITLDRecord record = (ITLDRecord) result;
-						Logger.log(Logger.INFO_DEBUG, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getPath()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+						Logger.log(Logger.INFO, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getPath()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 					}
 						break;
 					case (ITaglibRecord.JAR) : {
 						IJarRecord record = (IJarRecord) result;
-						Logger.log(Logger.INFO_DEBUG, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getLocation()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+						Logger.log(Logger.INFO, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getLocation()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 					}
 						break;
 					case (ITaglibRecord.TAGDIR) : {
@@ -425,7 +476,7 @@ public final class TaglibIndex {
 						break;
 					case (ITaglibRecord.URL) : {
 						IURLRecord record = (IURLRecord) result;
-						Logger.log(Logger.INFO_DEBUG, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getURL()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+						Logger.log(Logger.INFO, "TaglibIndex resolved " + basePath + ":" + reference + " = " + record.getURL()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 					}
 						break;
 				}
@@ -434,15 +485,61 @@ public final class TaglibIndex {
 		return result;
 	}
 
+	/**
+	 * Removes index files. Used for maintenance and keeping the index folder
+	 * a manageable size.
+	 * 
+	 * @param staleOnly -
+	 *            if <b>true</b>, removes only the indexes for projects not
+	 *            open in the workspace, if <b>false</b>, removes all of the
+	 *            indexes
+	 */
+	private void removeIndexes(boolean staleOnly) {
+		String osPath = getTaglibIndexStateLocation().toOSString();
+		File folder = new File(osPath);
+		if (!folder.isDirectory()) {
+			try {
+				folder.mkdir();
+			}
+			catch (SecurityException e) {
+			}
+		}
+
+		// remove any extraneous index files
+		IProject[] projects = ResourcesPlugin.getWorkspace().getRoot().getProjects();
+		List indexNames = new ArrayList(projects.length);
+		if (staleOnly) {
+			for (int i = 0; i < projects.length; i++) {
+				if (projects[i].isAccessible()) {
+					indexNames.add(computeIndexName(projects[i].getFullPath()));
+				}
+			}
+		}
+
+		if (folder.isDirectory()) {
+			File[] files = folder.listFiles();
+			for (int i = 0; files != null && i < files.length; i++) {
+				if (!indexNames.contains(files[i].getName()))
+					files[i].delete();
+			}
+		}
+	}
+
 	/**
 	 * Instructs the index to stop listening for resource and classpath
 	 * changes, and to forget all information about the workspace.
 	 */
 	public static synchronized void shutdown() {
-		if (_instance != null) {
-			_instance.stop();
+		try {
+			LOCK.acquire();
+			if (_instance != null) {
+				_instance.stop();
+			}
+			_instance = null;
+		}
+		finally {
+			LOCK.release();
 		}
-		_instance = null;
 	}
 
 	/**
@@ -450,8 +547,14 @@ public final class TaglibIndex {
 	 * changes.
 	 */
 	public static synchronized void startup() {
-		ENABLED = !"false".equalsIgnoreCase(System.getProperty(TaglibIndex.class.getName())); //$NON-NLS-1$
-		_instance = new TaglibIndex();
+		try {
+			LOCK.acquire();
+			ENABLED = !"false".equalsIgnoreCase(System.getProperty(TaglibIndex.class.getName())); //$NON-NLS-1$
+			_instance = new TaglibIndex();
+		}
+		finally {
+			LOCK.release();
+		}
 	}
 
 	private ClasspathChangeListener fClasspathChangeListener = null;
@@ -466,14 +569,45 @@ public final class TaglibIndex {
 
 	private TaglibIndex() {
 		super();
+
+		/*
+		 * Only consider a crash if a value exists and is DIRTY (not a new
+		 * workspace)
+		 */
+		if (DIRTY.equalsIgnoreCase(getState())) {
+			Logger.log(Logger.WARNING, "A workspace crash was detected. The previous session did not exit normally. Not using saved tag library indexes"); //$NON-NLS-3$
+			removeIndexes(false);
+		}
+
+		fProjectDescriptions = new Hashtable();
 		fResourceChangeListener = new ResourceChangeListener();
 		fClasspathChangeListener = new ClasspathChangeListener();
 		if (ENABLED) {
 			ResourcesPlugin.getWorkspace().addResourceChangeListener(fResourceChangeListener, IResourceChangeEvent.POST_CHANGE);
 			JavaCore.addElementChangedListener(fClasspathChangeListener);
 		}
-		LOCK = Platform.getJobManager().newLock();
-		fProjectDescriptions = new Hashtable();
+	}
+
+	/**
+	 * Based on org.eclipse.jdt.internal.core.search.indexing.IndexManager
+	 * 
+	 * @param containerPath
+	 * @return
+	 */
+	String computeIndexLocation(IPath containerPath) {
+		String fileName = computeIndexName(containerPath);
+		if (_debugIndexCreation)
+			Logger.log(Logger.INFO, "-> index name for " + containerPath + " is " + fileName); //$NON-NLS-1$ //$NON-NLS-2$
+		String indexLocation = getTaglibIndexStateLocation().append(fileName).toOSString();
+		return indexLocation;
+	}
+
+	String computeIndexName(IPath containerPath) {
+		checksumCalculator.reset();
+		checksumCalculator.update(containerPath.toOSString().getBytes());
+		// use ".dat" so we're not confused with JDT indexes
+		String fileName = Long.toString(checksumCalculator.getValue()) + ".dat"; //$NON-NLS-1$
+		return fileName;
 	}
 
 	/**
@@ -484,11 +618,11 @@ public final class TaglibIndex {
 		ProjectDescription description = null;
 		description = (ProjectDescription) fProjectDescriptions.get(project);
 		if (description == null) {
-			description = new ProjectDescription(project);
-			if (ENABLED) {
-				description.index();
-				description.indexClasspath();
+			// Once we've started indexing, we're dirty again
+			if (fProjectDescriptions.isEmpty()) {
+				setState(DIRTY);
 			}
+			description = new ProjectDescription(project, computeIndexLocation(project.getFullPath()));
 			fProjectDescriptions.put(project, description);
 		}
 		return description;
@@ -515,6 +649,10 @@ public final class TaglibIndex {
 		return description;
 	}
 
+	private IPath getTaglibIndexStateLocation() {
+		return JSPCorePlugin.getDefault().getStateLocation().append("taglibindex/");
+	}
+
 	private void internalAddTaglibIndexListener(ITaglibIndexListener listener) {
 		if (fTaglibIndexListeners == null) {
 			fTaglibIndexListeners = new ITaglibIndexListener[]{listener};
@@ -530,9 +668,29 @@ public final class TaglibIndex {
 		ITaglibRecord[] records = new ITaglibRecord[0];
 		if (path.segmentCount() > 0) {
 			IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(path.segment(0));
-			ProjectDescription description = createDescription(project);
-			List availableRecords = description.getAvailableTaglibRecords(path);
-			records = (ITaglibRecord[]) availableRecords.toArray(records);
+			if(project.isAccessible()) {
+				ProjectDescription description = createDescription(project);
+				List availableRecords = description.getAvailableTaglibRecords(path);
+	
+				// ICatalog catalog =
+				// XMLCorePlugin.getDefault().getDefaultXMLCatalog();
+				// while (catalog != null) {
+				// ICatalogEntry[] entries = catalog.getCatalogEntries();
+				// for (int i = 0; i < entries.length; i++) {
+				// // System.out.println(entries[i].getURI());
+				// }
+				// INextCatalog[] nextCatalogs = catalog.getNextCatalogs();
+				// for (int i = 0; i < nextCatalogs.length; i++) {
+				// ICatalogEntry[] entries2 =
+				// nextCatalogs[i].getReferencedCatalog().getCatalogEntries();
+				// for (int j = 0; j < entries2.length; j++) {
+				// // System.out.println(entries2[j].getURI());
+				// }
+				// }
+				// }
+	
+				records = (ITaglibRecord[]) availableRecords.toArray(records);
+			}
 		}
 		return records;
 	}
@@ -566,7 +724,24 @@ public final class TaglibIndex {
 		IProject project = null;
 		ITaglibRecord resolved = null;
 
-		IFile baseResource = FileBuffers.getWorkspaceFileAtLocation(new Path(basePath));
+		Path baseIPath = new Path(basePath);
+		IResource baseResource = FileBuffers.getWorkspaceFileAtLocation(baseIPath);
+
+		if (baseResource == null) {
+			IWorkspaceRoot workspaceRoot = ResourcesPlugin.getWorkspace().getRoot();
+			// Try the base path as a folder first
+			if (baseResource == null && baseIPath.segmentCount() > 1) {
+				baseResource = workspaceRoot.getFolder(baseIPath);
+			}
+			// If not a folder, then try base path as a file
+			if (baseResource != null && !baseResource.exists() && baseIPath.segmentCount() > 1) {
+				baseResource = workspaceRoot.getFile(baseIPath);
+			}
+			if (baseResource == null && baseIPath.segmentCount() == 1) {
+				baseResource = workspaceRoot.getProject(baseIPath.segment(0));
+			}
+		}
+
 		if (baseResource == null) {
 			/*
 			 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=116529
@@ -574,15 +749,16 @@ public final class TaglibIndex {
 			 * This method produces a less accurate result, but doesn't
 			 * require that the file exist yet.
 			 */
-			IFile[] files = ResourcesPlugin.getWorkspace().getRoot().findFilesForLocation(new Path(basePath));
+			IFile[] files = ResourcesPlugin.getWorkspace().getRoot().findFilesForLocation(baseIPath);
 			if (files.length > 0)
 				baseResource = files[0];
 		}
-		if (baseResource != null) {
+		if (baseResource != null && baseResource.isAccessible()) {
 			project = baseResource.getProject();
 			ProjectDescription description = createDescription(project);
 			resolved = description.resolve(basePath, reference);
 		}
+
 		return resolved;
 	}
 
@@ -590,9 +766,43 @@ public final class TaglibIndex {
 		return _instance != null && ENABLED;
 	}
 
+	private void setState(String state) {
+		if (!state.equals(getState())) {
+			JSPCorePlugin.getDefault().getPluginPreferences().setValue(TaglibIndex.class.getName(), state);
+			JSPCorePlugin.getDefault().savePluginPreferences();
+		}
+	}
+
 	private void stop() {
 		ResourcesPlugin.getWorkspace().removeResourceChangeListener(fResourceChangeListener);
 		JavaCore.removeElementChangedListener(fClasspathChangeListener);
+
+		/*
+		 * Clearing the existing saved states helps prune dead data from the
+		 * index folder.
+		 */
+		removeIndexes(true);
+
+		Iterator i = fProjectDescriptions.values().iterator();
+		while (i.hasNext()) {
+			ProjectDescription description = (ProjectDescription) i.next();
+			description.saveReferences();
+		}
+
 		fProjectDescriptions.clear();
+
+		setState(CLEAN);
+	}
+
+	void removeDescription(IProject project) {
+		ProjectDescription description = (ProjectDescription) fProjectDescriptions.remove(project);
+		if (description != null) {
+			if (_debugIndexCreation) {
+				Logger.log(Logger.INFO, "removing index of " + description.fProject.getName()); //$NON-NLS-1$
+			}
+			description.setBuildPathIsDirty();
+			description.clear();
+			description.saveReferences();
+		}
 	}
 }
