@@ -274,19 +274,26 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 	 * @throws CoreException
 	 */
 	private void publishDir(int deltaKind, Properties p, IModule module[], IProgressMonitor monitor) throws CoreException {
+		List status = new ArrayList();
 		if (deltaKind == REMOVED) {
 			try {
 				String publishPath = (String) p.get(module[0].getId());
-				PublishUtil.deleteDirectory(new File(publishPath), monitor);
+				File f = new File(publishPath);
+				if (f.exists()) {
+					IStatus[] stat = PublishUtil.deleteDirectory(f, monitor);
+					PublishOperation2.addArrayToList(status, stat);
+				}
 			} catch (Exception e) {
 				throw new CoreException(new Status(IStatus.WARNING, TomcatPlugin.PLUGIN_ID, 0, "Could not remove module", e));
 			}
 		} else {
 			IPath to = getServer().getRuntime().getLocation().append("webapps").append(module[0].getName());
 			IModuleResource[] mr = getResources(module);
-			PublishUtil.smartCopy(mr, to, monitor);
+			IStatus[] stat = PublishUtil.publishSmart(mr, to, monitor);
+			PublishOperation2.addArrayToList(status, stat);
 			p.put(module[0].getId(), to.toOSString());
 		}
+		PublishOperation2.throwException(status);
 	}
 
 	/**
@@ -323,7 +330,10 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 			}
 			
 			IModuleResource[] mr = getResources(module);
-			PublishUtil.createZipFile(mr, jarPath);
+			IStatus[] stat = PublishUtil.publishZip(mr, jarPath, monitor);
+			List status = new ArrayList();
+			PublishOperation2.addArrayToList(status, stat);
+			PublishOperation2.throwException(status);
 			p.put(module[1].getId(), jarPath.toOSString());
 		}
 	}
@@ -334,7 +344,7 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 			baseDir = getTempDirectory();
 		else
 			baseDir = getServer().getRuntime().getLocation();
-
+		
 		// Publish context configuration for servers that support META-INF/context.xml
 		IStatus status = getTomcatConfiguration().publishContextConfig(baseDir, monitor);
 		if (!status.isOK())
@@ -405,14 +415,14 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 		setServerRestartState(false);
 		setServerState(IServer.STATE_STARTING);
 		setMode(launchMode);
-	
+		
 		// ping server to check for startup
 		try {
 			String url = "http://localhost";
 			int port = configuration.getMainPort().getPort();
 			if (port != 80)
 				url += ":" + port;
-			ping = new PingThread(getServer(), url, 50, this);
+			ping = new PingThread(getServer(), url, -1, this);
 		} catch (Exception e) {
 			Trace.trace(Trace.SEVERE, "Can't ping for Tomcat startup.");
 		}
@@ -446,6 +456,7 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 			
 			String args = renderCommandLine(getRuntimeProgramArguments(false), " ");
 			wc.setAttribute(IJavaLaunchConfigurationConstants.ATTR_PROGRAM_ARGUMENTS, args);
+			wc.setAttribute("org.eclipse.debug.ui.private", true);
 			wc.setAttribute(ATTR_STOP, "true");
 			wc.launch(ILaunchManager.RUN_MODE, new NullProgressMonitor());
 		} catch (Exception e) {
@@ -669,10 +680,8 @@ public class TomcatServerBehaviour extends ServerBehaviourDelegate implements IT
 		
 		ITomcatRuntime runtime = getTomcatRuntime();
 		IVMInstall vmInstall = runtime.getVMInstall();
-		if (vmInstall != null) {
-			workingCopy.setAttribute(IJavaLaunchConfigurationConstants.ATTR_VM_INSTALL_TYPE, vmInstall.getVMInstallType().getId());
-			workingCopy.setAttribute(IJavaLaunchConfigurationConstants.ATTR_VM_INSTALL_NAME, vmInstall.getName());
-		}
+		if (vmInstall != null)
+			workingCopy.setAttribute(IJavaLaunchConfigurationConstants.ATTR_JRE_CONTAINER_PATH, JavaRuntime.newJREContainerPath(vmInstall).toPortableString());
 		
 		// update classpath
 		IRuntimeClasspathEntry[] originalClasspath = JavaRuntime.computeUnresolvedRuntimeClasspath(workingCopy);
