@@ -23,6 +23,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.wst.common.componentcore.ComponentCore;
+import org.eclipse.wst.common.componentcore.ModuleCoreNature;
 import org.eclipse.wst.common.componentcore.internal.ComponentcoreFactory;
 import org.eclipse.wst.common.componentcore.internal.ComponentcorePackage;
 import org.eclipse.wst.common.componentcore.internal.DependencyType;
@@ -36,6 +37,7 @@ import org.eclipse.wst.common.componentcore.resources.IVirtualComponent;
 import org.eclipse.wst.common.componentcore.resources.IVirtualFolder;
 import org.eclipse.wst.common.componentcore.resources.IVirtualReference;
 import org.eclipse.wst.common.componentcore.resources.IVirtualResource;
+import org.eclipse.wst.common.frameworks.internal.HashUtil;
 
 
 public class VirtualComponent implements IVirtualComponent {
@@ -50,6 +52,9 @@ public class VirtualComponent implements IVirtualComponent {
 	}
 	
 	public VirtualComponent(IProject aProject, IPath aRuntimePath) {
+		if(aProject == null){
+			throw new NullPointerException();
+		}
 		componentProject = aProject;
 		runtimePath = aRuntimePath;
 		rootFolder = ComponentCore.createFolder(componentProject, new Path("/")); //$NON-NLS-1$
@@ -83,63 +88,10 @@ public class VirtualComponent implements IVirtualComponent {
 	}
 	
 	public boolean exists() { 
-		StructureEdit core = null;
 		IProject project = getProject();
-		try {
-			if (project != null && getName() != null) {
-				core = StructureEdit.getStructureEditForRead(project);
-				if(core == null){
-					return false;
-				}
-				WorkbenchComponent component = core.getComponent(); 
-				return component != null;
-			}
-		} finally {
-			if(core != null)
-				core.dispose();
-		}
-		return false;
+		return ModuleCoreNature.isFlexibleProject(project);
 	}
 	
-//	public String getComponentTypeId() {
-//		if (null == componentTypeId) {
-//			StructureEdit core = null;
-//			try {
-//				if (getProject() == null || getName() == null)
-//					return null;
-//				core = StructureEdit.getStructureEditForRead(getProject());
-//				if (core == null)
-//					return null;
-//				WorkbenchComponent component = core.getComponent();
-//				ComponentType cType = component == null ? null : component.getComponentType();
-//				componentTypeId = cType == null ? null : cType.getComponentTypeId();
-//			} finally {
-//				if (core != null)
-//					core.dispose();
-//			}
-//		}
-//		return componentTypeId;
-//	}
-
-//	public void setComponentTypeId(String aComponentTypeId) {
-//
-//		StructureEdit core = null;
-//		try {
-//			core = StructureEdit.getStructureEditForWrite(getProject());
-//			WorkbenchComponent component = core.getComponent(); 
-//			ComponentType cType = component.getComponentType();
-//			if(cType == null) {
-//				cType = ComponentcorePackage.eINSTANCE.getComponentcoreFactory().createComponentType();
-//				component.setComponentType(cType);
-//			}
-//			cType.setComponentTypeId(aComponentTypeId);
-//		} finally {
-//			if(core != null) {
-//				core.saveIfNecessary(null);
-//				core.dispose();
-//			}
-//		}
-//	}
 
 	public Properties getMetaProperties() {
         StructureEdit core = null;
@@ -196,6 +148,20 @@ public class VirtualComponent implements IVirtualComponent {
         }
 	}
 	
+	public void clearMetaProperties() {
+		StructureEdit core = null;
+        try {
+            core = StructureEdit.getStructureEditForWrite(getProject());
+            WorkbenchComponent component = core.getComponent(); 
+            component.getProperties().clear();
+        } finally {
+            if(core != null){
+            	core.saveIfNecessary(null);
+                core.dispose();
+            }
+        }
+	}
+	
 	public void setMetaProperty(String key, String value) {
         StructureEdit core = null;
         try {
@@ -362,8 +328,9 @@ public class VirtualComponent implements IVirtualComponent {
 			if (referencedComponent==null) 
 				continue;
 			IVirtualReference vReference = StructureEdit.createVirtualReference(this, referencedComponent);
-			if (vReference == null || vReference.getReferencedComponent() == null || !vReference.getReferencedComponent().exists())
-				component.getReferencedComponents().remove(referencedComponent); 
+			if (vReference == null || vReference.getReferencedComponent() == null || !vReference.getReferencedComponent().exists()){
+				iter.remove();
+			}
 		}
 	}
 	
@@ -399,14 +366,20 @@ public class VirtualComponent implements IVirtualComponent {
 		}	
 	}
 
+	public int hashCode() {
+		int hash = HashUtil.SEED;
+		hash = HashUtil.hash(hash, getProject().getName());
+		hash = HashUtil.hash(hash, getName());
+		hash = HashUtil.hash(hash, isBinary());
+		return hash;
+	}
 	
 	public boolean equals(Object anOther) { 
 		if(anOther instanceof IVirtualComponent) {
 			IVirtualComponent otherComponent = (IVirtualComponent) anOther;
-			return getProject() !=null && 
-					getProject().equals(otherComponent.getProject()) && 
-					getName().equals(otherComponent.getName()) && 
-					isBinary() == otherComponent.isBinary();
+			return getProject().equals(otherComponent.getProject()) && 
+				   getName().equals(otherComponent.getName()) && 
+				   isBinary() == otherComponent.isBinary();
 		}
 		return false;
 	}
@@ -531,4 +504,8 @@ public class VirtualComponent implements IVirtualComponent {
 				core.dispose();
 		}		
 	}
+	
+	public String toString() {
+		return componentProject.toString();
+	}
 }
