@@ -11,8 +11,12 @@
 
 package org.eclipse.wst.common.project.facet.core.internal;
 
+import java.io.PrintWriter;
+import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -45,12 +49,14 @@ import org.eclipse.osgi.util.NLS;
 import org.eclipse.wst.common.project.facet.core.IActionDefinition;
 import org.eclipse.wst.common.project.facet.core.ICategory;
 import org.eclipse.wst.common.project.facet.core.IConstraint;
+import org.eclipse.wst.common.project.facet.core.IDefaultVersionProvider;
 import org.eclipse.wst.common.project.facet.core.IFacetedProject;
 import org.eclipse.wst.common.project.facet.core.IFacetedProjectTemplate;
 import org.eclipse.wst.common.project.facet.core.IGroup;
 import org.eclipse.wst.common.project.facet.core.IPreset;
 import org.eclipse.wst.common.project.facet.core.IProjectFacet;
 import org.eclipse.wst.common.project.facet.core.IProjectFacetVersion;
+import org.eclipse.wst.common.project.facet.core.IVersionExpr;
 import org.eclipse.wst.common.project.facet.core.IFacetedProject.Action;
 import org.osgi.service.prefs.BackingStoreException;
 import org.osgi.service.prefs.Preferences;
@@ -70,6 +76,7 @@ public final class ProjectFacetsManagerImpl
     private static final String ATTR_GROUP = "group"; //$NON-NLS-1$
     private static final String ATTR_ID = "id"; //$NON-NLS-1$
     private static final String ATTR_NAME = "name"; //$NON-NLS-1$
+    private static final String ATTR_PROVIDER = "provider"; //$NON-NLS-1$
     private static final String ATTR_SOFT = "soft"; //$NON-NLS-1$
     private static final String ATTR_TYPE = "type"; //$NON-NLS-1$
     private static final String ATTR_VALUE = "value"; //$NON-NLS-1$
@@ -78,6 +85,7 @@ public final class ProjectFacetsManagerImpl
     private static final String EL_CATEGORY = "category"; //$NON-NLS-1$
     private static final String EL_CONFIG_FACTORY = "config-factory"; //$NON-NLS-1$
     private static final String EL_CONSTRAINT = "constraint"; //$NON-NLS-1$
+    private static final String EL_DEFAULT_VERSION = "default-version"; //$NON-NLS-1$
     private static final String EL_DELEGATE = "delegate"; //$NON-NLS-1$
     private static final String EL_DESCRIPTION = "description"; //$NON-NLS-1$
     private static final String EL_EVENT_HANDLER = "event-handler"; //$NON-NLS-1$
@@ -103,6 +111,41 @@ public final class ProjectFacetsManagerImpl
     
     public ProjectFacetsManagerImpl()
     {
+        long activationStart = 0;
+        
+        if( FacetCorePlugin.isTracingFrameworkActivation() )
+        {
+            final StringWriter sw = new StringWriter();
+            final PrintWriter pw = new PrintWriter( sw );
+            ( new Throwable() ).printStackTrace( pw );
+            
+            String context = sw.getBuffer().toString();
+            final int endOfFirstLine = context.indexOf( '\n' );
+            context = context.substring( endOfFirstLine + 1 );
+            context = context.replaceAll( "\\t", "  " ); //$NON-NLS-1$ //$NON-NLS-2$
+            
+            int length = context.length();
+            
+            if( context.charAt( length - 2 ) == '\r' )
+            {
+                length = length - 2;
+            }
+            else
+            {
+                length = length - 1;
+            }
+            
+            context = context.substring( 0, length );
+            
+            final String msg 
+                = NLS.bind( Resources.tracingFrameworkActivationStarting, 
+                            context ); 
+            
+            System.out.println( msg );
+            
+            activationStart = System.currentTimeMillis();
+        }
+        
         this.facets = new IndexedSet();
         this.actions = new IndexedSet();
         this.categories = new IndexedSet();
@@ -117,6 +160,18 @@ public final class ProjectFacetsManagerImpl
         final IWorkspace ws = ResourcesPlugin.getWorkspace();
         final IResourceChangeListener ls = new ResourceChangeListener();
         ws.addResourceChangeListener( ls, IResourceChangeEvent.POST_CHANGE );
+        
+        if( FacetCorePlugin.isTracingFrameworkActivation() )
+        {
+            final long duration 
+                = System.currentTimeMillis() - activationStart;
+            
+            final String msg
+                = NLS.bind( Resources.tracingFrameworkActivationFinished, 
+                            String.valueOf( duration ) );
+            
+            System.out.println( msg );
+        }
     }
     
     public Set getProjectFacets()
@@ -426,12 +481,14 @@ public final class ProjectFacetsManagerImpl
     {
         if( monitor != null )
         {
-            monitor.beginTask( "", 2 ); //$NON-NLS-1$
+            monitor.beginTask( "", 1 ); //$NON-NLS-1$
         }
         
         try
         {
-            if( project.exists() && convertIfNecessary )
+            if( project.isAccessible() &&
+                ! project.isNatureEnabled( FacetedProjectNature.NATURE_ID ) && 
+                convertIfNecessary )
             {
                 IProjectDescription description = project.getDescription();
                 String[] prevNatures = description.getNatureIds();
@@ -443,8 +500,6 @@ public final class ProjectFacetsManagerImpl
                 project.setDescription( description, submon( monitor, 1 ) );
             }
             
-            project.open( IResource.BACKGROUND_REFRESH, submon( monitor, 1 ) );
-            
             return create( project );
         }
         finally
@@ -807,20 +862,58 @@ public final class ProjectFacetsManagerImpl
             unsorted = new ArrayList( actions );
         }
         
-        // Step 1 : Pre-sort all uninstall actions to the front of the list.
+        // Step 1 : Pre-sort all uninstall actions to the front of the list. 
+        //          Within that order, sort actions based on facet id. The
+        //          secondary sort assures a stable sort order among actions on
+        //          unrelated facets.
         
-        for( int i = 0, j = 0; j < count; j++ )
+        final Comparator comp = new Comparator()
         {
-            final Action action = (Action) actions.get( j );
-            
-            if( action.getType() == Action.Type.UNINSTALL && i != j )
+            public int compare( final Object obj1, 
+                                final Object obj2 )
             {
-                actions.set( j, actions.get( i ) );
-                actions.set( i, action );
-                i++;
-                steps++;
+                final Action a1 = (Action) obj1;
+                final Action a2 = (Action) obj2;
+                
+                int res = compare( a1.getType(), a2.getType() );
+                
+                if( res == 0 )
+                {
+                    final String fid1 
+                        = a1.getProjectFacetVersion().getProjectFacet().getId();
+                    
+                    final String fid2 
+                        = a2.getProjectFacetVersion().getProjectFacet().getId();
+                    
+                    res = fid1.compareTo( fid2 );
+                }
+                
+                return res;
             }
-        }
+            
+            private int compare( final Action.Type t1,
+                                 final Action.Type t2 )
+            {
+                if( t1 == t2 )
+                {
+                    return 0;
+                }
+                else if( t1 == Action.Type.UNINSTALL )
+                {
+                    return -1;
+                }
+                else if( t2 == Action.Type.UNINSTALL )
+                {
+                    return 1;
+                }
+                else
+                {
+                    return 0;
+                }
+            }
+        };
+        
+        Collections.sort( actions, comp );
         
         // Step 2 : Sort based on the constraints.
         
@@ -1109,6 +1202,17 @@ public final class ProjectFacetsManagerImpl
             }
         }
         
+        for( int i = 0, n = cfgels.size(); i < n; i++ )
+        {
+            final IConfigurationElement config
+                = (IConfigurationElement) cfgels.get( i );
+            
+            if( config.getName().equals( EL_PROJECT_FACET ) )
+            {
+                readDefaultVersionInfo( config );
+            }
+        }
+
         for( int i = 0, n = cfgels.size(); i < n; i++ )
         {
             final IConfigurationElement config
@@ -1164,6 +1268,16 @@ public final class ProjectFacetsManagerImpl
             }
         }
         
+        if( category.getLabel() == null )
+        {
+            category.setLabel( category.getId() );
+        }
+        
+        if( category.getDescription() == null )
+        {
+            category.setDescription( "" ); //$NON-NLS-1$
+        }
+        
         this.categories.add( id, category );
     }
     
@@ -1180,7 +1294,7 @@ public final class ProjectFacetsManagerImpl
         final ProjectFacet descriptor = new ProjectFacet();
         descriptor.setId( id );
         descriptor.setPluginId( config.getContributor().getName() );
-
+        
         final IConfigurationElement[] children = config.getChildren();
         
         for( int i = 0; i < children.length; i++ )
@@ -1237,6 +1351,12 @@ public final class ProjectFacetsManagerImpl
             descriptor.setLabel( id );
         }
         
+        if( descriptor.getDescription() == null )
+        {
+            descriptor.setDescription( "" ); //$NON-NLS-1$
+        }
+        
+        
         this.facets.add( id, descriptor );
     }
     
@@ -1333,6 +1453,91 @@ public final class ProjectFacetsManagerImpl
         }
     }
     
+    private void readDefaultVersionInfo( final IConfigurationElement config )
+    {
+        final String id = config.getAttribute( ATTR_ID );
+
+        if( id == null || ! isProjectFacetDefined( id ) )
+        {
+            // The error should have already been reported, don't need to log
+            // this again.
+            
+            return;
+        }
+        
+        final ProjectFacet f = (ProjectFacet) getProjectFacet( id );
+        boolean defaultVersionSpecified = false;
+
+        final IConfigurationElement[] children = config.getChildren();
+        
+        for( int i = 0; i < children.length; i++ )
+        {
+            final IConfigurationElement child = children[ i ];
+            final String childName = child.getName();
+            
+            if( childName.equals( EL_DEFAULT_VERSION ) )
+            {
+                final String clname = child.getAttribute( ATTR_PROVIDER );
+                
+                if( clname != null )
+                {
+                    try
+                    {
+                        final Class type = IDefaultVersionProvider.class;
+                        
+                        final IDefaultVersionProvider defaultVersionProvider
+                            = (IDefaultVersionProvider) 
+                                FacetCorePlugin.instantiate( f.getPluginId(),
+                                                             clname, type );
+                        
+                        f.setDefaultVersionProvider( defaultVersionProvider );
+                        defaultVersionSpecified = true;
+                    }
+                    catch( CoreException e )
+                    {
+                        FacetCorePlugin.log( e );
+                    }
+                }
+                else
+                {
+                    final String version = child.getAttribute( ATTR_VERSION );
+                    
+                    if( version != null )
+                    {
+                        if( f.hasVersion( version ) )
+                        {
+                            f.setDefaultVersion( f.getVersion( version ) );
+                            defaultVersionSpecified = true;
+                        }
+                        else
+                        {
+                            final String msg 
+                                = f.createVersionNotFoundErrMsg( version );
+                            
+                            FacetCorePlugin.log( msg );
+                        }
+                    }
+                    else
+                    {
+                        reportMissingAttribute( config, ATTR_VERSION );
+                    }
+                }
+            }
+        }
+        
+        if( ! defaultVersionSpecified )
+        {
+            try
+            {
+                f.setDefaultVersion( f.getLatestVersion() );
+            }
+            catch( Exception e )
+            {
+                FacetCorePlugin.log( e );
+            }
+        }
+    }
+    
     private void readAction( final IConfigurationElement config )
     {
         final String fid = config.getAttribute( ATTR_FACET );
@@ -1351,12 +1556,11 @@ public final class ProjectFacetsManagerImpl
             return;
         }
         
-        final String ver = config.getAttribute( ATTR_VERSION );
+        String ver = config.getAttribute( ATTR_VERSION );
 
         if( ver == null )
         {
-            reportMissingAttribute( config, ATTR_VERSION );
-            return;
+            ver = IVersionExpr.WILDCARD_SYMBOL;
         }
         
         readAction( config, f, ver );
@@ -1563,12 +1767,11 @@ public final class ProjectFacetsManagerImpl
             return;
         }
         
-        final String ver = config.getAttribute( ATTR_VERSION );
+        String ver = config.getAttribute( ATTR_VERSION );
 
         if( ver == null )
         {
-            reportMissingAttribute( config, ATTR_VERSION );
-            return;
+            ver = IVersionExpr.WILDCARD_SYMBOL;
         }
         
         readEventHandler( config, f, ver );
@@ -1721,20 +1924,19 @@ public final class ProjectFacetsManagerImpl
                 return null;
             }
 
-            final String vexprstr = root.getAttribute( ATTR_VERSION );
+            final IProjectFacet f = getProjectFacet( fid );
             
-            if( vexprstr == null )
+            String vexprstr = root.getAttribute( ATTR_VERSION );
+            
+            if( vexprstr == null || vexprstr.trim().length() == 0 )
             {
-                reportMissingAttribute( root, ATTR_VERSION );
-                return null;
+                vexprstr = IVersionExpr.WILDCARD_SYMBOL;
             }
-            
-            final IProjectFacet f;
+
             final VersionExpr vexpr;
-            
+
             try
             {
-                f = getProjectFacet( fid );
                 vexpr = new VersionExpr( f, vexprstr, pluginId );
             }
             catch( CoreException e )
@@ -1955,6 +2157,11 @@ public final class ProjectFacetsManagerImpl
             }
         }
         
+        if( preset.getLabel() == null )
+        {
+            preset.setLabel( preset.getId() );
+        }
+        
         if( preset.getDescription() == null )
         {
             preset.setDescription( "" ); //$NON-NLS-1$
@@ -2208,6 +2415,8 @@ public final class ProjectFacetsManagerImpl
         public static String invalidConflictsConstraint;
         public static String deprecatedRuntimeChangedAction;
         public static String tracingActionSorting;
+        public static String tracingFrameworkActivationStarting;
+        public static String tracingFrameworkActivationFinished;
         public static String unknownProperty;
         public static String propertyNotApplicable;
         
@@ -2235,4 +2444,4 @@ public final class ProjectFacetsManagerImpl
         }
     }
     
-}
+}
\ No newline at end of file
