@@ -687,18 +687,10 @@ public final class FacetsSelectionPanel
         {
             defaultFacets = new HashSet();
             
-            try
+            for( Iterator itr = this.fixed.iterator(); itr.hasNext(); )
             {
-                for( Iterator itr = this.fixed.iterator(); itr.hasNext(); )
-                {
-                    final IProjectFacet f = (IProjectFacet) itr.next();
-                    defaultFacets.add( f.getLatestVersion() );
-                }
-            }
-            catch( CoreException e )
-            {
-                FacetUiPlugin.log( e );
-                return;
+                final IProjectFacet f = (IProjectFacet) itr.next();
+                defaultFacets.add( f.getDefaultVersion() );
             }
         }
             
@@ -856,8 +848,6 @@ public final class FacetsSelectionPanel
         this.filters.add( this.conflictingFilter );
 
         refresh();
-        refreshPresetsCombo();
-        refreshVersionsDropDown();
         updateValidationDisplay();
     }
     
@@ -866,8 +856,6 @@ public final class FacetsSelectionPanel
         this.filters.add( filter );
         
         refresh();
-        refreshPresetsCombo();
-        refreshVersionsDropDown();
     }
 
     public void removeFilter( final IFilter filter )
@@ -875,10 +863,13 @@ public final class FacetsSelectionPanel
         this.filters.remove( filter );
         
         refresh();
-        refreshPresetsCombo();
-        refreshVersionsDropDown();
     }
-
+    
+    public boolean setFocus()
+    {
+        return this.tree.getTree().setFocus();
+    }
+    
     public void addProjectFacetsListener( final Listener listener )
     {
         this.listeners.add( listener );
@@ -1188,6 +1179,8 @@ public final class FacetsSelectionPanel
         final Object[] checked = this.tree.getCheckedElements();
         this.tree.refresh();
         this.tree.setCheckedElements( checked );
+        refreshPresetsCombo();
+        refreshVersionsDropDown();
     }
     
     public void syncWithPresetsModel( final Combo combo )
@@ -1726,7 +1719,7 @@ public final class FacetsSelectionPanel
         {
             this.f = f;
             this.versions = f.getSortedVersions( false );
-            this.current = f.getLatestVersion();
+            this.current = f.getDefaultVersion();
             this.isSelected = false;
             this.isFixed = false;
         }
