@@ -12,11 +12,10 @@ package org.eclipse.wst.rdb.internal.core.connection;
 
 import java.sql.Connection;
 import java.sql.Driver;
-import java.util.Properties;
 
-public class GenericConnectionFactory implements ConnectionFactory{
+public class GenericConnectionFactory implements ConnectionFactory2{
 
-	public Connection connect(Driver driver, ClassLoader loader, String url, Properties connectionProperties) throws Exception{
-		return driver.connect(url, connectionProperties);
+	public Connection connect(Driver driver, ClassLoader loader, ConnectionInfo info) throws Exception{
+		return driver.connect(info.getURL(), info.getProperties());
 	}
 }
