@@ -122,12 +122,12 @@ public final class GenericDdlGenerator implements DDLGenerator {
                 if(statement != null) script.addAlterTableAddConstraintStatement(statement);
             }
             else if(o instanceof UniqueConstraint) {
-            	if(!EngineeringOptionID.generatePKConstraints(options)) continue;
+            	if(!EngineeringOptionID.generatePKConstraints(options) || builder.isImplicitConstraint((UniqueConstraint)o)) continue;
                 String statement = builder.addUniqueConstraint((UniqueConstraint) o, quoteIdentifiers, qualifyNames);
                 if(statement != null) script.addAlterTableAddConstraintStatement(statement);
             }
             else if(o instanceof ForeignKey) {
-            	if(!EngineeringOptionID.generateFKConstraints(options)) continue;
+            	if(!EngineeringOptionID.generateFKConstraints(options) || builder.isImplicitConstraint((ForeignKey)o)) continue;
                 String statement = builder.addForeignKey((ForeignKey) o, quoteIdentifiers, qualifyNames);
                 if(statement != null) script.addAlterTableAddForeignKeyStatement(statement);
             }
@@ -171,12 +171,12 @@ public final class GenericDdlGenerator implements DDLGenerator {
                 if(statement != null) script.addAlterTableDropConstraintStatement(statement);
             }
             else if(o instanceof UniqueConstraint) {
-            	if(!EngineeringOptionID.generatePKConstraints(options)) continue;
+            	if(!EngineeringOptionID.generatePKConstraints(options) || builder.isImplicitConstraint((UniqueConstraint)o) ) continue;
                 String statement = builder.dropTableConstraint((UniqueConstraint) o, quoteIdentifiers, qualifyNames);
                 if(statement != null) script.addAlterTableDropConstraintStatement(statement);
             }
             else if(o instanceof ForeignKey) {
-            	if(!EngineeringOptionID.generateFKConstraints(options)) continue;
+            	if(!EngineeringOptionID.generateFKConstraints(options) || builder.isImplicitConstraint((ForeignKey)o)) continue;
                 String statement = builder.dropTableConstraint((ForeignKey) o, quoteIdentifiers, qualifyNames);
                 if(statement != null) script.addAlterTableDropForeignKeyStatement(statement);
             }
