@@ -167,7 +167,7 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 		
 		try {
 			DatabaseMetaData metaData = connection.getMetaData();
-			ResultSet r = metaData.getColumns(null, schema.getName(), table.getName(), null);
+			ResultSet r = metaData.getColumns(null, metaData.supportsSchemasInTableDefinitions()? null:schema.getName(), table.getName(), null);
 			while(r.next()) {
 				final String columnName = r.getString(4);
 
@@ -199,7 +199,7 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 					}
 					else if(typeDefinition.isPrecisionSupported()) {
 						EStructuralFeature feature = type.eClass().getEStructuralFeature("precision"); //$NON-NLS-1$
-						type.eSet(feature, new Integer(r.getInt(10)));
+						type.eSet(feature, new Integer(r.getInt(7)));
 					}
 					
 					if(typeDefinition.isScaleSupported()) {
@@ -241,7 +241,7 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 			final DataModelElementFactory factory = databaseDefinition.getDataModelElementFactory();
 			
 			DatabaseMetaData metaData = connection.getMetaData();
-			ResultSet r = metaData.getIndexInfo(null,schema.getName(),table.getName(),false,false);
+			ResultSet r = metaData.getIndexInfo(null,metaData.supportsSchemasInTableDefinitions()? null:schema.getName(),table.getName(),false,false);
 			Index index = null;
 			String indexName=""; //$NON-NLS-1$
 			while(r.next()) {
@@ -290,7 +290,7 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 	private synchronized JDBCPrimaryKey loadPrimaryKey(DatabaseMetaData metaData, EList constraintList){
 		JDBCPrimaryKey key = null;
 		try {
-			ResultSet r = metaData.getPrimaryKeys(null, this.getSchema().getName(),this.getName());
+			ResultSet r = metaData.getPrimaryKeys(null, metaData.supportsSchemasInTableDefinitions()? null:this.getSchema().getName(),this.getName());
 	
 			DataModelElementFactory factory = RDBCorePlugin.getDefault().getDatabaseDefinitionRegistry().getDefinition(this.getCatalogDatabase()).getDataModelElementFactory();
 
@@ -321,107 +321,9 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 		return key;
 	}
 	
-
-//	private synchronized void loadForeignKey(DatabaseMetaData metaData, UniqueConstraint uk){
-//		try {
-//			ResultSet r = metaData.getExportedKeys(null, this.getSchema().getName(),this.getName());
-//	
-//			DataModelElementFactory factory = RDBCorePlugin.getDefault().getDatabaseDefinitionRegistry().getDefinition(this.getCatalogDatabase()).getDataModelElementFactory();
-//			
-//			JDBCForeignKey fk = null;
-//			Table fkTable=null;
-//			String fkTableName=""; //$NON-NLS-1$
-//			while(r.next()) {
-//				final String fkSchema_Name= r.getString(6);
-//				final String fkTable_Name = r.getString(7);
-//				if(!fkTableName.equals(fkTable_Name)) {
-//					fkTable= this.getTable(fkSchema_Name,fkTable_Name);
-//					if (fkTable==null) continue;
-//					fkTableName = fkTable_Name;
-//					fk = new JDBCForeignKey();
-//					final String fkName = r.getString(12);
-//					fk.setName(fkName);
-//					fk.setUniqueConstraint(uk);
-//					short updateRule = r.getShort(10);
-//					switch(updateRule) {
-//						case DatabaseMetaData.importedKeyCascade:
-//							fk.setOnUpdate(ReferentialActionType.CASCADE_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeyRestrict:
-//							fk.setOnUpdate(ReferentialActionType.RESTRICT_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeySetDefault:
-//							fk.setOnUpdate(ReferentialActionType.SET_DEFAULT_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeySetNull:
-//							fk.setOnUpdate(ReferentialActionType.SET_NULL_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeyNoAction:
-//							default:
-//							fk.setOnUpdate(ReferentialActionType.NO_ACTION_LITERAL);
-//							break;
-//					}
-//					short deleteRule = r.getShort(11);
-//					switch(deleteRule) {
-//						case DatabaseMetaData.importedKeyCascade:
-//							fk.setOnDelete(ReferentialActionType.CASCADE_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeyRestrict:
-//							fk.setOnDelete(ReferentialActionType.RESTRICT_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeySetDefault:
-//							fk.setOnDelete(ReferentialActionType.SET_DEFAULT_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeySetNull:
-//							fk.setOnDelete(ReferentialActionType.SET_NULL_LITERAL);
-//							break;
-//						case DatabaseMetaData.importedKeyNoAction:
-//							default:
-//							fk.setOnDelete(ReferentialActionType.NO_ACTION_LITERAL);
-//							break;
-//					}
-//					short deferrability = r.getShort(14);
-//					switch(deferrability) {
-//						case DatabaseMetaData.importedKeyInitiallyDeferred:
-//							fk.setDeferrable(true);
-//							fk.setInitiallyDeferred(true);
-//							break;
-//						case DatabaseMetaData.importedKeyInitiallyImmediate:
-//							fk.setDeferrable(true);
-//							fk.setInitiallyDeferred(false);
-//							break;
-//						case DatabaseMetaData.importedKeyNotDeferrable:
-//						default:
-//							fk.setDeferrable(false);
-//							break;
-//					}
-//					((BaseTable)fkTable).getConstraints().add(fk);
-//				}
-//				
-//				String columnName = r.getString(8);
-//				Column column = JDBCTable.getColumn(fkTable,columnName);
-//				fk.getMembers().add(column);
-//				/* Add EAnnotation */
-//				EList tmpList = fk.getMembers();
-//				boolean isIdentify = fk.isIdentifyingRelationship(tmpList);
-//				EAnnotation eAnnotation = fk.addEAnnotation(RDBCorePlugin.FK_MODELING_RELATIONSHIP);
-//				fk.addEAnnotationDetail(eAnnotation,RDBCorePlugin.FK_IS_IDENTIFYING_RELATIONSHIP,new Boolean(isIdentify).toString());
-//
-//				fk.addEAnnotationDetail(eAnnotation, RDBCorePlugin.FK_CHILD_MULTIPLICITY, RDBCorePlugin.MANY);
-//				fk.addEAnnotationDetail(eAnnotation, RDBCorePlugin.FK_CHILD_ROLE_NAME, new String ());
-//				fk.addEAnnotationDetail(eAnnotation, RDBCorePlugin.FK_PARENT_MULTIPLICITY, (fk.getMembers().size() > 0) ? RDBCorePlugin.ZERO_TO_ONE : RDBCorePlugin.ONE);
-//				fk.addEAnnotationDetail(eAnnotation, RDBCorePlugin.FK_PARENT_ROLE_NAME, new String ());
-//			}
-//			r.close();
-//		}catch (Exception e){
-//			e.printStackTrace();
-//		}
-//	}
-	
-	
 	private synchronized void loadForeignKey(DatabaseMetaData metaData, EList constraintList){
 		try {
-			ResultSet r = metaData.getImportedKeys(null, this.getSchema().getName(),this.getName());
+			ResultSet r = metaData.getImportedKeys(null, metaData.supportsSchemasInTableDefinitions()? null:this.getSchema().getName(),this.getName());
 	
 			DataModelElementFactory factory = RDBCorePlugin.getDefault().getDatabaseDefinitionRegistry().getDefinition(this.getCatalogDatabase()).getDataModelElementFactory();
 			
@@ -531,7 +433,7 @@ public class JDBCTable extends PersistentTableImpl implements ICatalogObject {
 	
 	private static Schema getSchema(Table table, String schemaName) {
 		Schema s = table.getSchema();
-		if(s.getName().equals(schemaName)) return s;
+		if(schemaName == null | s.getName().equals(schemaName)) return s;
 		Database d = s.getDatabase();
 		Iterator it = d.getSchemas().iterator();
 		while(it.hasNext()) {
