@@ -60,6 +60,7 @@ import org.eclipse.emf.ecore.EObject;
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseVendorDefinition#isQuotedDDLSupported <em>Quoted DDL Supported</em>}</li>
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseVendorDefinition#isXmlSupported <em>Xml Supported</em>}</li>
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseVendorDefinition#isMQTIndexSupported <em>MQT Index Supported</em>}</li>
+ *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseVendorDefinition#isPackageSupported <em>Package Supported</em>}</li>
  * </ul>
  * </p>
  *
@@ -672,6 +673,33 @@ public interface DatabaseVendorDefinition extends EObject{
 	 */
 	void setMQTIndexSupported(boolean value);
 
+	/**
+	 * Returns the value of the '<em><b>Package Supported</b></em>' attribute.
+	 * The default value is <code>"false"</code>.
+	 * <!-- begin-user-doc -->
+	 * <p>
+	 * If the meaning of the '<em>Package Supported</em>' attribute isn't clear,
+	 * there really should be more of a description here...
+	 * </p>
+	 * <!-- end-user-doc -->
+	 * @return the value of the '<em>Package Supported</em>' attribute.
+	 * @see #setPackageSupported(boolean)
+	 * @see org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseDefinitionPackage#getDatabaseVendorDefinition_PackageSupported()
+	 * @model default="false"
+	 * @generated
+	 */
+	boolean isPackageSupported();
+
+	/**
+	 * Sets the value of the '{@link org.eclipse.wst.rdb.internal.models.dbdefinition.DatabaseVendorDefinition#isPackageSupported <em>Package Supported</em>}' attribute.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @param value the new value of the '<em>Package Supported</em>' attribute.
+	 * @see #isPackageSupported()
+	 * @generated
+	 */
+	void setPackageSupported(boolean value);
+
 	/**
 	 * Returns the value of the '<em><b>Predefined Data Type Definitions</b></em>' containment reference list.
 	 * The list contents are of type {@link org.eclipse.wst.rdb.internal.models.dbdefinition.PredefinedDataTypeDefinition}.
