@@ -88,6 +88,7 @@ import org.eclipse.wst.rdb.internal.models.dbdefinition.ViewDefinition;
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.impl.DatabaseVendorDefinitionImpl#isQuotedDDLSupported <em>Quoted DDL Supported</em>}</li>
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.impl.DatabaseVendorDefinitionImpl#isXmlSupported <em>Xml Supported</em>}</li>
  *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.impl.DatabaseVendorDefinitionImpl#isMQTIndexSupported <em>MQT Index Supported</em>}</li>
+ *   <li>{@link org.eclipse.wst.rdb.internal.models.dbdefinition.impl.DatabaseVendorDefinitionImpl#isPackageSupported <em>Package Supported</em>}</li>
  * </ul>
  * </p>
  *
@@ -714,6 +715,26 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 	 */
 	protected boolean mQTIndexSupported = MQT_INDEX_SUPPORTED_EDEFAULT;
 
+	/**
+	 * The default value of the '{@link #isPackageSupported() <em>Package Supported</em>}' attribute.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @see #isPackageSupported()
+	 * @generated
+	 * @ordered
+	 */
+	protected static final boolean PACKAGE_SUPPORTED_EDEFAULT = false;
+
+	/**
+	 * The cached value of the '{@link #isPackageSupported() <em>Package Supported</em>}' attribute.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @see #isPackageSupported()
+	 * @generated
+	 * @ordered
+	 */
+	protected boolean packageSupported = PACKAGE_SUPPORTED_EDEFAULT;
+
 	/**
 	 * <!-- begin-user-doc -->
 	 * <!-- end-user-doc -->
@@ -1215,6 +1236,27 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 			eNotify(new ENotificationImpl(this, Notification.SET, DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__MQT_INDEX_SUPPORTED, oldMQTIndexSupported, mQTIndexSupported));
 	}
 
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public boolean isPackageSupported() {
+		return packageSupported;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public void setPackageSupported(boolean newPackageSupported) {
+		boolean oldPackageSupported = packageSupported;
+		packageSupported = newPackageSupported;
+		if (eNotificationRequired())
+			eNotify(new ENotificationImpl(this, Notification.SET, DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__PACKAGE_SUPPORTED, oldPackageSupported, packageSupported));
+	}
+
 	/**
 	 * <!-- begin-user-doc -->
 	 * <!-- end-user-doc -->
@@ -1973,6 +2015,8 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 				return isXmlSupported() ? Boolean.TRUE : Boolean.FALSE;
 			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__MQT_INDEX_SUPPORTED:
 				return isMQTIndexSupported() ? Boolean.TRUE : Boolean.FALSE;
+			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__PACKAGE_SUPPORTED:
+				return isPackageSupported() ? Boolean.TRUE : Boolean.FALSE;
 		}
 		return eDynamicGet(eFeature, resolve);
 	}
@@ -2103,6 +2147,9 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__MQT_INDEX_SUPPORTED:
 				setMQTIndexSupported(((Boolean)newValue).booleanValue());
 				return;
+			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__PACKAGE_SUPPORTED:
+				setPackageSupported(((Boolean)newValue).booleanValue());
+				return;
 		}
 		eDynamicSet(eFeature, newValue);
 	}
@@ -2231,6 +2278,9 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__MQT_INDEX_SUPPORTED:
 				setMQTIndexSupported(MQT_INDEX_SUPPORTED_EDEFAULT);
 				return;
+			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__PACKAGE_SUPPORTED:
+				setPackageSupported(PACKAGE_SUPPORTED_EDEFAULT);
+				return;
 		}
 		eDynamicUnset(eFeature);
 	}
@@ -2320,6 +2370,8 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 				return xmlSupported != XML_SUPPORTED_EDEFAULT;
 			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__MQT_INDEX_SUPPORTED:
 				return mQTIndexSupported != MQT_INDEX_SUPPORTED_EDEFAULT;
+			case DatabaseDefinitionPackage.DATABASE_VENDOR_DEFINITION__PACKAGE_SUPPORTED:
+				return packageSupported != PACKAGE_SUPPORTED_EDEFAULT;
 		}
 		return eDynamicIsSet(eFeature);
 	}
@@ -2379,6 +2431,8 @@ public class DatabaseVendorDefinitionImpl extends EObjectImpl implements Databas
 		result.append(xmlSupported);
 		result.append(", mQTIndexSupported: "); //$NON-NLS-1$
 		result.append(mQTIndexSupported);
+		result.append(", packageSupported: "); //$NON-NLS-1$
+		result.append(packageSupported);
 		result.append(')');
 		return result.toString();
 	}
