@@ -35,15 +35,20 @@ public class ServerUtil {
 	}
 
 	/**
-	 * Returns the project modules attached to a project.
+	 * Returns the module contained within the given project. If more than one module
+	 * is contained with the project, this method will return an arbitrary module
+	 * unless the module factory defines an ordering. If there might be multiple
+	 * modules in a project, users should typically use getModules(IProject) instead.
 	 * 
 	 * @param project a project
-	 * @return a possibly empty array of modules
+	 * @return a module that is contained with the project, or null if no
+	 *    modules are contained in the given project
+	 * @see #getModules(IProject)
 	 */
 	public static IModule getModule(IProject project) {
 		if (project == null)
 			throw new IllegalArgumentException();
-
+		
 		IModule[] modules = getModules();
 		if (modules != null) {
 			int size = modules.length;
@@ -55,6 +60,31 @@ public class ServerUtil {
 		return null;
 	}
 
+	/**
+	 * Returns the modules contained within the given project.
+	 * 
+	 * @param project a project
+	 * @return a possibly-empty array of modules
+	 * @see #getModule(IProject)
+	 */
+	public static IModule[] getModules(IProject project) {
+		if (project == null)
+			throw new IllegalArgumentException();
+		
+		IModule[] modules = getModules();
+		List list = new ArrayList();
+		if (modules != null) {
+			int size = modules.length;
+			for (int i = 0; i < size; i++) {
+				if (modules[i] != null && project.equals(modules[i].getProject()))
+					list.add(modules[i]);
+			}
+		}
+		IModule[] modules2 = new IModule[list.size()];
+		list.toArray(modules2);
+		return modules2;
+	}
+
 	/**
 	 * Returns a module from the given moduleId. The moduleId must not be null.
 	 * 
@@ -109,7 +139,7 @@ public class ServerUtil {
 		list.toArray(modules);
 		return modules;
 	}
-	
+
 	/**
 	 * Return all the available modules from all factories whose
 	 * type matches the given module type id.
@@ -139,18 +169,23 @@ public class ServerUtil {
 		list.toArray(modules);
 		return modules;
 	}
-	
+
 	/**
 	 * Returns <code>true</code> if any of the given moduleTypes have the given
 	 * module type id and version id.
 	 * 
 	 * @param moduleTypes an array of module types
-	 * @param typeId a module type
-	 * @param versionId a module version
+	 * @param typeId a module type id, or null for any module type
+	 * @param versionId a module version, or null for any version
 	 * @return <code>true</code> if the module type is supported, and
 	 *    <code>false</code> otherwise
 	 */
 	public static boolean isSupportedModule(IModuleType[] moduleTypes, String typeId, String versionId) {
+		if ("".equals(typeId))
+			typeId = null;
+		if ("".equals(versionId))
+			versionId = null;
+		
 		if (moduleTypes != null) {
 			int size = moduleTypes.length;
 			for (int i = 0; i < size; i++) {
@@ -177,11 +212,14 @@ public class ServerUtil {
 	 * module type.
 	 * 
 	 * @param moduleTypes an array of modules types
-	 * @param mt a module type
+	 * @param mt a module type, may not be null
 	 * @return <code>true</code> if the module type is supported, and
 	 *    <code>false</code> otherwise
 	 */
 	public static boolean isSupportedModule(IModuleType[] moduleTypes, IModuleType mt) {
+		if (mt == null)
+			throw new IllegalArgumentException();
+		
 		if (moduleTypes != null) {
 			int size = moduleTypes.length;
 			for (int i = 0; i < size; i++) {
@@ -291,15 +329,12 @@ public class ServerUtil {
 			boolean found = false;
 			try {
 				IModule[] parents = server.getRootModules(add[i], monitor);
-				if (parents != null) {
+				if (parents != null && parents.length > 0) {				
+					Object parent = parents[0];
 					found = true;
-					if (parents.length > 0) {				
-						Object parent = parents[0];
-						found = true;
-						if (!addParentModules.contains(parent))
-							addParentModules.add(parent);
-					}
-				} 
+					if (!addParentModules.contains(parent))
+						addParentModules.add(parent);
+				}
 			} catch (Exception e) {
 				Trace.trace(Trace.WARNING, "Could not find parent module", e);
 			}
@@ -314,15 +349,12 @@ public class ServerUtil {
 			boolean found = false;
 			try {
 				IModule[] parents = server.getRootModules(remove[i], monitor);
-				if (parents != null) {
+				if (parents != null && parents.length > 0) {				
+					Object parent = parents[0];
 					found = true;
-					if (parents.length > 0) {				
-						Object parent = parents[0];
-						found = true;
-						if (!removeParentModules.contains(parent))
-							removeParentModules.add(parent);
-					}
-				} 
+					if (!removeParentModules.contains(parent))
+						removeParentModules.add(parent);
+				}
 			} catch (Exception e) {
 				Trace.trace(Trace.WARNING, "Could not find parent module 2", e);
 			}
@@ -692,22 +724,19 @@ public class ServerUtil {
 			return false;
 		Trace.trace(Trace.FINEST, "containsModule() " + server + " " + module);
 		
-		class Helper {
-			boolean b;
-		}
-		final Helper h = new Helper();
-
+		final boolean[] b = new boolean[1];
+		
 		((Server)server).visit(new IModuleVisitor() {
 			public boolean visit(IModule[] modules) {
 				int size = modules.length;
 				if (modules[size - 1].equals(module)) {
-					h.b = true;
+					b[0] = true;
 					return false;
 				}
 				return true;
 			}
 		}, null);
-		return h.b;
+		return b[0];
 	}
 
 	/**
