@@ -182,7 +182,7 @@ public class ServerPlugin extends Plugin {
 			Trace.trace(Trace.WARNING, "Could not remove temp directory", e);
 		}
 	}
-	
+
 	/**
 	 * Load the temporary directory information.
 	 */
@@ -190,25 +190,25 @@ public class ServerPlugin extends Plugin {
 		Trace.trace(Trace.FINEST, "Loading temporary directory information");
 		IPath statePath = ServerPlugin.getInstance().getStateLocation();
 		String filename = statePath.append(TEMP_DATA_FILE).toOSString();
-	
+		
 		tempDirHash = new HashMap();
 		try {
 			IMemento memento = XMLMemento.loadMemento(filename);
-	
+			
 			IMemento[] children = memento.getChildren("temp-directory");
 			int size = children.length;
 			for (int i = 0; i < size; i++) {
 				String key = children[i].getString("key");
-	
+				
 				TempDir d = new TempDir();
 				d.path = children[i].getString("path");
 				d.age = children[i].getInteger("age").intValue();
 				d.age++;
-	
+				
 				tempDirHash.put(key, d);
 			}
 		} catch (Exception e) {
-			Trace.trace(Trace.SEVERE, "Could not load temporary directory information: " + e.getMessage());
+			Trace.trace(Trace.WARNING, "Could not load temporary directory information: " + e.getMessage());
 		}
 	}
 
@@ -795,8 +795,20 @@ public class ServerPlugin extends Plugin {
 			for (int i = 0; i < size; i++) {
 				try {
 					if (adapters[i].isEnabled(obj)) {
-						Trace.trace(Trace.FINER, "Run On Server for " + obj + " is enabled by " + adapters[i].getId());
-						return true;
+						Trace.trace(Trace.FINER, "ServerPlugin.hasModuleArtifact() - " + adapters[i].getId());
+						if (adapters[i].isDelegateLoaded()) {
+							long time = System.currentTimeMillis();
+							IModuleArtifact ma = adapters[i].getModuleArtifact(obj);
+							Trace.trace(Trace.FINER, "Deep enabled time: " + (System.currentTimeMillis() - time));
+							if (ma != null) {
+								Trace.trace(Trace.FINER, "Deep enabled");
+								return true;
+							}
+							Trace.trace(Trace.FINER, "Not enabled");
+						} else {
+							Trace.trace(Trace.FINER, "Enabled");
+							return true;
+						}
 					}
 				} catch (CoreException ce) {
 					Trace.trace(Trace.WARNING, "Could not use moduleArtifactAdapter", ce);
