@@ -12,14 +12,12 @@ package org.eclipse.wst.validation.internal;
 
 
 import java.text.MessageFormat;
-import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
-import java.util.List;
 import java.util.Set;
 import java.util.StringTokenizer;
 import java.util.logging.Level;
@@ -43,6 +41,7 @@ import org.eclipse.wst.common.project.facet.core.IFacetedProject;
 import org.eclipse.wst.common.project.facet.core.IProjectFacet;
 import org.eclipse.wst.common.project.facet.core.IProjectFacetVersion;
 import org.eclipse.wst.common.project.facet.core.ProjectFacetsManager;
+import org.eclipse.wst.validation.internal.delegates.ValidatorDelegatesRegistry;
 import org.eclipse.wst.validation.internal.operations.IRuleGroup;
 import org.eclipse.wst.validation.internal.operations.IWorkbenchContext;
 import org.eclipse.wst.validation.internal.plugin.ValidationPlugin;
@@ -89,8 +88,6 @@ public final class ValidationRegistryReader implements RegistryConstants {
 
 	private static final String UNKNOWN_PROJECT = "UNKNOWN"; //$NON-NLS-1$ // This 'project nature id' is used as a key to get the validators which can run on a project type which hasn't been explicitly filtered in or out by any validator.
 	private static final String EXCLUDED_PROJECT = "EXCLUDED"; //$NON-NLS-1$ // This 'project nature id' is used as a key to get the validators which are excluded on certain projects.
-
-	private List _tempList = null; // list for temporary values. Retrieve and use via the
 	
 	public HashMap projectValidationMetaData = null;
 
@@ -889,7 +886,33 @@ public final class ValidationRegistryReader implements RegistryConstants {
 			Set projVmds = null;
 			if ((projectNatures == null) || (projectNatures.length == 0)) {
 				executionMap |= 0x4;
-				clone(getValidatorMetaDataUnknownProject(), vmds);
+				
+				// Also include the validators which are enabled through enablement
+				// expression for this project.
+				// Note that the API isFacetEnabled(vmd, project) works properly 
+				// only when the plugin containing the property tester is activated.
+				// forcePluginActivation="true" may be needed in the declaration of 
+				// the enablement in the validator extension point.
+		        // <enablement>
+		        //  <test forcePluginActivation="true" property="foo.testProperty"/>
+		        // </enablement> 
+				
+				Set validatorsWithEnablementExpression = new HashSet();
+				Iterator allValidators = getAllValidators().iterator();
+				while (allValidators.hasNext()) {
+					ValidatorMetaData vmd = (ValidatorMetaData) allValidators.next();
+					if (isFacetEnabled(vmd, project)) {
+						validatorsWithEnablementExpression.add(vmd);
+					}
+				}
+				if(validatorsWithEnablementExpression.size() > 0 ){
+					validatorsWithEnablementExpression.addAll( getValidatorMetaDataUnknownProject());
+					clone(validatorsWithEnablementExpression, vmds);
+				}
+				else
+					clone(getValidatorMetaDataUnknownProject(), vmds);
+
+
 			} else {
 				executionMap |= 0x8;
 				if (logger.isLoggingLevel(Level.FINEST)) {
@@ -982,7 +1005,6 @@ public final class ValidationRegistryReader implements RegistryConstants {
 				return result == EvaluationResult.TRUE;
 			}
 		} catch (CoreException ce) {
-			Logger.getLogger().log(ce);
 		}
 		return false;
 	}
@@ -1000,7 +1022,6 @@ public final class ValidationRegistryReader implements RegistryConstants {
 				return projectFacetIds;
 			}
 		} catch (CoreException ce) {
-			Logger.getLogger().log(ce);
 		}
 
 		return null;
@@ -1048,16 +1069,9 @@ public final class ValidationRegistryReader implements RegistryConstants {
 			// nothing needs to be removed from the list
 			return;
 		}
-
-		// First of all, clone the Set because we need to remove entries
-		// from it, and we can't alter the set while we're iterating over
-		// it.
-		List tempList = getTempList();
-		clone(vmds, tempList);
-
 		for (int i = 0; i < projectNatures.length; i++) {
 			String nature = projectNatures[i];
-			Iterator iterator = tempList.iterator();
+			Iterator iterator = vmds.iterator();
 			while (iterator.hasNext()) {
 				ValidatorMetaData vmd = (ValidatorMetaData) iterator.next();
 				ValidatorNameFilter[] natureFilters = vmd.getProjectNatureFilters();
@@ -1069,7 +1083,8 @@ public final class ValidationRegistryReader implements RegistryConstants {
 				for (int j = 0; j < natureFilters.length; j++) {
 					ValidatorNameFilter pn = natureFilters[j];
 					if (nature.equals(pn.getNameFilter()) && !pn.isInclude()) {
-						vmds.remove(vmd);
+						iterator.remove();
+						break;
 					}
 				}
 			}
@@ -1415,18 +1430,6 @@ public final class ValidationRegistryReader implements RegistryConstants {
 		return null;
 	}
 
-	private List getTempList() {
-		// Return a list for temporary use
-		if (_tempList == null) {
-			_tempList = new ArrayList();
-		} else {
-			// Prepare list for use
-			_tempList.clear();
-		}
-
-		return _tempList;
-	}
-
 	/**
 	 * This method should be called ONLY BY THE VALIDATION FRAMEWORK! The value from this method is
 	 * used to populate the validation preference page.
@@ -1497,6 +1500,12 @@ public final class ValidationRegistryReader implements RegistryConstants {
 		for (int i = 0; i < extensions.length; i++) {
 			readExtension(extensions[i]);
 		}
+    
+    // Force the delegate validators registry to be read early to avoid
+    // the non-synchronized singleton issue which occurs when two delegating
+    // validators race to load the registry.
+    
+    ValidatorDelegatesRegistry.getInstance();
 	}
 
 	public IValidator getValidator(String validatorClassName) throws InstantiationException {
