@@ -17,6 +17,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.logging.Level;
@@ -32,6 +33,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.jem.util.logger.LogEntry;
 import org.eclipse.jem.util.logger.proxy.Logger;
 import org.eclipse.wst.validation.internal.ConfigurationManager;
+import org.eclipse.wst.validation.internal.GlobalConfiguration;
 import org.eclipse.wst.validation.internal.InternalValidatorManager;
 import org.eclipse.wst.validation.internal.ProjectConfiguration;
 import org.eclipse.wst.validation.internal.TaskListUtility;
@@ -64,6 +66,7 @@ public final class ValidatorManager {
 	private static Class _messageLimitOwner = null;
 	private String[] _internalOwners = null;
 	private Map validatorMsgs = Collections.synchronizedMap( new HashMap() );	
+	private Set problemValidators = new HashSet();	
 	
 	/**
 	 * ValidatorManager constructor comment.
@@ -588,8 +591,12 @@ public final class ValidatorManager {
 	 */
 	protected Set getEnabledValidators(IProject project) {
 		try {
+			ValidatorMetaData[] vmds = null;
 			ProjectConfiguration prjp = ConfigurationManager.getManager().getProjectConfiguration(project);
-			ValidatorMetaData[] vmds = prjp.getEnabledValidators();
+			if(!prjp.useGlobalPreference()) 
+			   vmds = prjp.getEnabledValidators();
+			else
+			   vmds = getStateOfProjectLevelValidatorsFromGlobal(prjp);
 			return InternalValidatorManager.wrapInSet(vmds);
 		} catch (InvocationTargetException exc) {
 			Logger logger = ValidationPlugin.getPlugin().getMsgLogger();
@@ -608,6 +615,29 @@ public final class ValidatorManager {
 		}
 	}
 
+	private ValidatorMetaData[] getStateOfProjectLevelValidatorsFromGlobal(ProjectConfiguration prjp) throws InvocationTargetException {
+		List enabledGlobalValidatorsForProject = new ArrayList();
+		GlobalConfiguration gf = ConfigurationManager.getManager().getGlobalConfiguration();
+		List allProjectValidator = getAllValidatorUniqueNames(prjp.getValidators());
+		ValidatorMetaData[] vmd = gf.getBuildEnabledValidators();
+		for(int i = 0; i < vmd.length; i++) {
+			if(allProjectValidator.contains(vmd[i].getValidatorUniqueName())) {
+				enabledGlobalValidatorsForProject.add(vmd[i]);
+			}
+	   }
+		return (ValidatorMetaData[]) enabledGlobalValidatorsForProject.toArray(new ValidatorMetaData[enabledGlobalValidatorsForProject.size()]);
+	}
+	
+	private List getAllValidatorUniqueNames(ValidatorMetaData[] metaData) {
+		List names = new ArrayList();
+		for(int i = 0; i < metaData.length; i++) {
+			names.add(metaData[i].getValidatorUniqueName());
+		}
+		return names;
+	}
+	
+	
+
 	protected Set getManualEnabledValidators(IProject project) {
 		try {
 			ProjectConfiguration prjp = ConfigurationManager.getManager().getProjectConfiguration(project);
@@ -1125,5 +1155,11 @@ public final class ValidatorManager {
 			list.clear();
 		}
 		validatorMsgs.remove( validator );
-	}	
+	}
+
+	
+	public Set getProblemValidators() {
+		return problemValidators;
+	}
+	
 }
