@@ -24,6 +24,7 @@ import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
+import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.SubProgressMonitor;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.viewers.IStructuredSelection;
@@ -48,6 +49,7 @@ import org.eclipse.wst.common.frameworks.internal.datamodel.DataModelPausibleOpe
 import org.eclipse.wst.common.frameworks.internal.datamodel.ui.DataModelWizardPage;
 import org.eclipse.wst.common.project.facet.core.IFacetedProject;
 import org.eclipse.wst.common.project.facet.core.IFacetedProjectTemplate;
+import org.eclipse.wst.common.project.facet.core.IPreset;
 import org.eclipse.wst.common.project.facet.core.IProjectFacetVersion;
 import org.eclipse.wst.common.project.facet.core.IFacetedProject.Action.Type;
 import org.eclipse.wst.common.project.facet.core.runtime.IRuntime;
@@ -115,41 +117,91 @@ public abstract class NewProjectDataModelFacetWizard extends AddRemoveFacetsWiza
 		}
 
 		super.addPages();
-		final Set fixed = this.template.getFixedProjectFacets();
 
-		this.facetsSelectionPage.setFixedProjectFacets(fixed);
+        final Set fixed = this.template.getFixedProjectFacets();
 
-		this.facetsSelectionPage.addSelectedFacetsChangedListener(new Listener() {
-			public void handleEvent(Event event) {
-				facetSelectionChangedEvent(event);
-			}
-		});
+        this.facetsSelectionPage.setFixedProjectFacets(fixed);
 
-		IRuntime runtime = (IRuntime) model.getProperty(FACET_RUNTIME);
-        setRuntimeAndDefaultFacets( runtime );
-        
-		synchRuntimes();
-	}
+        this.facetsSelectionPage.addSelectedFacetsChangedListener(new Listener() {
+            public void handleEvent(Event event) {
+                facetSelectionChangedEvent(event);
+            }
+        });
+    }
 
 	public void createPageControls(Composite container) {
 		super.createPageControls(container);
-		/*
-		 * This does not interfere with the rutines selection
-		 */
+
+        final IPreset preset = this.template.getInitialPreset();
+        final IRuntime runtime = (IRuntime) model.getProperty( FACET_RUNTIME );
+
+        if( preset == null )
+        {
+            // If no preset is specified, select the runtime and it's default
+            // facets.
+            
+            setRuntimeAndDefaultFacets( runtime );
+        }
+        else
+        {
+            // If preset is specified, select the runtime only if supports all
+            // of the facets included in the preset.
+
+            this.facetsSelectionPage.panel.selectPreset( preset );
+            
+            boolean supports = false;
+            
+            if( runtime != null )
+            {
+                supports = true;
+                
+                for( Iterator itr = preset.getProjectFacets().iterator(); itr.hasNext(); )
+                {
+                    final IProjectFacetVersion fv = (IProjectFacetVersion) itr.next();
+                    
+                    if( ! runtime.supports( fv ) )
+                    {
+                        supports = false;
+                        break;
+                    }
+                }
+            }
+            
+            final ChangeTargetedRuntimesDataModel rdm
+                = getModel().getTargetedRuntimesDataModel();
+
+            if( supports )
+            {
+                rdm.setTargetedRuntimes( Collections.singleton( runtime ) );
+            }
+            else
+            {
+                model.setProperty( FACET_RUNTIME, null );
+            }
+        }
+        
+        synchRuntimes();
+        
+        facetsSelectionPage.setInitialSelection(getFacetsFromDataModel());
+       
+	}
+
+	protected Set getFacetsFromDataModel() {
 		Set facetVersions = new HashSet();
 		FacetDataModelMap map = (FacetDataModelMap) model.getProperty(FACET_DM_MAP);
 		for (Iterator iterator = map.values().iterator(); iterator.hasNext();) {
 			IDataModel facetModel = (IDataModel) iterator.next();
-			facetVersions.add(facetModel.getProperty(IFacetDataModelProperties.FACET_VERSION));
+			if(facetModel.getBooleanProperty(IFacetDataModelProperties.SHOULD_EXECUTE)){
+				facetVersions.add(facetModel.getProperty(IFacetDataModelProperties.FACET_VERSION));
+			}
 		}
 		
 		FacetActionMap mapAction = (FacetActionMap) model.getProperty(FACET_ACTION_MAP);
-        for (Iterator iterator = mapAction.values().iterator(); iterator.hasNext();) {
-            IFacetedProject.Action action = (IFacetedProject.Action) iterator.next();            
-            facetVersions.add(action.getProjectFacetVersion());
-        }
-        
-		facetsSelectionPage.setInitialSelection(facetVersions);
+		for (Iterator iterator = mapAction.values().iterator(); iterator.hasNext();) {
+		    IFacetedProject.Action action = (IFacetedProject.Action) iterator.next();            
+		    facetVersions.add(action.getProjectFacetVersion());
+		}
+		return facetVersions;
 	}
 
 	
@@ -204,7 +256,7 @@ public abstract class NewProjectDataModelFacetWizard extends AddRemoveFacetsWiza
         );
 	}
     
-    private void setRuntimeAndDefaultFacets( final IRuntime runtime )
+    protected void setRuntimeAndDefaultFacets( final IRuntime runtime )
     {
         final ChangeTargetedRuntimesDataModel rdm
             = getModel().getTargetedRuntimesDataModel();
@@ -237,7 +289,16 @@ public abstract class NewProjectDataModelFacetWizard extends AddRemoveFacetsWiza
 
 			final Set fixed = this.template.getFixedProjectFacets();
 			this.fproj.setFixedProjectFacets(fixed);
-		} finally {
+
+            try {
+                getFacetProjectNotificationOperation().execute(new NullProgressMonitor(), null);
+            } catch (ExecutionException e) {
+                String msg = e.getMessage();
+                if( msg == null ) msg = ""; //$NON-NLS-1$
+                final IStatus st = new Status( IStatus.ERROR, WSTWebUIPlugin.PLUGIN_ID, 0, msg, e );
+                throw new CoreException( st );
+            }
+        } finally {
 			monitor.done();
 		}
 	}
@@ -354,11 +415,6 @@ public abstract class NewProjectDataModelFacetWizard extends AddRemoveFacetsWiza
 
 		String projName = getProjectName();
 		BasicNewResourceWizard.selectAndReveal(ResourcesPlugin.getWorkspace().getRoot().getProject(projName), WSTWebUIPlugin.getDefault().getWorkbench().getActiveWorkbenchWindow());
-		try {
-			getFacetProjectNotificationOperation().execute(new NullProgressMonitor(), null);
-		} catch (ExecutionException e) {
-			throw new InvocationTargetException(e);
-		}
 	}
 
 	protected IDataModelOperation getFacetProjectNotificationOperation() {
