@@ -11,17 +11,21 @@
 package org.eclipse.wst.wsdl.ui.internal;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
-
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.emf.common.notify.Adapter;
 import org.eclipse.emf.common.notify.Notifier;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
+import org.eclipse.gef.EditPartFactory;
+import org.eclipse.gef.KeyStroke;
 import org.eclipse.gef.ui.actions.ActionRegistry;
+import org.eclipse.gef.ui.actions.GEFActionConstants;
 import org.eclipse.jface.text.IDocument;
+import org.eclipse.jface.viewers.IContentProvider;
 import org.eclipse.jface.viewers.IPostSelectionProvider;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
@@ -29,6 +33,8 @@ import org.eclipse.jface.viewers.ISelectionProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
+import org.eclipse.jface.viewers.TreeViewer;
+import org.eclipse.swt.SWT;
 import org.eclipse.ui.IEditorInput;
 import org.eclipse.ui.IFileEditorInput;
 import org.eclipse.wst.sse.core.StructuredModelManager;
@@ -36,6 +42,7 @@ import org.eclipse.wst.sse.core.internal.provisional.INodeNotifier;
 import org.eclipse.wst.sse.core.internal.provisional.IStructuredModel;
 import org.eclipse.wst.sse.core.internal.provisional.text.IStructuredDocument;
 import org.eclipse.wst.wsdl.Definition;
+import org.eclipse.wst.wsdl.XSDSchemaExtensibilityElement;
 import org.eclipse.wst.wsdl.ui.internal.actions.OpenInNewEditor;
 import org.eclipse.wst.wsdl.ui.internal.adapters.WSDLBaseAdapter;
 import org.eclipse.wst.wsdl.ui.internal.adapters.actions.W11AddPartAction;
@@ -50,9 +57,13 @@ import org.eclipse.wst.wsdl.ui.internal.adapters.basic.W11Description;
 import org.eclipse.wst.wsdl.ui.internal.adapters.basic.W11Type;
 import org.eclipse.wst.wsdl.ui.internal.asd.ASDMultiPageEditor;
 import org.eclipse.wst.wsdl.ui.internal.asd.actions.ASDAddMessageAction;
+import org.eclipse.wst.wsdl.ui.internal.asd.actions.ASDDirectEditAction;
 import org.eclipse.wst.wsdl.ui.internal.asd.actions.BaseSelectionAction;
+import org.eclipse.wst.wsdl.ui.internal.asd.design.DesignViewGraphicalViewer;
+import org.eclipse.wst.wsdl.ui.internal.asd.design.KeyboardDragImpl;
+import org.eclipse.wst.wsdl.ui.internal.asd.design.editparts.DefinitionsEditPart;
 import org.eclipse.wst.wsdl.ui.internal.asd.facade.IDescription;
-import org.eclipse.wst.wsdl.ui.internal.asd.util.ASDEditPartFactoryHelper;
+import org.eclipse.wst.wsdl.ui.internal.asd.outline.ASDContentOutlinePage;
 import org.eclipse.wst.wsdl.ui.internal.asd.util.IOpenExternalEditorHelper;
 import org.eclipse.wst.wsdl.ui.internal.edit.W11BindingReferenceEditManager;
 import org.eclipse.wst.wsdl.ui.internal.edit.W11InterfaceReferenceEditManager;
@@ -67,6 +78,10 @@ import org.eclipse.wst.wsdl.ui.internal.util.WSDLEditorUtil;
 import org.eclipse.wst.wsdl.ui.internal.util.WSDLResourceUtil;
 import org.eclipse.wst.xml.core.internal.provisional.document.IDOMModel;
 import org.eclipse.wst.xml.core.internal.provisional.document.IDOMNode;
+import org.eclipse.wst.xsd.ui.internal.adt.design.IKeyboardDrag;
+import org.eclipse.wst.xsd.ui.internal.adt.editor.EditorMode;
+import org.eclipse.wst.xsd.ui.internal.adt.editor.EditorModeManager;
+import org.eclipse.wst.xsd.ui.internal.adt.editor.ProductCustomizationProvider;
 import org.eclipse.wst.xsd.ui.internal.editor.XSDElementReferenceEditManager;
 import org.eclipse.wst.xsd.ui.internal.editor.XSDTypeReferenceEditManager;
 import org.eclipse.xsd.XSDSchema;
@@ -88,6 +103,7 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 	protected WSDLSelectionManagerSelectionListener fWSDLSelectionListener;
 
   private IStructuredModel structuredModel;
+  private final static String WSDL_EDITOR_MODE_EXTENSION_ID = "org.eclipse.wst.wsdl.ui.editorModes"; //$NON-NLS-N$  
   
   public IDescription buildModel(IFileEditorInput editorInput) {   
 	  try {
@@ -157,6 +173,10 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
         {
           return ((Adapter)model).getTarget(); 
         }
+		else if (type == IOpenExternalEditorHelper.class) {
+			return new W11OpenExternalEditorHelper(((IFileEditorInput) getEditorInput()).getFile());
+		}
+
         else if (type == XSDTypeReferenceEditManager.class)
         {
           IEditorInput editorInput = getEditorInput();
@@ -203,7 +223,13 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
             	return new W11MessageReferenceEditManager((W11Description) getModel(), fileEditorInput.getFile());
             }        	
         }
-		
+        else if (type == ProductCustomizationProvider.class)
+        {
+          return WSDLEditorPlugin.getInstance().getProductCustomizationProvider();
+        }
+        else if (type == IKeyboardDrag.class) {
+			return new KeyboardDragImpl();
+		}
 		return super.getAdapter(type);
 	}
 	
@@ -213,12 +239,12 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 	 */
 	private class SourceEditorSelectionListener implements ISelectionChangedListener {
 		/**
-		 * Determines WSDL node based on object (DOM node)
+		 * Determines WSDL facade object based on DOM node
 		 * 
 		 * @param object
 		 * @return
 		 */
-		private Object getWSDLNode(Object object) {
+		private Object getWSDLFacadeObject(Object object) {
 			// get the element node
 			Element element = null;
 			if (object instanceof Node) {
@@ -236,6 +262,15 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 			if (element != null) {
 				Definition def = (Definition) ((W11Description) model).getTarget();
 				Object modelObject = WSDLEditorUtil.getInstance().findModelObjectForElement(def, element);
+				
+				// rmah: We handle this special scenario where the modelObject is an XSDSchemaExtensibilityElement.
+				// We actually want the XSDSchema object.  However, our node reconciler will always return
+				// XSDSchemaExtensibilityElement because both XSDSchemaExtensibilityElement and XSDSchema
+				// both have the SAME Element object, and the reconciler encounters the XSDSchemaExtensibilityElement
+				// first....  See WSDLNodeNodeAssociationProvider for more details.....
+				if (modelObject instanceof XSDSchemaExtensibilityElement) {
+					modelObject = ((XSDSchemaExtensibilityElement) modelObject).getSchema();
+				}
 				if (modelObject != null) {
 					o = WSDLAdapterFactoryHelper.getInstance().adapt((Notifier) modelObject);
 				}
@@ -253,10 +288,10 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 					for (Iterator i = ((IStructuredSelection) selection).iterator(); i.hasNext();)
 					{
 						Object domNode = i.next();
-						Object node = getWSDLNode(domNode);
-						if (node != null)
+						Object facade = getWSDLFacadeObject(domNode);
+						if (facade != null)
 						{
-							selections.add(node);
+							selections.add(facade);
 						}
 					}
 					
@@ -340,7 +375,8 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 	
 	protected void configureGraphicalViewer() {
 		super.configureGraphicalViewer();
-		setEditPartFactory(ASDEditPartFactoryHelper.getInstance().getEditPartFactory());
+		graphicalViewer.getKeyHandler().put(KeyStroke.getPressed(SWT.F2, 0), getActionRegistry().getAction(GEFActionConstants.DIRECT_EDIT));
+		setEditPartFactory(getEditorModeManager().getCurrentMode().getEditPartFactory());
 	}
 	
 	protected void createPages() {
@@ -434,13 +470,93 @@ public class InternalWSDLMultiPageEditor extends ASDMultiPageEditor
 	    action = new W11OpenImportAction(this);
 	    action.setSelectionProvider(getSelectionManager());
 	    registry.registerAction(action);
-      
-      action = new OpenInNewEditor(this);
-      action.setSelectionProvider(getSelectionManager());
-      registry.registerAction(action);
+
+	    action = new OpenInNewEditor(this);
+	    action.setSelectionProvider(getSelectionManager());
+	    registry.registerAction(action);
+
+	    ASDDirectEditAction directEditAction = new ASDDirectEditAction(this);
+	    directEditAction.setSelectionProvider(getSelectionManager());
+	    registry.registerAction(directEditAction);
 	  }
 	
+  /*
+   * @deprecated: rmah: remove the method below post WTP1.5.  Use getAdapter() method instead.
+   */
   public IOpenExternalEditorHelper getOpenExternalEditorHelper() {
     return new W11OpenExternalEditorHelper(((IFileEditorInput) getEditorInput()).getFile());
   }
+  
+  private static final String DEFAULT_EDITOR_MODE_ID = "org.eclipse.wst.wsdl.ui.defaultEditorModeId"; //$NON-NLS-1$
+  
+  protected EditorModeManager createEditorModeManager()
+  {
+    final ProductCustomizationProvider productCustomizationProvider = (ProductCustomizationProvider)getAdapter(ProductCustomizationProvider.class);
+    EditorModeManager manager = new EditorModeManager(WSDL_EDITOR_MODE_EXTENSION_ID)
+    {
+      public void init()
+      {
+        if (productCustomizationProvider == null || 
+            productCustomizationProvider.isEditorModeApplicable(DefaultEditorMode.ID))
+        {          
+          addMode(new DefaultEditorMode());
+        }  
+        super.init();
+      }
+      
+      protected EditorMode getDefaultMode()
+      {
+        String defaultModeId = WSDLEditorPlugin.getInstance().getPreferenceStore().getString(DEFAULT_EDITOR_MODE_ID);
+        if (defaultModeId != null)
+        {
+          EditorMode editorMode = getEditorMode(defaultModeId);
+          if (editorMode != null)
+          {
+            return editorMode;
+          }  
+        }               
+        return super.getDefaultMode();
+      }      
+    };
+    manager.setProductCustomizationProvider(productCustomizationProvider);
+    return manager;
+  }
+  
+  public void editorModeChanged(EditorMode newEditorMode)
+  {
+    EditPartFactory editPartFactory = newEditorMode.getEditPartFactory();
+    if (editPartFactory != null)
+    {  
+      graphicalViewer.setEditPartFactory(editPartFactory);
+      if (graphicalViewer instanceof DesignViewGraphicalViewer)
+      {  
+        DesignViewGraphicalViewer viewer = (DesignViewGraphicalViewer)graphicalViewer;
+        DefinitionsEditPart editPart = (DefinitionsEditPart)viewer.getRootEditPart().getContents();
+        editPart.setModelChildren(Collections.EMPTY_LIST);
+        editPart.refresh();
+        editPart.setModelChildren(null);
+        editPart.refresh();        
+      }
+    }  
+    IContentProvider provider = newEditorMode.getOutlineProvider();
+    if (provider != null)
+    {
+      ASDContentOutlinePage outline = (ASDContentOutlinePage)getContentOutlinePage();
+      if (outline != null)
+      {
+        TreeViewer treeViewer = outline.getTreeViewer();
+        if (treeViewer != null)
+        {      
+          outline.getTreeViewer().setContentProvider(provider);
+          outline.getTreeViewer().refresh();
+        }
+      }  
+
+    }  
+  }
+  
+  protected void storeCurrentModePreference(String id)
+  {
+    WSDLEditorPlugin.getInstance().getPreferenceStore().setValue(DEFAULT_EDITOR_MODE_ID, id);    
+  }  
 }
