@@ -29,6 +29,7 @@ import org.eclipse.wst.wsdl.Port;
 import org.eclipse.wst.wsdl.PortType;
 import org.eclipse.wst.wsdl.WSDLElement;
 import org.eclipse.wst.wsdl.ui.internal.Messages;
+import org.eclipse.wst.wsdl.ui.internal.commands.AddBaseParameterCommand;
 import org.eclipse.wst.wsdl.ui.internal.util.WSDLEditorUtil;
 import org.eclipse.xsd.XSDElementDeclaration;
 import org.w3c.dom.Node;
@@ -47,7 +48,9 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 	protected Object element;
 	protected String newName;
 	private List messageReferences; // This variable should be accessed by method getAllMessageReferences()
-	protected Node node;   
+	protected Node node;
+	private boolean renameParent = true;
+	private String oldName;
 	
 	public SmartRenameAction(Object element, String newName) {
 		setText("Smart Rename Action"); // Do not translate //$NON-NLS-1$
@@ -61,12 +64,20 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 	}
 
 	public String getUndoDescription() {
-	  return Messages.getString("_UI_ACTION_RENAME");  //$NON-NLS-1$
+	  return Messages._UI_ACTION_RENAME;  //$NON-NLS-1$
+	}
+	
+	/*
+	 * boolean argument is used to determine if the top level (parent) object should be renamed
+	 * itself.  Otherwise, only the "child" objects will be renamed.
+	 */
+	public void run(boolean renameParent) {
+		this.renameParent = renameParent;
+		run();
 	}
 
 	public void run() {
 		RenameAction renamer;
-		String oldName;
 		
 		beginRecording();
 		if (element instanceof Operation) {
@@ -77,9 +88,11 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 				return;
 			}
 			
-			// Rename Operation 
-			renamer = new RenameAction(operation, newName);
-			renamer.run();
+			// Rename Operation
+			if (renameParent) {
+				renamer = new RenameAction(operation, newName);
+				renamer.run();
+			}
 			
 			// Rename Input
 			Input input = operation.getEInput();
@@ -170,7 +183,9 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 				return;
 			}
 			
-			input.setName(newName);
+			if (renameParent) {
+				input.setName(newName);
+			}
 
 //			 Rename Messages and Parts
 			Message msg;
@@ -203,7 +218,9 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 				return;
 			}
 			
-			output.setName(newName);
+			if (renameParent) {
+				output.setName(newName);
+			}
 
 //			 Rename Messages and Parts
 			Message msg;
@@ -234,8 +251,10 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 			}
 			
 			// Rename the Fault
-			renamer = new RenameAction(fault, newName);
-			renamer.run();
+			if (renameParent) {
+				renamer = new RenameAction(fault, newName);
+				renamer.run();
+			}
 
 			// Rename the Message and Parts
 			if (msg != null) {
@@ -259,10 +278,14 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 				return;
 			}
 
-			renameMessageHelper(msg, computeNewMessageName(msg, oldName, newName));
+			String newMessageName = computeNewMessageName(msg, oldName, newName);
+			if (renameParent) {
+				renameMessageHelper(msg, newMessageName);
+			}
 					
 			if (msg.getEParts() != null)
-				renamePartsHelper(msg.getEParts(), oldMessageName, msg.getQName().getLocalPart(), true);
+				renamePartsHelper(msg.getEParts(), oldMessageName, newMessageName, true);
+//				renamePartsHelper(msg.getEParts(), oldMessageName, msg.getQName().getLocalPart(), true);
 		}
 		else if (element instanceof Part) {
 			Part part = (Part) element;
@@ -272,8 +295,10 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 				return;
 			}
 			
-			renamer = new RenameAction(element, newName);
-			renamer.run();
+			if (renameParent) {
+				renamer = new RenameAction(element, newName);
+				renamer.run();
+			}
 			
 //			Rename Elements
 			renameXSDElement(part, oldPartName, newName);
@@ -282,8 +307,10 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 			Port port = (Port) element;
 			String oldPortName = port.getName();
 			
-			renamer = new RenameAction(element, newName);
-			renamer.run();
+			if (renameParent) {
+				renamer = new RenameAction(element, newName);
+				renamer.run();
+			}
 
 //			Rename Binding
 			Binding binding = port.getEBinding();
@@ -319,8 +346,11 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 					renamer.run();
 					
 					// Rename Elements
-					renameXSDElement(part, oldPartName, newPartName);
+//					renameXSDElement(part, oldPartName, newPartName);
 				}
+				
+				// Rename Elements
+				renameXSDElement(part, oldSubString, newSubString);
 			}
 		}
 	}
@@ -540,12 +570,25 @@ public class SmartRenameAction extends BaseNodeAction implements Runnable {
 			QName qname = new QName(part.getElementName().getNamespaceURI(), newXSDName);
 			part.setElementName(qname);			
 		}
+		else if (elementDeclaration != null && element instanceof Operation) {
+			Operation operation = (Operation) element;
+			if (AddBaseParameterCommand.getParameterPattern(operation, true) == AddBaseParameterCommand.PART_ELEMENT_SEQ_ELEMENT) {
+				if (elementDeclaration.getName().equals(oldName)) {
+					renameElementDeclarationHelper(elementDeclaration, oldName, newName);
+					
+					// Here we rename the element reference.
+					//
+					QName qname = new QName(part.getElementName().getNamespaceURI(), newName);
+					part.setElementName(qname);	
+				}
+			}
+		}
 	}
 	
 	private void renameElementDeclarationHelper(XSDElementDeclaration elementDeclaration, String oldXSDName, String newXSDName) {
 		if (elementDeclaration != null && elementDeclaration.getName().startsWith(oldXSDName)) {
-			elementDeclaration.setName(newXSDName);
+			String newElementName = replaceSectionWithSubString(elementDeclaration.getName(), oldXSDName, newXSDName, 0);
+			elementDeclaration.setName(newElementName);
 		}
 	}
-	
-}
+}
\ No newline at end of file
