@@ -15,6 +15,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import org.eclipse.wst.sse.core.internal.format.IStructuredFormatProcessor;
 import org.eclipse.wst.wsdl.Definition;
 import org.eclipse.wst.wsdl.Fault;
 import org.eclipse.wst.wsdl.Input;
@@ -28,6 +29,9 @@ import org.eclipse.wst.wsdl.WSDLElement;
 import org.eclipse.wst.wsdl.ui.internal.util.ComponentReferenceUtil;
 import org.eclipse.wst.wsdl.ui.internal.util.NameUtil;
 import org.eclipse.wst.wsdl.ui.internal.util.XSDComponentHelper;
+import org.eclipse.wst.xml.core.internal.provisional.document.IDOMModel;
+import org.eclipse.wst.xml.core.internal.provisional.document.IDOMNode;
+import org.eclipse.wst.xml.core.internal.provisional.format.FormatProcessorXML;
 import org.eclipse.xsd.XSDComplexTypeDefinition;
 import org.eclipse.xsd.XSDElementDeclaration;
 import org.eclipse.xsd.XSDModelGroup;
@@ -36,6 +40,7 @@ import org.eclipse.xsd.XSDParticle;
 import org.eclipse.xsd.XSDSchema;
 import org.eclipse.xsd.XSDSimpleTypeDefinition;
 import org.eclipse.xsd.XSDTypeDefinition;
+import org.w3c.dom.Element;
 
 public abstract class AddBaseParameterCommand {
 	public static int PART_ELEMENT_SEQ_ELEMENT     = 0;
@@ -47,6 +52,7 @@ public abstract class AddBaseParameterCommand {
 	protected int style = 0;
 	protected Operation operation;
 	protected XSDElementDeclaration newXSDElement;
+	protected Part newPart;
 	
 	protected String newAnonymousXSDElementName;
 	protected String newXSDElementName;
@@ -76,60 +82,65 @@ public abstract class AddBaseParameterCommand {
 		return false;
 	}
 	
+	protected XSDElementDeclaration createPartElementSeqElementPattern(Part part, XSDElementDeclaration partElement) {
+		XSDElementDeclaration returnedXSDElement = null;
+		
+		XSDElementDeclaration originalElement = null;
+		XSDElementDeclaration anonXSDElement = null;
+		
+		// Create the XSDElement (anonymous) referenced by the Part if necessary
+		if (partElement == null || partElement.getAnonymousTypeDefinition() == null || partElement.getSchema() == null) {
+			anonXSDElement = XSDComponentHelper.createAnonymousXSDElementDefinition(getAnonymousXSDElementBaseName(), part);
+//			part.setElementDeclaration(anonXSDElement);
+			String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), anonXSDElement);
+			ComponentReferenceUtil.setComponentReference(part, false, prefixedName);
+			part.setTypeDefinition(null);
+			
+			if (partElement != null && partElement.getSchema() != null) {
+				originalElement = partElement;
+				// Remove the 'original' XSDElement as a Global Element
+				partElement.getSchema().getContents().remove(partElement);
+			}
+		}
+		else {
+			anonXSDElement = partElement;
+		}
+		
+		// Add the 'original' XSDElement if it's type wasn't anonymous
+		if (originalElement != null) {
+			XSDComponentHelper.addXSDElementToModelGroup(anonXSDElement, originalElement);
+		}
+		
+		// Create a new XSDElement
+		XSDModelGroup modelGroup = XSDComponentHelper.getXSDModelGroup(anonXSDElement, part.getEnclosingDefinition());
+		returnedXSDElement = XSDComponentHelper.createXSDElementDeclarationCommand(null, getNewXSDElementBaseName(), modelGroup);
+		
+		// Add the newly created XSDElement to the ModelGroup
+		XSDComponentHelper.addXSDElementToModelGroup(anonXSDElement, returnedXSDElement);
+
+		formatChild(anonXSDElement.getElement());
+		return returnedXSDElement;
+	}
+	
 	protected XSDElementDeclaration createPartElementReferenceComponents(Part part) {
 		XSDElementDeclaration returnedXSDElement = null;
 		XSDElementDeclaration partElement = part.getElementDeclaration();
 		
 		if (style == PART_ELEMENT_SEQ_ELEMENT) {
-			XSDElementDeclaration originalElement = null;
-			XSDElementDeclaration anonXSDElement = null;
-			
-			// Create the XSDElement (anonymous) referenced by the Part if necessary
-			if (partElement == null || partElement.getAnonymousTypeDefinition() == null) {
-				anonXSDElement = XSDComponentHelper.createAnonymousXSDElementDefinition(getAnonymousXSDElementBaseName(), part);
-//				part.setElementDeclaration(anonXSDElement);
-				String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), anonXSDElement);
-				ComponentReferenceUtil.setComponentReference(part, false, prefixedName);
-				part.setTypeDefinition(null);
-				
-				if (partElement != null) {
-					originalElement = partElement;
-					// Remove the 'original' XSDElement as a Global Element
-					partElement.getSchema().getContents().remove(partElement);
-				}
-			}
-			else {
-				anonXSDElement = partElement;
-			}
-			
-			// Create a new XSDElement
-			XSDModelGroup modelGroup = XSDComponentHelper.getXSDModelGroup(anonXSDElement, part.getEnclosingDefinition());
-			returnedXSDElement = XSDComponentHelper.createXSDElementDeclarationCommand(null, getNewXSDElementBaseName(), modelGroup);
-			
-			// Add the newly created XSDElement to the ModelGroup
-			XSDComponentHelper.addXSDElementToModelGroup(anonXSDElement, returnedXSDElement);
-			
-			// Add the 'original' XSDElement if it's type wasn't anonymous
-			if (originalElement != null) {
-				XSDComponentHelper.addXSDElementToModelGroup(anonXSDElement, originalElement);
-			}
+			returnedXSDElement = createPartElementSeqElementPattern(part, partElement);
 		}
 		else if (style == PART_ELEMENT) {
 			if (partElement == null) {
 				returnedXSDElement = XSDComponentHelper.createXSDElementDeclarationCommand(part.getEnclosingDefinition(), getNewXSDElementBaseName(), part);
+				if (returnedXSDElement != null && !returnedXSDElement.equals(part.getElementDeclaration())) {
+//					part.setElementDeclaration(returnedXSDElement);
+					String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), returnedXSDElement);
+					ComponentReferenceUtil.setComponentReference(part, false, prefixedName);
+				}
 			}
 			else {
-				// TODO: What should we do here.....  We can default to the PART_ELEMENT_SEQ_ELEMENT style
-				// since it handles 'multiple' XSDElements.... OR ..... we can 'overwrite and set a new
-				// XSDElement
+				returnedXSDElement = createPartElementSeqElementPattern(part, partElement);
 			}
-			
-			if (returnedXSDElement != null && !returnedXSDElement.equals(part.getElementDeclaration())) {
-//				part.setElementDeclaration(returnedXSDElement);
-				String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), returnedXSDElement);
-				ComponentReferenceUtil.setComponentReference(part, false, prefixedName);
-
-			}	
 		}
 		
 		return returnedXSDElement;
@@ -171,8 +182,7 @@ public abstract class AddBaseParameterCommand {
 //			part.setTypeDefinition(topLevelType);
 			String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), topLevelType);
 			ComponentReferenceUtil.setComponentReference(part, true, prefixedName);
-
-			
+			formatChild(topLevelType.getElement());
 		}
 		else if (style == PART_COMPLEXTYPE) {
 			XSDComplexTypeDefinition complexType = null;
@@ -196,6 +206,7 @@ public abstract class AddBaseParameterCommand {
 //				part.setTypeDefinition(complexType);
 				String prefixedName = getPrefixedComponentName(part.getEnclosingDefinition(), complexType);
 				ComponentReferenceUtil.setComponentReference(part, true, prefixedName);
+				formatChild(complexType.getElement());
 			}	
 		}
 		
@@ -209,7 +220,7 @@ public abstract class AddBaseParameterCommand {
 		Message message = messageRef.getEMessage();
 		Part part = null;
 		
-		if (message == null) {
+		if (message == null || message.eContainer() == null) {
 			// Create Message
 			AddMessageCommand command = new AddMessageCommand(messageRef.getEnclosingDefinition(), getWSDLMessageName());
 			command.run();
@@ -219,32 +230,68 @@ public abstract class AddBaseParameterCommand {
 		
 		if (message.getEParts().size() == 0) {
 			// Create Part
-			AddPartCommand command = new AddPartCommand(message, getWSDLPartName());
+			String partName = getWSDLPartName();
+			if (style == PART_ELEMENT_SEQ_ELEMENT) {
+				partName = getDocLitWrappedPartName();
+			}
+			AddPartCommand command = new AddPartCommand(message, partName);
 			command.run();
 			part = (Part) command.getWSDLElement();
 		}
 		else {
-			part = (Part) message.getEParts().get(0);
+			// there is an existing Part
+//			part = (Part) message.getEParts().get(0);
 		}
+		formatChild(message.getElement());
 		
 		return part;
 	}
 	
+	protected String getDocLitWrappedPartName() {
+		return "parameters";
+	}
+
 	protected XSDElementDeclaration createXSDObjects(Part part) {
 		XSDElementDeclaration returnedXSDElement = null;
 		if (isPartElementReference()) {
 			// Is a Part --> Element reference
+			if (part == null && getMessageReference() != null && getMessageReference().getEMessage() != null) {
+				part = (Part) getMessageReference().getEMessage().getEParts().get(0);
+			}
+			
 			returnedXSDElement = createPartElementReferenceComponents(part);
 		}
 		else {
 			// Is a Part --> Complex Type reference
-			returnedXSDElement = createPartComplexTypeReference(part);
+//			returnedXSDElement = createPartComplexTypeReference(part);
+			
+			// If it's a Part --> Type reference, adding a new parameter always means adding a new Part
+			// with a string reference.  Because of this case, we should really rename this method instead
+			// of createXSDObjects() since we may end up creating a Part.
+			if (part == null && getMessageReference() != null && getMessageReference().getEMessage() != null) {
+				List partNames = new ArrayList();
+				Message message = getMessageReference().getEMessage();
+				Iterator it = message.getEParts().iterator();
+				while (it.hasNext()) {
+					Part item = (Part) it.next();
+					partNames.add(item.getName());
+				}
+				String partName = NameUtil.getUniqueNameHelper(getWSDLPartName(), partNames);
+				AddPartCommand command = new AddPartCommand(message, partName);
+				command.run();
+				newPart = (Part) command.getWSDLElement();
+			}
 		}
 		
 		return returnedXSDElement;
 	}
 	
-    private String getPrefixedComponentName(Definition definition, XSDNamedComponent component) {
+	// TODO: rmah: Post WTP 1.5, this method should be made abstract
+	public MessageReference getMessageReference() {
+		return null;
+	}
+	
+    protected String getPrefixedComponentName(Definition definition, XSDNamedComponent component) {
     	String name = component.getName();
     	String tns = component.getTargetNamespace();
         List prefixes = getPrefixes(definition, tns);
@@ -482,6 +529,31 @@ public abstract class AddBaseParameterCommand {
     	
     	return isSequencePattern;
     }
+    
+    protected void formatChild(Element child)
+    {
+      if (child instanceof IDOMNode)
+      {
+        IDOMModel model = ((IDOMNode)child).getModel();
+        try
+        {
+          // tell the model that we are about to make a big model change
+          model.aboutToChangeModel();
+          
+          IStructuredFormatProcessor formatProcessor = new FormatProcessorXML();
+          formatProcessor.formatNode(child);
+        }
+        finally
+        {
+          // tell the model that we are done with the big model change
+          model.changedModel(); 
+        }
+      }
+    }
+    
+    public Part getNewlyAddedComponentPart() {
+    	return newPart;
+    }
 
 	protected abstract String getAnonymousXSDElementBaseName();
 	protected abstract String getNewXSDElementBaseName();
