@@ -12,6 +12,7 @@ package org.eclipse.wst.wsi.internal.core.profile.validator.impl.wsdl;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -51,8 +52,10 @@ import org.eclipse.wst.wsi.internal.core.analyzer.AnalyzerContext;
 import org.eclipse.wst.wsi.internal.core.analyzer.AssertionFailException;
 import org.eclipse.wst.wsi.internal.core.analyzer.CandidateInfo;
 import org.eclipse.wst.wsi.internal.core.analyzer.ServiceReference;
+import org.eclipse.wst.wsi.internal.core.analyzer.config.AnalyzerConfig;
 import org.eclipse.wst.wsi.internal.core.analyzer.config.WSDLElement;
 import org.eclipse.wst.wsi.internal.core.profile.ProfileArtifact;
+import org.eclipse.wst.wsi.internal.core.profile.ProfileAssertions;
 import org.eclipse.wst.wsi.internal.core.profile.TestAssertion;
 import org.eclipse.wst.wsi.internal.core.profile.validator.EntryContext;
 import org.eclipse.wst.wsi.internal.core.profile.validator.WSDLValidator;
@@ -72,7 +75,6 @@ import org.eclipse.wst.wsi.internal.core.xml.schema.XMLSchemaValidator;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-
 /**
  * The WSDL validator will verify that the WSDL and associated XML schema definitions
  * are in conformance with the profile.
@@ -81,12 +83,14 @@ import org.w3c.dom.Element;
  * @author Peter Brittenham (peterbr@us.ibm.com)
  * @author Graham Turrell 	(gturrell@uk.ibm.com)
  */
+
 public class WSDLValidatorImpl
   extends BaseValidatorImpl
   implements WSDLValidator
 {
   /**
    * WSDL URL.
+   * @deprecated -- access the wsdl url via wsdlDocument field.
    */
   protected String wsdlURL;
 
@@ -94,11 +98,73 @@ public class WSDLValidatorImpl
    * WSDL document.
    */
   protected WSDLDocument wsdlDocument = null;
-
+  private boolean testable;
+  
   /**
    * Entry container map.
    */
   protected HashMap containerMap = new HashMap();
+  
+  protected boolean processDefAssertions = true;
+
+  /**
+   * Get the artifact type that this validator applies to.
+   * @return the artifact type (a String)
+   */
+  public String getArtifactType() 
+  {  
+      return TYPE_DESCRIPTION;
+  }
+
+  /**
+   * Get the collection of entry types that this validator applies to.
+   * @return an array of entry types (Strings)
+   */
+  public String[] getEntryTypes() 
+  {
+      return new String[] {
+              TYPE_DESCRIPTION_DEFINITIONS,
+              TYPE_DESCRIPTION_IMPORT,
+              TYPE_DESCRIPTION_TYPES,
+              TYPE_DESCRIPTION_MESSAGE,
+              TYPE_DESCRIPTION_OPERATION,
+              TYPE_DESCRIPTION_PORTTYPE,
+              TYPE_DESCRIPTION_BINDING,
+              TYPE_DESCRIPTION_PORT
+      };
+  }
+
+  /* (non-Javadoc)
+   * @see org.wsi.test.profile.validator.WSDLValidator#init(org.eclipse.wst.wsi.internal.core.analyzer.AnalyzerContext, org.wsi.test.profile.ProfileArtifact, org.wsi.test.report.ReportArtifact, java.lang.String, org.wsi.wsdl.WSDLDocument, org.wsi.test.report.Reporter)
+   */
+  public void init(
+    AnalyzerContext analyzerContext,
+    ProfileAssertions assertions,
+    ReportArtifact reportArtifact,
+    AnalyzerConfig analyzerConfig,
+    Reporter reporter)
+    throws WSIException
+  {
+    init(analyzerContext, assertions, reportArtifact, analyzerConfig, reporter, true);
+  }
+
+  public void init(
+    AnalyzerContext analyzerContext,
+    ProfileAssertions assertions,
+    ReportArtifact reportArtifact,
+    AnalyzerConfig analyzerConfig,
+    Reporter reporter,
+    boolean processDefAssertions)
+    throws WSIException
+  {
+    // BaseValidatorImpl
+    super.init(analyzerContext, assertions.getArtifact(TYPE_DESCRIPTION), reportArtifact, reporter);
+    this.wsdlDocument = analyzerContext.getWsdlDocument();
+    testable = analyzerContext.getWsdlDocument() != null;
+    if (this.wsdlDocument != null)
+      this.wsdlURL = wsdlDocument.getLocation();
+    this.processDefAssertions = processDefAssertions;
+  }
 
   /* (non-Javadoc)
    * @see org.wsi.test.profile.validator.WSDLValidator#init(org.eclipse.wst.wsi.internal.core.analyzer.AnalyzerContext, org.wsi.test.profile.ProfileArtifact, org.wsi.test.report.ReportArtifact, java.lang.String, org.wsi.wsdl.WSDLDocument, org.wsi.test.report.Reporter)
@@ -111,21 +177,36 @@ public class WSDLValidatorImpl
     WSDLDocument wsdlDocument,
     Reporter reporter)
     throws WSIException
+  {
+    init(analyzerContext, profileArtifact, reportArtifact, wsdlURL, wsdlDocument, reporter, true);
+  }
+
+  public void init(
+    AnalyzerContext analyzerContext,
+    ProfileArtifact profileArtifact,
+    ReportArtifact reportArtifact,
+    String wsdlURL,
+    WSDLDocument wsdlDocument,
+    Reporter reporter,
+    boolean processDefAssertions)
+    throws WSIException
   {
     // BaseValidatorImpl
     super.init(analyzerContext, profileArtifact, reportArtifact, reporter);
     this.wsdlDocument = wsdlDocument;
+    testable = (wsdlDocument != null);
     if (wsdlDocument != null)
       this.wsdlURL = wsdlDocument.getLocation();
 
     if (wsdlURL != null)
       this.wsdlURL = wsdlURL;
+    this.processDefAssertions = processDefAssertions;
   }
 
   /* (non-Javadoc)
    * @see org.wsi.test.profile.validator.WSDLValidator#validate()
    */
-  public WSDLDocument validate() throws WSIException
+  public void validateArtifact() throws WSIException
   {
     //WSDLDocument wsdlDocument = null;
     Service service = null;
@@ -140,20 +221,6 @@ public class WSDLValidatorImpl
     //String classPrefix = this.getClass().getName() + "$";
     String classPrefix = this.getClass().getPackage().getName()+".";
 
-    try
-    {
-      // Validate the WSDL service description
-      if (this.wsdlDocument == null)
-        this.wsdlDocument = new WSDLDocument(wsdlURL);
-    }
-
-    catch (Exception e)
-    {
-      // ADD: Certain exceptions should result in validation errors
-
-      throw new WSIException(e.getMessage(), e);
-    }
-
     // Get the definition element
     Definition definition = wsdlDocument.getDefinitions();
 
@@ -170,9 +237,12 @@ public class WSDLValidatorImpl
 
     // always process Import, Definitions & Types assertions 
     // TEMP:
-    processDefinitionAssertions(classPrefix, candidate);
-    processTypesAssertions(classPrefix, candidate);
-    processImportAssertions(classPrefix, candidate);
+    if (processDefAssertions)
+    {
+      processDefinitionAssertions(classPrefix, candidate);
+      processTypesAssertions(classPrefix, candidate);
+      processImportAssertions(classPrefix, candidate);
+    }
 
     // Process the element hierarchy in the WSDL document starting with the one that was specified  
     // FIX: Element finding already completed by CandidateInfo constructor - so use that rather than retest here  
@@ -210,14 +280,10 @@ public class WSDLValidatorImpl
       {
         //throw new WSIRuntimeException("Could not locate WSDL binding for port: " + port.getName());  
         // Set missingInput for all binding, portType, operation and message test assertions 
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
       }
 
       else
@@ -234,12 +300,9 @@ public class WSDLValidatorImpl
         {
           //throw new WSIRuntimeException("Could not locate WSDL portType for binding: " + binding.getQName().getLocalPart());
           // Set missingInput for all portType, operation and message test assertions 
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
         }
 
         else
@@ -308,12 +371,9 @@ public class WSDLValidatorImpl
           //throw new WSIRuntimeException("Could not locate WSDL PortType for Binding: " + binding.getQName().getLocalPart());
 
           // Set missingInput for all portType, operation and message test assertions 
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
         }
 
         else
@@ -343,14 +403,10 @@ public class WSDLValidatorImpl
       else
       {
         // Set missingInput for all binding, portType, operation and message test assertions 
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
       }
     }
 
@@ -371,8 +427,7 @@ public class WSDLValidatorImpl
       }
 
       // Set missingInput for all binding test assertions 
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
 
       processPortTypeAssertions(
         portType,
@@ -426,10 +481,8 @@ public class WSDLValidatorImpl
       }
 
       // Set missingInput for all binding and portType test assertions 
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
 
       processOperationAssertions(
         operation,
@@ -461,12 +514,9 @@ public class WSDLValidatorImpl
       }
 
       // Set missingInput for all binding, portType, and operation test assertions 
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
 
       processMessageAssertions(
         message,
@@ -484,11 +534,19 @@ public class WSDLValidatorImpl
 
     // Cleanup
     cleanup();
+  }
 
+ /* (non-Javadoc)
+  * @see org.wsi.test.profile.validator.WSDLValidator#validate()
+  */
+  /** @deprecated -- use validateArtifact(). */
+  public WSDLDocument validate() throws WSIException
+  {
+    validateArtifact();
+    
     // Return WSDL document
     return this.wsdlDocument;
   }
-
   /**
    * Get entry container using the filename for WSDL document.
    * @param filename a file name.
@@ -568,8 +626,7 @@ public class WSDLValidatorImpl
         continue;
       // Create entry 
       entry = this.reporter.getReport().createEntry();
-      entry.setEntryType(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_DEFINITIONS));
+      entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_DEFINITIONS));
       entry.setReferenceID(definition.getDocumentBaseURI());
       entry.setEntryDetail(definition);
 
@@ -607,7 +664,7 @@ public class WSDLValidatorImpl
     if (wsdlTypes == null || wsdlTypes.length == 0)
     {
       // Set missingInput for all test assertions with this entry type
-      setMissingInput(EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_TYPES));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_TYPES));
     }
 
     else
@@ -623,8 +680,7 @@ public class WSDLValidatorImpl
 
         // Create entry 
         entry = this.reporter.getReport().createEntry();
-        entry.setEntryType(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_TYPES));
+        entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_TYPES));
         entry.setReferenceID(
           candidate.getDefinition(types).getDocumentBaseURI() + "-Types");
         entry.setEntryDetail(types);
@@ -662,8 +718,7 @@ public class WSDLValidatorImpl
     if (wsdlImports == null || wsdlImports.length == 0)
     {
       // Set missingInput for all test assertions with this entry type
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_IMPORT));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_IMPORT));
     }
 
     else
@@ -673,8 +728,7 @@ public class WSDLValidatorImpl
         Import wsdlImport = wsdlImports[i];
         // Create entry 
         entry = this.reporter.getReport().createEntry();
-        entry.setEntryType(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_IMPORT));
+        entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_IMPORT));
         entry.setReferenceID(wsdlImport.getNamespaceURI());
         entry.setEntryDetail(wsdlImport);
 
@@ -710,7 +764,7 @@ public class WSDLValidatorImpl
 
     // Create entry 	  
     entry = this.reporter.getReport().createEntry();
-    entry.setEntryType(EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORT));
+    entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_PORT));
     entry.setReferenceID(port.getName());
     entry.setParentElementName(
       serviceReference.getWSDLElement().getParentElementName());
@@ -742,7 +796,7 @@ public class WSDLValidatorImpl
     // Create entry 
     entry = this.reporter.getReport().createEntry();
     entry.setEntryType(
-      EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_BINDING));
+      EntryType.getEntryType(TYPE_DESCRIPTION_BINDING));
     entry.setReferenceID(bindingQName.toString());
     entry.setEntryDetail(binding);
 
@@ -779,8 +833,7 @@ public class WSDLValidatorImpl
 
     // Create entry 
     entry = this.reporter.getReport().createEntry();
-    entry.setEntryType(
-      EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_PORTTYPE));
+    entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_PORTTYPE));
     entry.setReferenceID(portTypeQName.toString());
     entry.setEntryDetail(portType);
 
@@ -818,8 +871,7 @@ public class WSDLValidatorImpl
 
     // Create entry 
     entry = this.reporter.getReport().createEntry();
-    entry.setEntryType(
-      EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
+    entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
     entry.setReferenceID(operation.getName());
     entry.setParentElementName(portType.getQName().getLocalPart());
     entry.setEntryDetail(operation);
@@ -854,8 +906,7 @@ public class WSDLValidatorImpl
     // For each operation, 
     if (portType.getOperations() == null)
     {
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
     }
 
     else
@@ -866,8 +917,7 @@ public class WSDLValidatorImpl
       {
         operation = (Operation) opIt.next();
         if (operation == null || operation.isUndefined())
-          setMissingInput(
-            EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_OPERATION));
+          setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_OPERATION));
         else
           processOperationAssertions(
             operation,
@@ -901,8 +951,7 @@ public class WSDLValidatorImpl
 
     // Create entry 
     entry = this.reporter.getReport().createEntry();
-    entry.setEntryType(
-      EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+    entry.setEntryType(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
     entry.setReferenceID(messageQName.toString());
     entry.setEntryDetail(message);
 
@@ -1013,8 +1062,7 @@ public class WSDLValidatorImpl
       if (messageSet.size() == 0)
       {
         // Set all message test assertion results to missingInput
-        setMissingInput(
-          EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+        setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
       }
 
       else
@@ -1070,8 +1118,7 @@ public class WSDLValidatorImpl
     if (messageSet.size() == 0)
     {
       // Set all message test assertion results to missingInput
-      setMissingInput(
-        EntryType.getEntryType(EntryType.TYPE_DESCRIPTION_MESSAGE));
+      setMissingInput(EntryType.getEntryType(TYPE_DESCRIPTION_MESSAGE));
     }
 
     else
@@ -1499,7 +1546,11 @@ public class WSDLValidatorImpl
     try
     {
       // Need to read the file directly, since WSDL4J always puts in the default WSDL namespace
-      Document document = parseXMLDocumentURL(def.getDocumentBaseURI(), null);
+      Document document = wsdlDocument.getDocument();
+      if (document == null)
+      {
+        document = parseXMLDocumentURL(def.getDocumentBaseURI(), null);
+      }
 
       if (document != null)
       {
@@ -1682,32 +1733,46 @@ public class WSDLValidatorImpl
    */
   protected List getWSDLTargetNamespaceList(Definition definition)
   {
-    List list = new Vector();
+    return getWSDLTargetNamespaceList(definition, new ArrayList());
+  }
 
-    // Always add current document targetNamespace
-    if (definition.getTargetNamespace() != null)
-      list.add(definition.getTargetNamespace());
-
-    // Get list of imported WSDL documents
-    Map importMap = definition.getImports();
-
-    Import imp;
-
-    // Add each imports targetNamespace to the list
-    if (importMap != null && !importMap.isEmpty())
+  /**
+   * Build list of WSDL targetNamespaces.
+   * @param definition a Definition object.
+   * @return list of WSDL targetNamespaces.
+   */
+  protected List getWSDLTargetNamespaceList(Definition definition, List alreadyProcessedDefinitions)
+  {
+    List list = new ArrayList();
+    if ((definition != null) && (!alreadyProcessedDefinitions.contains(definition)))
     {
-      Iterator values = importMap.values().iterator();
-      List importList;
-      while (values.hasNext())
+      alreadyProcessedDefinitions.add(definition);
+      
+      // Always add current document targetNamespace
+      if (definition.getTargetNamespace() != null)
+        list.add(definition.getTargetNamespace());
+
+      // Get list of imported WSDL documents
+      Map importMap = definition.getImports();
+
+      Import imp;
+
+      // Add each imports targetNamespace to the list
+      if (importMap != null && !importMap.isEmpty())
       {
-        importList = (List) values.next();
-        Iterator imports = importList.iterator();
-        while (imports.hasNext())
+        Iterator values = importMap.values().iterator();
+        List importList;
+        while (values.hasNext())
         {
-          imp = (Import) imports.next();
-          if (imp != null && imp.getDefinition() != null)
-          list.addAll(getWSDLTargetNamespaceList(imp.getDefinition()));
+          importList = (List) values.next();
+          Iterator imports = importList.iterator();
+          while (imports.hasNext())
+          {
+            imp = (Import) imports.next();
+            if (imp != null && imp.getDefinition() != null)
+            list.addAll(getWSDLTargetNamespaceList(imp.getDefinition(), alreadyProcessedDefinitions));
             // list.add(imp.getDefinition().getTargetNamespace());
+          }
         }
       }
     }
@@ -2311,4 +2376,10 @@ public class WSDLValidatorImpl
     return true;
 
   }
+  
+  /**
+   * Returns true if these tests should be run (depending on the analyzer
+   * config)
+   */
+  public boolean runTests() { return testable; } 
 }
