@@ -28,18 +28,23 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.Iterator;
+import java.util.Map;
 import java.util.ResourceBundle;
 import com.ibm.icu.util.StringTokenizer;
 import java.util.Vector;
 
+import org.eclipse.wst.wsi.internal.WSITestToolsPlugin;
 import org.eclipse.wst.wsi.internal.core.WSIConstants;
 import org.eclipse.wst.wsi.internal.core.WSIException;
+import org.eclipse.wst.wsi.internal.core.analyzer.config.AnalyzerConfig;
 import org.eclipse.wst.wsi.internal.core.log.MimePart;
 import org.eclipse.wst.wsi.internal.core.log.MimeParts;
 import org.eclipse.wst.wsi.internal.core.log.impl.MimePartImpl;
 import org.eclipse.wst.wsi.internal.core.log.impl.MimePartsImpl;
 import org.eclipse.wst.wsi.internal.core.profile.ProfileAssertions;
+import org.eclipse.wst.wsi.internal.core.report.Reporter;
 import org.eclipse.wst.wsi.internal.core.xml.XMLUtils;
 
 import com.ibm.icu.text.SimpleDateFormat;
@@ -53,6 +58,9 @@ public final class Utils
   public static final byte CR = (byte) '\r';
   public static final byte LF = (byte) '\n';
 
+  
+  private static Map validProfileTADVersions;
+
   /**
    * Common timestamp format.
    */
@@ -1133,6 +1141,19 @@ public final class Utils
       v.add(array[i]);
     return v;
   }
+
+  /**
+   * Designates legal versions for the profile test assertion document
+   * @param name - the TAD name
+   * @param version - the legal version
+   */
+  public static void registerValidProfileTADVersion(String name, String version)
+  {
+      if (validProfileTADVersions == null)
+          validProfileTADVersions = new HashMap();
+      validProfileTADVersions.put(name, version);
+  }
+  
   /**
    * Checks to ensure that version of the profile test assertion 
    * document is supported in this version of the test tools.
@@ -1142,29 +1163,21 @@ public final class Utils
    */
   public static boolean isValidProfileTADVersion(ProfileAssertions profileAssertions)
   {
-    boolean result = false;
 
     String name = profileAssertions.getTADName();
     String version = profileAssertions.getTADVersion();
-
-    if (WSIConstants.BASIC_PROFILE_TAD_NAME.equals(name))
-    {
-      result =
-        checkVersionNumber(WSIConstants.BASIC_PROFILE_TAD_VERSION, version);
-    } else if (WSIConstants.BASIC_PROFILE_1_1_TAD_NAME.equals(name))
-    {  
-      result =
-        checkVersionNumber(WSIConstants.BASIC_PROFILE_1_1_TAD_VERSION, version);
-    } else if (WSIConstants.SIMPLE_SOAP_BINDINGS_PROFILE_TAD_NAME.equals(name))
-    {
-      result =
-        checkVersionNumber(WSIConstants.SIMPLE_SOAP_BINDINGS_PROFILE_TAD_VERSION, version);
-    } else if (WSIConstants.ATTACHMENTS_PROFILE_TAD_NAME.equals(name))
-    {
-      result =
-        checkVersionNumber(WSIConstants.ATTACHMENTS_PROFILE_TAD_VERSION, version);
+    
+    if (validProfileTADVersions == null) {
+       String versions[][] = WSITestToolsPlugin.getPlugin().getAllTADVersions();
+       for (int i = 0; i < versions.length; i++)
+           registerValidProfileTADVersion(versions[i][0], versions[i][1]);
     }
-    return result;
+
+    if (validProfileTADVersions.containsKey(name))
+        return checkVersionNumber((String) validProfileTADVersions.get(name),
+                version);
+    else
+        return false;
   }
 
   /**
@@ -1413,4 +1426,21 @@ public final class Utils
 	}
   	catch (Exception e){}
   }
+
+  public static AnalyzerConfig getAnalyzerConfig(Reporter reporter) 
+  {
+	AnalyzerConfig result = null;
+	if (reporter != null)
+	{
+	  try
+	  {
+		result = reporter.getReport().getReportContext().getAnalyzer().getAnalyzerConfig();
+	  }
+	  catch (Exception e)
+	  {
+		result = null;
+	  }
+	}
+	return result;
+  }
 }
