@@ -1,6 +1,9 @@
 package org.eclipse.wst.xsd.ui.internal.adt.editor;
 
+import java.text.Collator;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Comparator;
 import java.util.EventObject;
 import java.util.Iterator;
 import java.util.List;
@@ -10,12 +13,16 @@ import org.eclipse.core.resources.IResourceChangeListener;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.draw2d.ColorConstants;
+import org.eclipse.draw2d.IFigure;
+import org.eclipse.draw2d.geometry.Point;
 import org.eclipse.gef.DefaultEditDomain;
 import org.eclipse.gef.EditPartFactory;
+import org.eclipse.gef.EditPartViewer;
 import org.eclipse.gef.MouseWheelHandler;
 import org.eclipse.gef.MouseWheelZoomHandler;
 import org.eclipse.gef.commands.CommandStack;
 import org.eclipse.gef.commands.CommandStackListener;
+import org.eclipse.gef.editparts.LayerManager;
 import org.eclipse.gef.editparts.ZoomManager;
 import org.eclipse.gef.ui.actions.ActionRegistry;
 import org.eclipse.gef.ui.actions.UpdateAction;
@@ -26,9 +33,21 @@ import org.eclipse.gef.ui.parts.SelectionSynchronizer;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.dialogs.ErrorDialog;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.MouseAdapter;
+import org.eclipse.swt.events.MouseEvent;
+import org.eclipse.swt.events.PaintEvent;
+import org.eclipse.swt.events.PaintListener;
+import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.SelectionListener;
+import org.eclipse.swt.graphics.GC;
+import org.eclipse.swt.graphics.Image;
+import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FillLayout;
+import org.eclipse.swt.layout.GridData;
+import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.ui.IEditorInput;
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IEditorSite;
@@ -39,17 +58,22 @@ import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.forms.widgets.ImageHyperlink;
 import org.eclipse.ui.ide.IDE;
+import org.eclipse.ui.ide.IGotoMarker;
 import org.eclipse.ui.part.FileEditorInput;
 import org.eclipse.ui.part.MultiPageEditorPart;
 import org.eclipse.ui.views.contentoutline.IContentOutlinePage;
 import org.eclipse.ui.views.properties.tabbed.ITabbedPropertySheetPageContributor;
 import org.eclipse.wst.sse.ui.StructuredTextEditor;
+import org.eclipse.wst.xsd.ui.internal.adt.design.DesignViewerGraphicConstants;
+import org.eclipse.wst.xsd.ui.internal.adt.design.FlatCCombo;
 import org.eclipse.wst.xsd.ui.internal.adt.design.editparts.RootEditPart;
+import org.eclipse.wst.xsd.ui.internal.editor.XSDEditorPlugin;
 
-public abstract class CommonMultiPageEditor extends MultiPageEditorPart implements IResourceChangeListener, CommandStackListener, ITabbedPropertySheetPageContributor, IPropertyListener
+public abstract class CommonMultiPageEditor extends MultiPageEditorPart implements IResourceChangeListener, CommandStackListener, ITabbedPropertySheetPageContributor, IPropertyListener, IEditorModeListener
 {
-  public static int SOURCE_PAGE_INDEX = 1, DESIGN_PAGE_INDEX = 0;
+  public static int SOURCE_PAGE_INDEX = 1, DESIGN_PAGE_INDEX = 0;  
   
   protected IContentOutlinePage fOutlinePage;
   protected DefaultEditDomain editDomain;
@@ -58,12 +82,40 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
   protected StructuredTextEditor structuredTextEditor;
   protected CommonSelectionManager selectionProvider;
   protected ScrollingGraphicalViewer graphicalViewer;
+  protected EditorModeManager editorModeManager;
+  protected FlatCCombo modeCombo;
+  private EditorModeAndCustomizedName[] editorModeAndCustomizedNames;
+  protected Composite toolbar;
+  protected ModeComboListener modeComboListener;
+  protected int maxLength = 0;
   
   public CommonMultiPageEditor()
   {
     super();
-    editDomain = new DefaultEditDomain(this);
-
+    editDomain = new DefaultEditDomain(this)
+    {
+      public void mouseDown(MouseEvent mouseEvent, EditPartViewer viewer)
+      {
+        boolean eatTheEvent = false;      
+        LayerManager manager = (LayerManager)viewer.getEditPartRegistry().get(LayerManager.ID);     
+        IFigure layer = manager.getLayer(DesignViewerGraphicConstants.SCALED_HANDLE_LAYER);
+        if (layer != null)
+        {  
+          Point p = new Point(mouseEvent.x, mouseEvent.y);
+          layer.translateToRelative(p);
+          IFigure figure = layer.findFigureAt(p);     
+          if (figure != null && figure != layer)
+          {
+            // we eat this selection event!
+            eatTheEvent = true;
+          } 
+        }
+        if (!eatTheEvent)
+        {
+          super.mouseDown(mouseEvent, viewer);
+        }  
+      }      
+    };
   }
 
   /* (non-Javadoc)
@@ -281,6 +333,11 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
     actionRegistry = null;
     selectionProvider = null;
     graphicalViewer = null;
+    if (modeCombo != null && !modeCombo.isDisposed())
+    {
+      modeCombo.removeSelectionListener(modeComboListener);
+      modeComboListener = null;
+    }
     
     super.dispose();
   }
@@ -295,8 +352,8 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
    */
   public void gotoMarker(IMarker marker)
   {
-    setActivePage(0);
-    IDE.gotoMarker(getEditor(0), marker);
+    setActivePage(SOURCE_PAGE_INDEX);
+    IDE.gotoMarker(structuredTextEditor, marker);
   }
 
   /**
@@ -338,6 +395,16 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
       return getCommandStack();
     if (type == ActionRegistry.class)
       return getActionRegistry();
+    if (type == EditorModeManager.class)
+      return getEditorModeManager();
+    if (type == IGotoMarker.class) {
+      return new IGotoMarker() {
+        public void gotoMarker(IMarker marker) {
+          CommonMultiPageEditor.this.gotoMarker(marker);
+        }
+      };
+    }
+
     
     return super.getAdapter(type);
   }
@@ -435,15 +502,16 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
     // Set the root edit part
     // ScalableFreeformRootEditPart root = new ScalableFreeformRootEditPart();
     RootEditPart root = new RootEditPart();
-
+    ZoomManager zoomManager = root.getZoomManager();
+    
     List zoomLevels = new ArrayList(3);
     zoomLevels.add(ZoomManager.FIT_ALL);
     zoomLevels.add(ZoomManager.FIT_WIDTH);
     zoomLevels.add(ZoomManager.FIT_HEIGHT);
-    root.getZoomManager().setZoomLevelContributions(zoomLevels);
+    zoomManager.setZoomLevelContributions(zoomLevels);
 
-    IAction zoomIn = new ZoomInAction(root.getZoomManager());
-    IAction zoomOut = new ZoomOutAction(root.getZoomManager());
+    IAction zoomIn = new ZoomInAction(zoomManager);
+    IAction zoomOut = new ZoomOutAction(zoomManager);
     getActionRegistry().registerAction(zoomIn);
     getActionRegistry().registerAction(zoomOut);
 
@@ -457,9 +525,7 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
     // connectionLayer.setVisible(false);
 
     // Zoom
-    ZoomManager manager = (ZoomManager) graphicalViewer.getProperty(ZoomManager.class.toString());
-    if (manager != null)
-      manager.setZoom(1.0);
+    zoomManager.setZoom(1.0);
     // Scroll-wheel Zoom
     graphicalViewer.setProperty(MouseWheelHandler.KeyGenerator.getKey(SWT.CTRL), MouseWheelZoomHandler.SINGLETON);
     graphicalViewer.setRootEditPart(root);
@@ -474,4 +540,172 @@ public abstract class CommonMultiPageEditor extends MultiPageEditorPart implemen
   protected abstract ScrollingGraphicalViewer getGraphicalViewer();
   protected abstract EditPartFactory getEditPartFactory();
   protected abstract void initializeGraphicalViewer();
+
+  protected EditorModeManager getEditorModeManager()
+  {
+    if (editorModeManager == null)
+    {
+      editorModeManager = createEditorModeManager();
+      editorModeManager.addListener(this);
+      editorModeManager.init();
+    }  
+    return editorModeManager;
+  }
+  
+  protected abstract EditorModeManager createEditorModeManager();
+  
+  
+  private String getEditModeName(EditorMode editorMode, ProductCustomizationProvider productCustomizationProvider)
+  {
+    String result = editorMode.getDisplayName();
+    if (productCustomizationProvider != null)
+    {
+      String customizedName = productCustomizationProvider.getEditorModeDisplayName(editorMode.getId());
+      if (customizedName != null)
+      {
+        result = customizedName;
+      }  
+    } 
+    return result;
+  }
+  
+  class EditorModeAndCustomizedName
+  {
+    EditorMode mode;
+    String name;
+  }
+  
+  protected void createViewModeToolbar(Composite parent)
+  {
+    EditorModeManager manager = (EditorModeManager)getAdapter(EditorModeManager.class);
+    final ProductCustomizationProvider productCustomizationProvider = (ProductCustomizationProvider)getAdapter(ProductCustomizationProvider.class);
+    EditorMode [] modeList = manager.getModes();
+    
+    int modeListLength = modeList.length;
+    boolean showToolBar = modeListLength > 1;
+   
+    if (showToolBar)
+    {
+      toolbar = new Composite(parent, SWT.FLAT | SWT.DRAW_TRANSPARENT);
+      toolbar.setBackground(ColorConstants.white);
+      toolbar.addPaintListener(new PaintListener() {
+
+        public void paintControl(PaintEvent e)
+        {
+          Rectangle clientArea = toolbar.getClientArea(); 
+          e.gc.setForeground(ColorConstants.lightGray);
+          e.gc.drawRectangle(clientArea.x, clientArea.y, clientArea.width - 1, clientArea.height - 1);
+        }
+      });
+      
+      GridLayout gridLayout = new GridLayout(3, false);
+      toolbar.setLayout(gridLayout);
+
+      Label label = new Label(toolbar, SWT.FLAT | SWT.HORIZONTAL);
+      label.setBackground(ColorConstants.white);
+      label.setText(Messages._UI_LABEL_VIEW);
+      label.setLayoutData(new GridData(GridData.VERTICAL_ALIGN_CENTER));
+
+      modeCombo = new FlatCCombo(toolbar, SWT.FLAT);
+      modeCombo.setEditable(false);
+      modeCombo.setText(getEditModeName(manager.getCurrentMode(), productCustomizationProvider)); 
+      GC gc = new GC(modeCombo);
+      int textWidth = 0;
+      maxLength = 0;
+      
+      // populate combo with modes
+      editorModeAndCustomizedNames = new EditorModeAndCustomizedName[modeListLength];      
+      for (int i = 0; i < modeListLength; i++)
+      {  
+        EditorModeAndCustomizedName entry = new EditorModeAndCustomizedName();
+        editorModeAndCustomizedNames[i] = entry;
+        entry.name = getEditModeName(modeList[i], productCustomizationProvider);
+        entry.mode = modeList[i];
+      }        
+      Arrays.sort(editorModeAndCustomizedNames, new Comparator()
+      {
+        public int compare(Object arg0, Object arg1)
+        {
+          EditorModeAndCustomizedName a = (EditorModeAndCustomizedName)arg0;
+          EditorModeAndCustomizedName b = (EditorModeAndCustomizedName)arg1;        
+          return Collator.getInstance().compare(a.name, b.name);
+        }
+      });
+      for (int i = 0; i < editorModeAndCustomizedNames.length; i++ )
+      {
+        EditorModeAndCustomizedName entry = editorModeAndCustomizedNames[i];
+        modeCombo.add(entry.name);
+        maxLength = Math.max (gc.stringExtent(entry.name).x, maxLength);
+        int approxWidthOfStrings = Math.max (gc.stringExtent(entry.name).x, textWidth);
+        if (approxWidthOfStrings > maxLength)
+          maxLength = approxWidthOfStrings;
+      }
+      
+      maxLength += gc.stringExtent(Messages._UI_LABEL_VIEW).x; 
+      gc.dispose();
+      
+      modeComboListener = new ModeComboListener();
+      modeCombo.addSelectionListener(modeComboListener);
+      modeCombo.setLayoutData(new GridData(GridData.VERTICAL_ALIGN_END));
+      modeCombo.setBackground(toolbar.getBackground());
+
+      ImageHyperlink hyperlink = new ImageHyperlink(toolbar, SWT.FLAT);
+      hyperlink.setBackground(ColorConstants.white);
+      // https://bugs.eclipse.org/bugs/show_bug.cgi?id=154457
+      Image image = XSDEditorPlugin.getDefault().getIconImage("etool16/help_contents");
+      hyperlink.setImage(image);
+      hyperlink.setToolTipText(Messages._UI_HOVER_VIEW_MODE_DESCRIPTION);
+      hyperlink.setLayoutData(new GridData(GridData.VERTICAL_ALIGN_CENTER));
+      hyperlink.addMouseListener(new MouseAdapter()
+      {
+        public void mouseDown(MouseEvent e)
+        {
+          if (productCustomizationProvider != null)
+          {
+            productCustomizationProvider.handleAction("showEditorModeHelp");
+          }
+        }
+      });      
+    }
+  }
+  
+  
+  protected class ModeComboListener implements SelectionListener
+  {
+    public ModeComboListener()
+    {
+    }
+    
+    public void widgetDefaultSelected(SelectionEvent e)
+    {
+    }
+
+    public void widgetSelected(SelectionEvent e)
+    {
+      if (e.widget == modeCombo)
+      {        
+        EditorModeManager manager = (EditorModeManager)getAdapter(EditorModeManager.class);
+        EditorMode [] modeList = manager.getModes();
+        if (modeList.length >= 1)
+        {
+          EditorModeAndCustomizedName entry = editorModeAndCustomizedNames[modeCombo.getSelectionIndex()];
+          if (manager.getCurrentMode() != entry.mode)
+          {  
+            manager.setCurrentMode(entry.mode);
+            storeCurrentModePreference(entry.mode.getId());
+            ProductCustomizationProvider productCustomizationProvider = (ProductCustomizationProvider) getAdapter(ProductCustomizationProvider.class);
+            if (productCustomizationProvider != null)
+            {
+              productCustomizationProvider.handleAction("editorModeChanged");
+            }
+          }
+        }  
+      }
+    }
+  }
+  
+  protected void storeCurrentModePreference(String id)
+  {
+    // Don't do anything as default.  Allow extenders to implement.
+  }
 }
