@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2006 IBM Corporation and others.
+ * Copyright (c) 2001, 2007 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,9 +11,11 @@
 package org.eclipse.wst.xsd.ui.internal.common.properties.sections;
 
 import java.util.List;
+
 import org.eclipse.draw2d.ColorConstants;
 import org.eclipse.gef.commands.Command;
 import org.eclipse.jface.action.MenuManager;
+import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
@@ -24,8 +26,10 @@ import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.window.Window;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.SashForm;
+import org.eclipse.swt.custom.ScrolledComposite;
 import org.eclipse.swt.events.MouseTrackAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
@@ -35,10 +39,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.ui.IEditorPart;
+import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.forms.widgets.ExpandableComposite;
 import org.eclipse.ui.forms.widgets.Section;
-import org.eclipse.ui.part.PageBook;
+import org.eclipse.ui.views.properties.PropertySheet;
+import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
 import org.eclipse.wst.sse.core.internal.provisional.INodeAdapter;
 import org.eclipse.wst.sse.core.internal.provisional.INodeNotifier;
 import org.eclipse.wst.xsd.ui.internal.common.commands.AddExtensionCommand;
@@ -49,7 +55,9 @@ import org.eclipse.wst.xsd.ui.internal.common.properties.sections.appinfo.Extens
 import org.eclipse.wst.xsd.ui.internal.common.properties.sections.appinfo.ExtensionsSchemasRegistry;
 import org.eclipse.wst.xsd.ui.internal.common.properties.sections.appinfo.SpecificationForExtensionsSchema;
 import org.eclipse.wst.xsd.ui.internal.common.util.Messages;
+import org.eclipse.wst.xsd.ui.internal.editor.XSDEditorCSHelpIds;
 import org.w3c.dom.Element;
+import org.w3c.dom.Node;
 
 public abstract class AbstractExtensionsSection extends AbstractSection
 {
@@ -62,9 +70,10 @@ public abstract class AbstractExtensionsSection extends AbstractSection
   protected IDocumentChangedNotifier documentChangeNotifier;
   protected INodeAdapter internalNodeAdapter = new InternalNodeAdapter();
 
-  private Composite page, pageBook2;
+  private Composite page;
   protected Button addButton, removeButton;
-  private PageBook pageBook;
+  private Object prevInput;
+  private SpecificationForExtensionsSchema prevCategory;
 
   /**
    * 
@@ -98,8 +107,12 @@ public abstract class AbstractExtensionsSection extends AbstractSection
       if (!isRoot)
       {  
         extensionTreeViewer.refresh(notifier);
+        if ( newValue instanceof Element)
+        {
+          extensionTreeViewer.expandToLevel(notifier, 1);
+          extensionTreeViewer.setSelection(new StructuredSelection(newValue));
+        }
       }  
-      extensionDetailsViewer.refresh();
     }    
   }
   
@@ -145,36 +158,64 @@ public abstract class AbstractExtensionsSection extends AbstractSection
     gridData.verticalAlignment = GridData.FILL;
     gridData.horizontalAlignment = GridData.FILL;
     page.setLayoutData(gridData);
+    
+    SashForm sashForm = new SashForm(page, SWT.HORIZONTAL);
+    // Try to limit the initial width of the section
+    
+    int w = SWT.DEFAULT;
+    try
+    {
+      IWorkbenchPart part = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().getActivePart();
 
-    pageBook = new PageBook(page, SWT.FLAT);
-    gridData = new GridData();
-    gridData.grabExcessHorizontalSpace = true;
-    gridData.grabExcessVerticalSpace = true;
-    gridData.verticalAlignment = GridData.FILL;
-    gridData.horizontalAlignment = GridData.FILL;
-    pageBook.setLayoutData(gridData);
-
-    pageBook2 = getWidgetFactory().createComposite(pageBook, SWT.FLAT);
-
-    gridLayout = new GridLayout();
-    gridLayout.marginHeight = 2;
-    gridLayout.marginWidth = 2;
-    gridLayout.numColumns = 1;
-    pageBook2.setLayout(gridLayout);
-
-    gridData = new GridData();
-    gridData.grabExcessHorizontalSpace = true;
-    gridData.grabExcessVerticalSpace = true;
-    gridData.verticalAlignment = GridData.FILL;
-    gridData.horizontalAlignment = GridData.FILL;
-    pageBook2.setLayoutData(gridData);
-
-    SashForm sashForm = new SashForm(pageBook2, SWT.HORIZONTAL);
+      // Find the width of the Tabbed Property Sheet's composite excluding the tab
+      if (part instanceof PropertySheet)
+      {
+        PropertySheet sheet = (PropertySheet)part;
+        if (sheet.getCurrentPage() instanceof TabbedPropertySheetPage)
+        {
+          TabbedPropertySheetPage tabbedPage = (TabbedPropertySheetPage)sheet.getCurrentPage();
+          Composite targetComposite = null;
+          if (tabbedPage.getControl() instanceof Composite)
+          {
+            Composite c = (Composite)tabbedPage.getControl();
+            int length = c.getChildren().length;
+            for (int i = 0; i < length; i++)
+            {
+              Control ctrl = c.getChildren()[i];
+              int length2  = (((Composite)ctrl).getChildren()).length;
+              for (int j = 0; j < length2; j++ )
+              {
+                if ((((Composite)ctrl).getChildren())[j] instanceof ScrolledComposite)
+                {
+                  targetComposite = (Composite)(((Composite)ctrl).getChildren())[j];
+                  break;
+                }
+              }
+            }
+          }
+          if (targetComposite != null)
+          {
+            w = targetComposite.getSize().x - 20;  // ensure scrollbars don't show
+          }
+          // The above can be accomplished by the following code
+          // but because TabbedPropertyComposite is in an internal package, I will get a discouraged
+          // access warning.
+          // w = ((TabbedPropertyComposite)(tabbedPage.getControl())).getTabComposite().getSize().x;
+        }
+      }
+    }
+    catch(Exception e)
+    {
+      w = SWT.DEFAULT;
+    }
     gridData = new GridData();
     gridData.grabExcessHorizontalSpace = true;
     gridData.grabExcessVerticalSpace = true;
     gridData.verticalAlignment = GridData.FILL;
     gridData.horizontalAlignment = GridData.FILL;
+    // The initial size should be set, not the widthHint, which forces the width
+    // to remain constant.
+    sashForm.setSize(w, SWT.DEFAULT);
     sashForm.setLayoutData(gridData);
     sashForm.setForeground(ColorConstants.white);
     sashForm.setBackground(ColorConstants.white);
@@ -249,10 +290,13 @@ public abstract class AbstractExtensionsSection extends AbstractSection
             }
           }
         }
-      };
+      }
 
     });
     
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(extensionTreeViewer.getControl(),
+    		XSDEditorCSHelpIds.EXTENSIONS_TAB__EXTENSIONS); 
+    
     Composite buttonComposite = getWidgetFactory().createComposite(tableAndButtonComposite, SWT.FLAT);
     //ColumnLayout columnLayout = new ColumnLayout();
     //buttonComposite.setLayout(columnLayout);
@@ -270,10 +314,18 @@ public abstract class AbstractExtensionsSection extends AbstractSection
     addButton.setToolTipText(Messages._UI_ACTION_ADD_EXTENSION_COMPONENT);
     //addButton.setLayoutData(new ColumnLayoutData(ColumnLayoutData.FILL));
     addButton.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+    
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(addButton,
+    		XSDEditorCSHelpIds.EXTENSIONS_TAB__ADD);     
+    
     removeButton = getWidgetFactory().createButton(buttonComposite, Messages._UI_ACTION_DELETE, SWT.FLAT);
     removeButton.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
     removeButton.addSelectionListener(this);
     removeButton.setToolTipText(Messages._UI_ACTION_DELETE_EXTENSION_COMPONENT);
+    
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(removeButton,
+    		XSDEditorCSHelpIds.EXTENSIONS_TAB__DELETE);   
+    
     //removeButton.setLayoutData(new ColumnLayoutData(ColumnLayoutData.FILL));
 
     // TODO (cs) uncomment the up/down button when we have time to implement
@@ -328,10 +380,8 @@ public abstract class AbstractExtensionsSection extends AbstractSection
 
     createElementContentWidget(testComp);
 
-    int[] weights = { 50, 50 };
+    int[] weights = { 40, 60 };
     sashForm.setWeights(weights);
-
-    pageBook.showPage(pageBook2);
   }
 
   protected void createElementContentWidget(Composite parent)
@@ -339,6 +389,9 @@ public abstract class AbstractExtensionsSection extends AbstractSection
     extensionDetailsViewer = new ExtensionDetailsViewer(parent, getWidgetFactory());
     extensionDetailsViewer.setContentProvider(new DOMExtensionDetailsContentProvider());    
     extensionDetailsViewer.getControl().setLayoutData(new GridData(GridData.FILL_BOTH));
+    
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(extensionDetailsViewer.getControl(),
+    		XSDEditorCSHelpIds.EXTENSIONS_TAB__EXTENSIONS_DETAILS);   
   }
   
 
@@ -350,6 +403,11 @@ public abstract class AbstractExtensionsSection extends AbstractSection
     setListenerEnabled(false);
     if (input != null)
     {
+      if ( prevInput == input)
+    	  return;
+      else
+    	  prevInput = input;
+      
       Tree tree = extensionTreeViewer.getTree();
       extensionDetailsViewer.setInput(null);
       tree.removeAll();
@@ -390,6 +448,10 @@ public abstract class AbstractExtensionsSection extends AbstractSection
 
       dialog.setInput(properties);
       dialog.setBlockOnOpen(true);
+      dialog.setPrefStore( getPrefStore() );
+      
+      if (prevCategory != null)
+    	  dialog.setInitialCategorySelection(prevCategory);
 
       if (dialog.open() == Window.OK)
       {
@@ -408,14 +470,15 @@ public abstract class AbstractExtensionsSection extends AbstractSection
               newSelection = addExtensionCommand.getNewObject();
             }
           }
-        }  
+        }
         //refresh();
         if (newSelection != null)
-        {  
+        {
           extensionTreeViewer.setSelection(new StructuredSelection(newSelection));
-        }  
+        }
       }
 
+      prevCategory = dialog.getSelectedCategory();
     }
     else if (event.widget == removeButton)
     {
@@ -437,6 +500,12 @@ public abstract class AbstractExtensionsSection extends AbstractSection
     }
   }
 
+  // TODO make this one an abstract method. XSDEditor and WSDLEditor should return
+  // diferent IpreferenceStore objects
+  protected IPreferenceStore getPrefStore() {
+	return null;
+  }
+
   public void widgetDefaultSelected(SelectionEvent event)
   {
 
@@ -454,7 +523,7 @@ public abstract class AbstractExtensionsSection extends AbstractSection
   }
  
 
-  Element selectedElement;
+  Node selectedNode;
 
   class ElementSelectionChangedListener implements ISelectionChangedListener
   {
@@ -468,9 +537,9 @@ public abstract class AbstractExtensionsSection extends AbstractSection
         if (structuredSelection.size() > 0)
         {  
           Object obj = structuredSelection.getFirstElement();
-          if (obj instanceof Element)
+          if (obj instanceof Node)
           {
-            selectedElement = (Element) obj;
+            selectedNode = (Node) obj;
             extensionDetailsViewer.setInput(obj);
             isDeleteEnabled = true;         
           }
@@ -480,7 +549,31 @@ public abstract class AbstractExtensionsSection extends AbstractSection
           // if nothing is selected then don't show any details
           //
           extensionDetailsViewer.setInput(null);
-        }  
+        }
+
+        // Upon element selection, the details view populates fine, but there is no vertical scrollbar,
+        // so it misleads the user into thinking there are no other attributes available
+        // See https://bugs.eclipse.org/bugs/show_bug.cgi?id=174073
+        // This is a workaround to force a layout of the tab composite
+        IWorkbenchPart part = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().getActivePart();
+        if (part instanceof PropertySheet)
+        {
+          PropertySheet sheet = (PropertySheet)part;
+          if (sheet.getCurrentPage() instanceof TabbedPropertySheetPage)
+          {
+            TabbedPropertySheetPage tabbedPage = (TabbedPropertySheetPage)sheet.getCurrentPage();
+            if (tabbedPage.getControl() instanceof Composite)
+            {
+              Composite c = (Composite)tabbedPage.getControl();
+              Point p = c.getSize();
+              // c.layout(true, true) doesn't appear to work.
+              // But this forces a relayout:
+              c.setSize(p.x, p.y + 1);
+              // Change the size back to the original
+              c.setSize(p.x, p.y);
+            }
+          }
+        }
       }
       removeButton.setEnabled(isDeleteEnabled);
     }
