@@ -10,9 +10,6 @@
  *******************************************************************************/
 package org.eclipse.wst.xsd.ui.internal.common.properties.sections;
 
-import java.util.ArrayList;
-import java.util.List;
-
 import org.apache.xerces.util.XMLChar;
 import org.eclipse.gef.commands.Command;
 import org.eclipse.jface.viewers.ISelection;
@@ -29,6 +26,7 @@ import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetWidgetFactory;
 import org.eclipse.wst.common.ui.internal.search.dialogs.ComponentSpecification;
 import org.eclipse.wst.xsd.ui.internal.adt.edit.ComponentReferenceEditManager;
@@ -36,9 +34,10 @@ import org.eclipse.wst.xsd.ui.internal.adt.edit.IComponentDialog;
 import org.eclipse.wst.xsd.ui.internal.common.commands.UpdateNameCommand;
 import org.eclipse.wst.xsd.ui.internal.dialogs.NewTypeDialog;
 import org.eclipse.wst.xsd.ui.internal.editor.Messages;
+import org.eclipse.wst.xsd.ui.internal.editor.XSDEditorCSHelpIds;
+import org.eclipse.wst.xsd.ui.internal.editor.XSDElementReferenceEditManager;
 import org.eclipse.wst.xsd.ui.internal.editor.XSDTypeReferenceEditManager;
 import org.eclipse.wst.xsd.ui.internal.editor.search.XSDSearchListDialogDelegate;
-import org.eclipse.wst.xsd.ui.internal.util.TypesHelper;
 import org.eclipse.xsd.XSDElementDeclaration;
 import org.eclipse.xsd.XSDTypeDefinition;
 import org.eclipse.xsd.util.XSDConstants;
@@ -50,6 +49,7 @@ public class XSDElementDeclarationSection extends MultiplicitySection
   protected CCombo typeCombo;
   protected CCombo componentNameCombo;
   boolean isElementReference;
+  protected String typeName = ""; //$NON-NLS-1$
 
   private XSDTypeDefinition typeDefinition;
 
@@ -94,6 +94,8 @@ public class XSDElementDeclarationSection extends MultiplicitySection
       nameText = getWidgetFactory().createText(composite, ""); //$NON-NLS-1$
       nameText.setLayoutData(data);
       applyAllListeners(nameText);   
+      PlatformUI.getWorkbench().getHelpSystem().setHelp(nameText,
+        		XSDEditorCSHelpIds.GENERAL_TAB__ELEMENT__NAME);
      
       // ------------------------------------------------------------------
       // Refactor/rename hyperlink 
@@ -122,10 +124,9 @@ public class XSDElementDeclarationSection extends MultiplicitySection
       componentNameCombo = getWidgetFactory().createCCombo(composite, SWT.FLAT);
       componentNameCombo.addSelectionListener(this);
       componentNameCombo.setLayoutData(data);
-
-      data = new GridData();
-      data.horizontalAlignment = GridData.HORIZONTAL_ALIGN_BEGINNING;
-      data.grabExcessHorizontalSpace = false;
+      
+      PlatformUI.getWorkbench().getHelpSystem().setHelp(componentNameCombo,
+      		XSDEditorCSHelpIds.GENERAL_TAB__ELEMENT__REFERENCE);
 
       getWidgetFactory().createCLabel(composite, ""); //$NON-NLS-1$
     }
@@ -146,6 +147,8 @@ public class XSDElementDeclarationSection extends MultiplicitySection
     typeCombo.setEditable(false);
     typeCombo.setLayoutData(data);
     typeCombo.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(typeCombo,
+    		XSDEditorCSHelpIds.GENERAL_TAB__ELEMENT__TYPE);
     
     // ------------------------------------------------------------------
     // DummyLabel
@@ -171,6 +174,8 @@ public class XSDElementDeclarationSection extends MultiplicitySection
     minCombo.add("1"); //$NON-NLS-1$
     applyAllListeners(minCombo);
     minCombo.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(minCombo,
+    		XSDEditorCSHelpIds.GENERAL_TAB__ELEMENT__MIN_OCCURENCE);    
 
     // ------------------------------------------------------------------
     // DummyLabel
@@ -196,6 +201,8 @@ public class XSDElementDeclarationSection extends MultiplicitySection
     maxCombo.add("unbounded"); //$NON-NLS-1$
     applyAllListeners(maxCombo);
     maxCombo.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(maxCombo,
+    		XSDEditorCSHelpIds.GENERAL_TAB__ELEMENT__MAX_OCCURENCE);    
   }
 
   public void setInput(IWorkbenchPart part, ISelection selection)
@@ -205,15 +212,6 @@ public class XSDElementDeclarationSection extends MultiplicitySection
     init();
     relayout();
     
-    if (isElementReference)
-    {
-      TypesHelper helper = new TypesHelper(xsdSchema);
-      List items = new ArrayList();
-      items = helper.getGlobalElements();
-      items.add(0, ""); //$NON-NLS-1$
-      componentNameCombo.setItems((String [])items.toArray(new String[0]));
-    }
-//    fillTypesCombo();
     setListenerEnabled(true);
   }
   
@@ -241,12 +239,14 @@ public class XSDElementDeclarationSection extends MultiplicitySection
     {
       typeCombo.add(items[i].getName());
     }
-    // Add the current Type of this attribute if needed
+    // Add the current Type of this element if needed
     XSDElementDeclaration namedComponent = ((XSDElementDeclaration) input).getResolvedElementDeclaration();
     XSDTypeDefinition td = namedComponent.getType();
     if (td != null)
     {  
-      String currentTypeName = td.getQName(xsdSchema); //no prefix
+      String currentTypeName = td.getQName(xsdSchema);
+      if (currentTypeName == null) // anonymous type
+    	currentTypeName = "**Anonymous**";
       ComponentSpecification ret = getComponentSpecFromQuickPickForValue(currentTypeName,manager);
       if (ret == null && currentTypeName != null) //not in quickPick
       {
@@ -308,8 +308,7 @@ public class XSDElementDeclarationSection extends MultiplicitySection
         boolean isAnonymous = xsdElementDeclaration.getAnonymousTypeDefinition() != null;
         //XSDTypeDefinition typeDef = XSDUtils.getResolvedType(xsdElementDeclaration);
         XSDTypeDefinition typeDef = xsdElementDeclaration.getResolvedElementDeclaration().getTypeDefinition();
-        
-        String typeName = ""; //$NON-NLS-1$
+         
         if (typeDef != null)
           typeName = typeDef.getQName(xsdSchema);
 
@@ -318,13 +317,14 @@ public class XSDElementDeclarationSection extends MultiplicitySection
           typeName = ""; //$NON-NLS-1$
         }
 
+        fillTypesCombo();
         if (isAnonymous)
         {
-          typeCombo.setText("**anonymous**"); //$NON-NLS-1$
+        	typeCombo.setText("**Anonymous**");
+          typeName = "**Anonymous**";
         }
         else
         {
-          fillTypesCombo();
           if (typeDefinition != null)
           {
             typeCombo.setText(typeName);
@@ -334,6 +334,9 @@ public class XSDElementDeclarationSection extends MultiplicitySection
             typeCombo.setText(Messages.UI_NO_TYPE); //$NON-NLS-1$
           }
         }
+
+        maxCombo.setEnabled(!xsdElementDeclaration.isGlobal() || isElementReference);
+        minCombo.setEnabled(!xsdElementDeclaration.isGlobal() || isElementReference);
       }
     }
 
@@ -378,6 +381,10 @@ public class XSDElementDeclarationSection extends MultiplicitySection
           newValue = dialog.getSelectedComponent();
           manager.modifyComponentReference(input, newValue);
         }
+        else
+        {
+          typeCombo.setText(typeName );
+        }
       }
       else //use the value from selected quickPick item
       {
@@ -385,18 +392,42 @@ public class XSDElementDeclarationSection extends MultiplicitySection
         if (newValue != null)
           manager.modifyComponentReference(input, newValue);
       }
-//      refresh();
     }
     else if (e.widget == componentNameCombo)
     {
-      String newValue = componentNameCombo.getText();
-      String newName = newValue.substring(newValue.indexOf(":") + 1); //$NON-NLS-1$
-      if (isElementReference)
+      IEditorPart editor = getActiveEditor();
+      if (editor == null) return;
+      ComponentReferenceEditManager manager = (ComponentReferenceEditManager)editor.getAdapter(XSDElementReferenceEditManager.class);    
+
+      String selection = componentNameCombo.getText();
+      ComponentSpecification newValue;
+      IComponentDialog dialog= null;
+      if ( selection.equals(Messages._UI_ACTION_BROWSE))
       {
-        XSDElementDeclaration elementRef = (XSDElementDeclaration)input;
-        elementRef.getElement().setAttribute(XSDConstants.REF_ATTRIBUTE, newValue);
-        nameText.setText(newName);
-        //refresh();
+        dialog = manager.getBrowseDialog();
+      }
+      else if ( selection.equals(Messages._UI_ACTION_NEW))
+      {
+        dialog = manager.getNewDialog();
+      }
+
+      if (dialog != null)
+      {
+        if (dialog.createAndOpen() == Window.OK)
+        {
+          newValue = dialog.getSelectedComponent();
+          manager.modifyComponentReference(input, newValue);
+        }
+        else
+        {
+          componentNameCombo.setText("");
+        }
+      }
+      else //use the value from selected quickPick item
+      {
+        newValue = getComponentSpecFromQuickPickForValue(selection, manager);
+        if (newValue != null)
+          manager.modifyComponentReference(input, newValue);
       }
 
     }
@@ -501,7 +532,36 @@ public class XSDElementDeclarationSection extends MultiplicitySection
   protected void refreshRefCombo()
   {
     componentNameCombo.setText(""); //$NON-NLS-1$
-
+    fillElementsCombo();
+  }
+  
+  private void fillElementsCombo()
+  {
+    IEditorPart editor = getActiveEditor();
+    ComponentReferenceEditManager manager = (ComponentReferenceEditManager)editor.getAdapter(XSDElementReferenceEditManager.class);    
+    
+    componentNameCombo.removeAll();
+    componentNameCombo.add(Messages._UI_ACTION_BROWSE);
+    componentNameCombo.add(Messages._UI_ACTION_NEW);
+    ComponentSpecification[] quickPicks = manager.getQuickPicks();
+    if (quickPicks != null)
+    {
+      for (int i=0; i < quickPicks.length; i++)
+      {
+        ComponentSpecification componentSpecification = quickPicks[i];
+        componentNameCombo.add(componentSpecification.getName());
+      }  
+    }
+    ComponentSpecification[] history = manager.getHistory();
+    if (history != null)
+    {
+      for (int i=0; i < history.length; i++)
+      {
+        ComponentSpecification componentSpecification = history[i];
+        componentNameCombo.add(componentSpecification.getName());
+      }  
+    }
+    
     XSDElementDeclaration namedComponent = (XSDElementDeclaration) input;
     Element element = namedComponent.getElement();
     if (element != null)
@@ -511,7 +571,13 @@ public class XSDElementDeclarationSection extends MultiplicitySection
       {
         attrValue = ""; //$NON-NLS-1$
       }
+      ComponentSpecification ret = getComponentSpecFromQuickPickForValue(attrValue, manager);
+      if (ret == null)
+      {
+        componentNameCombo.add(attrValue);
+      }
       componentNameCombo.setText(attrValue);
-    }
+    } 
   }
+
 }
