@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006 IBM Corporation and others.
+ * Copyright (c) 2006, 2007 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,9 +11,12 @@
 package org.eclipse.wst.xsd.ui.internal.common.properties.sections.appinfo;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.StringTokenizer;
 import org.apache.xerces.dom.DocumentImpl;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
@@ -44,9 +47,11 @@ import org.eclipse.swt.widgets.MessageBox;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.SelectionDialog;
 import org.eclipse.wst.xsd.contentmodel.internal.XSDImpl;
 import org.eclipse.wst.xsd.ui.internal.common.util.Messages;
+import org.eclipse.wst.xsd.ui.internal.editor.XSDEditorCSHelpIds;
 import org.eclipse.wst.xsd.ui.internal.editor.XSDEditorPlugin;
 import org.eclipse.xsd.XSDAttributeDeclaration;
 import org.eclipse.xsd.XSDElementDeclaration;
@@ -78,11 +83,27 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
   private ArrayList existingNames;
 
   private ViewerFilter elementTableViewerFilter;
-
+  private SpecificationForExtensionsSchema currentExtCategory;
+  private HashMap specToComponentsList = new HashMap();
+  private IPreferenceStore prefStore;
+  
   public void setInput(List input)
   {
     this.fInput = input;
   }
+  
+  public SpecificationForExtensionsSchema getSelectedCategory(){
+	return currentExtCategory;
+  }
+  
+  public void setInitialCategorySelection(SpecificationForExtensionsSchema spec){
+	  currentExtCategory = spec;
+  }
+  
+  protected IStructuredContentProvider getCategoryContentProvider()
+  {
+    return new CategoryContentProvider();
+  }
 
   protected Control createDialogArea(Composite container)
   {
@@ -103,10 +124,11 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     new Label(categoryComposite, SWT.NONE);
 
     categoryTableViewer = new TableViewer(categoryComposite, getTableStyle());
-    categoryTableViewer.setContentProvider(new CategoryContentProvider());
+    categoryTableViewer.setContentProvider(getCategoryContentProvider());
     categoryTableViewer.setLabelProvider(new CategoryLabelProvider());
     categoryTableViewer.setInput(fInput);
     categoryTableViewer.addSelectionChangedListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(categoryTableViewer.getControl(), XSDEditorCSHelpIds.ADD_EXTENSIONS_COMPONENTS__EXTENSION_CATEGORIES);
 
     GridData gd = new GridData(GridData.FILL_BOTH);
     Table table = categoryTableViewer.getTable();
@@ -126,16 +148,24 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     addButton.setText(Messages._UI_LABEL_ADD_WITH_DOTS);
     addButton.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
     addButton.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(addButton,
+    		XSDEditorCSHelpIds.ADD_EXTENSIONS_COMPONENTS__ADD);    
 
     removeButton = new Button(buttonComposite, SWT.PUSH);
     removeButton.setText(Messages._UI_LABEL_DELETE);
     removeButton.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
     removeButton.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(removeButton,
+    		XSDEditorCSHelpIds.ADD_EXTENSIONS_COMPONENTS__DELETE);    
+
     
     editButton = new Button(buttonComposite, SWT.PUSH);
     editButton.setText(Messages._UI_LABEL_EDIT);
     editButton.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
     editButton.addSelectionListener(this);
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(editButton,
+    		XSDEditorCSHelpIds.ADD_EXTENSIONS_COMPONENTS__EDIT);    
+    
     
     List initialSelection = getInitialElementSelections();
     if (initialSelection != null)
@@ -171,6 +201,7 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
 	          getButton(IDialogConstants.OK_ID).setEnabled(true);			
 	    }        	  
       });
+    PlatformUI.getWorkbench().getHelpSystem().setHelp(elementTableViewer.getControl(), XSDEditorCSHelpIds.ADD_EXTENSIONS_COMPONENTS__AVAILABLE_COMPONENTS_TO_ADD);
     
     return parent;
   }
@@ -181,14 +212,48 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     if (categoryTableViewer.getTable().getItemCount() > 0)
     {
       categoryTableViewer.getTable().select(0);
-      categoryTableViewer.setSelection(new StructuredSelection(categoryTableViewer.getElementAt(0)));
+      
+      StructuredSelection structuredSelection;
+      if (currentExtCategory != null){
+    	  structuredSelection = new StructuredSelection(currentExtCategory);
+      }
+      else{
+    	  structuredSelection = 
+    		  new StructuredSelection(categoryTableViewer.getElementAt(0));
+      }
+      
+	  categoryTableViewer.setSelection(structuredSelection);
     }
     
     // Setup the list of category names that already exist
+    // and contructs the XSDSchema for each category
 	existingNames = new ArrayList();
-	TableItem[] categoryNames = categoryTableViewer.getTable().getItems();
-	for (int i = 0; i < categoryNames.length; i++ ){
-		existingNames.add(categoryNames[i].getText());
+	TableItem[] categories = categoryTableViewer.getTable().getItems();
+	for (int i = 0; i < categories.length; i++ ){
+		existingNames.add(categories[i].getText());
+
+		SpecificationForExtensionsSchema spec = 
+			(SpecificationForExtensionsSchema) categories[i].getData();
+		XSDSchema schema = getASISchemaModel(spec);
+		
+		if (schema == null)
+		{
+			continue;
+		}
+
+		List components = buildInput(schema);
+		specToComponentsList.put(spec, components);
+
+		// mark category as gray/empty if applicable
+		Object[] remains = components.toArray();
+		if ( elementTableViewerFilter != null)
+			remains = elementTableViewerFilter.filter(elementTableViewer, 
+					elementTableViewer.getTable(), remains);
+		if ( remains.length == 0)
+		{
+		  categories[i].setForeground(
+			getShell().getDisplay().getSystemColor(SWT.COLOR_GRAY));
+		}
 	}
 	
 	getButton(IDialogConstants.OK_ID).setEnabled(false);
@@ -197,6 +262,11 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
   public void addElementsTableFilter(ViewerFilter filter){
 	elementTableViewerFilter = filter;
   }
+  
+  public void setPrefStore(IPreferenceStore prefStore)
+  {
+    this.prefStore = prefStore;
+  }
 
   protected Point getInitialSize()
   {
@@ -251,29 +321,43 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     	addNewCategoryDialog.setUnavailableCategoryNames(existingNames);
     	
     	if ( addNewCategoryDialog.open() == Window.OK ){    		
-    		SpecificationForExtensionsSchema schemaSpec = addNewCategoryDialog.getExtensionsSchemaSpec();
-    		
+    		SpecificationForExtensionsSchema schemaSpec = 
+    			new SpecificationForExtensionsSchema();
+    		schemaSpec.setDisplayName(addNewCategoryDialog.getNewCategoryName() );
+    		schemaSpec.setLocation(addNewCategoryDialog.getCategoryLocation() );
+    		schemaSpec.setSourceHint(addNewCategoryDialog.getSource());
+    		schemaSpec.setFromCatalog(addNewCategoryDialog.getFromCatalog() );
+
     		fInput.add(schemaSpec);
     		existingNames.add(schemaSpec.getDisplayName());
-    		
+
     		// refresh without updating labels of existing TableItems    		
     		categoryTableViewer.refresh(false);
-    		
+
     		categoryTableViewer.setSelection(new StructuredSelection(schemaSpec));
     		getButton(IDialogConstants.OK_ID).setEnabled(false);
+    		
+    		storeSpecInPref(schemaSpec);  // must store after selection changed is called ie. 2 lines above (trung)
     	}
     }
     else if (e.widget == removeButton)
     {
     	TableItem[] selections = categoryTableViewer.getTable().getSelection();
     	for (int i =0; i < selections.length; i++){
-    		fInput.remove(selections[i].getData() );
+    		SpecificationForExtensionsSchema spec = 
+    			(SpecificationForExtensionsSchema) selections[i].getData();
+
+			fInput.remove(spec );
+    		existingNames.remove(spec.getDisplayName());
+    		specToComponentsList.remove(spec);
+    		
+    		removeFromPref(spec);
     	}
     	categoryTableViewer.refresh(false);
 
     	elementTableViewer.setInput(null);
     	elementTableViewer.refresh();
-    	
+
         // TODO auto select either the prev category, the next category or the first category in the Table
     	getButton(IDialogConstants.OK_ID).setEnabled(false);
     }
@@ -281,19 +365,44 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     {
         // use this dialog not for adding but for editing purpose.
         AddNewCategoryDialog dialog = new AddNewCategoryDialog(getShell(), Messages._UI_LABEL_EDIT_CATEGORY);
+        
+    	TableItem[] selections = categoryTableViewer.getTable().getSelection();
+    	if (selections.length == 0)
+    		return;
+
+    	SpecificationForExtensionsSchema spec = (SpecificationForExtensionsSchema) selections[0].getData();
+        
+    	String displayName = spec.getDisplayName();
+
+		dialog.setCategoryName(displayName );
+    	dialog.setFromCatalog(spec.isFromCatalog() );
+    	dialog.setSource(spec.getSourceHint() );
+    	dialog.setCategoryLocation(spec.getLocation() );
+
+    	specToComponentsList.remove(spec);
+    	dialog.setUnavailableCategoryNames(existingNames);
+        
         if ( dialog.open() == Window.OK){
-        	TableItem[] selections = categoryTableViewer.getTable().getSelection();        	
-        	SpecificationForExtensionsSchema spec = (SpecificationForExtensionsSchema) selections[0].getData();
-        	
-			spec.setDisplayName(dialog.getNewCategoryName());
+        	existingNames.remove(displayName);
+			String newDisplayName = dialog.getNewCategoryName();
+
+			spec.setDisplayName(newDisplayName);
         	spec.setLocation(dialog.getCategoryLocation());
+        	spec.setSourceHint(dialog.getSource());
+        	spec.setFromCatalog(dialog.getFromCatalog());
+        	spec.setNamespaceURI(null);
+        	
+        	existingNames.add(newDisplayName);
+
         	categoryTableViewer.update(spec, null);
         	refreshElementsViewer(spec);
+        	
+        	editSpecInPref(displayName, spec);
         }
     }
   }
 
-  /*
+/*
    * (non-Javadoc)
    * 
    * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
@@ -314,7 +423,7 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
         if (obj instanceof SpecificationForExtensionsSchema)
         {
           SpecificationForExtensionsSchema spec = (SpecificationForExtensionsSchema) obj;
-
+          currentExtCategory = spec;
           refreshElementsViewer(spec);
 
           if ( spec.isDefautSchema() ){
@@ -333,23 +442,44 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
   }
   
   private void refreshElementsViewer(SpecificationForExtensionsSchema spec) {
-	  XSDSchema xsdSchema = getASISchemaModel(spec);
+	  List components = (List) specToComponentsList.get(spec);
+	  if ( components != null){
+		elementTableViewer.setInput(components);
+		return;
+	  }
 	  
+	  XSDSchema xsdSchema = getASISchemaModel(spec);
+
 	  if (xsdSchema == null){
 		  MessageBox errDialog = new MessageBox(getShell(), SWT.ICON_ERROR);
 		  errDialog.setText(Messages._UI_ERROR_INVALID_CATEGORY);
-		  errDialog.setMessage(Messages._UI_ERROR_FILE_CANNOT_BE_PARSED
-				  + "\n" + Messages._UI_ERROR_VALIDATE_THE_FILE);  //$NON-NLS-1$
+		  // TODO (trung) I was forced to use a String in Messages to make the error clearer
+		  // When we are back to development phase, use another string: "Extension Category: "
+		  // not "Extension Categories:" + " " like we are using here
+		  errDialog.setMessage(Messages._UI_LABEL_EXTENSION_CATEGORIES + " " + spec.getDisplayName() //$NON-NLS-1$
+				  + "\n"   //$NON-NLS-1$
+				  + Messages._UI_ERROR_FILE_CANNOT_BE_PARSED
+				  + "\n" + Messages._UI_ERROR_VALIDATE_THE_FILE);   //$NON-NLS-1$
 		  errDialog.open();
+		  
+		  elementTableViewer.setInput(new ArrayList(0));
 		  return;
 	  }
 	  
+	  components = buildInput(xsdSchema);
+      specToComponentsList.put(spec, components);	  
+	  
 	  List allItems = buildInput(xsdSchema);
+	  if ( allItems == null )
+		  return;
 	  elementTableViewer.setInput(allItems);
   }
   
   private static List buildInput(XSDSchema xsdSchema)
   {
+	if ( xsdSchema ==null )
+		return null;
+
     List elements = xsdSchema.getElementDeclarations();
     List attributes = xsdSchema.getAttributeDeclarations();
     String targetNamespace = xsdSchema.getTargetNamespace();
@@ -357,6 +487,7 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     // For safety purpose: We don't append 'attributes' to 'elements'
     // ArrayStoreException(or similar one) may occur
     List allItems = new ArrayList(attributes.size() + elements.size());
+    
     {
       // getElementDeclarations returns a lot of elements from import
       // statement, we
@@ -399,7 +530,10 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
   
   private static XSDSchema getASISchemaModel(SpecificationForExtensionsSchema extensionsSchemaSpec)
   {
-    XSDSchema xsdSchema = XSDImpl.buildXSDModel(extensionsSchemaSpec.getLocation());
+    String location = extensionsSchemaSpec.getLocation();
+    if ( location == null)
+    	return null;
+	XSDSchema xsdSchema = XSDImpl.buildXSDModel(location);
     
     // now that the .xsd file is read, we can retrieve the namespace of this xsd file
     // and set the namespace for 'properties'
@@ -410,7 +544,75 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
     return xsdSchema;
   }
 
-  static class CategoryContentProvider implements IStructuredContentProvider
+  private void storeSpecInPref(SpecificationForExtensionsSchema schemaSpec) {
+	if (prefStore == null)
+		return;
+	
+	String currentValue = prefStore.getString(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS);
+	String specDesc = "  " + "\t" + schemaSpec.getDisplayName() + "\t"+
+		schemaSpec.getNamespaceURI() + "\t" + schemaSpec.getLocation() + "\t" +
+		schemaSpec.isDefautSchema() + "\t" + schemaSpec.getSourceHint() + "\t" +
+		schemaSpec.isFromCatalog();
+	currentValue += specDesc + "\n";
+
+	prefStore.setValue(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS,
+			currentValue);
+  }
+
+  private void editSpecInPref(String displayName, SpecificationForExtensionsSchema newSpec) {
+	if (prefStore == null)
+	  return;
+	
+	String newValue = "";
+	String currentValue = prefStore.getString(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS);
+	StringTokenizer tokenizer = new StringTokenizer(currentValue, "\n");
+
+	while (tokenizer.hasMoreTokens())
+	{
+	  String oneSpecDesc = tokenizer.nextToken();
+	  // get the Display name
+	  StringTokenizer _tokenizer_2 = new StringTokenizer(oneSpecDesc, "\t");
+	  _tokenizer_2.nextToken();
+	  String dName = _tokenizer_2.nextToken();
+
+	  if ( dName.equals(displayName ) )
+	  {
+		oneSpecDesc = "  " + "\t" + newSpec.getDisplayName() + "\t"+
+			newSpec.getNamespaceURI() + "\t" + newSpec.getLocation() + "\t" +
+			newSpec.isDefautSchema() + "\t" + newSpec.getSourceHint() + "\t" +
+			newSpec.isFromCatalog();		  
+	  }
+
+	  newValue += oneSpecDesc + "\n";
+	}
+	prefStore.setValue(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS, newValue);
+	
+  }
+
+  private void removeFromPref(SpecificationForExtensionsSchema spec) {
+	if (prefStore == null)
+	  return;	  
+	  
+	String newValue = "";
+	String currentValue = prefStore.getString(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS);
+	StringTokenizer tokenizer = new StringTokenizer(currentValue, "\n");
+
+	while (tokenizer.hasMoreTokens())
+	{
+	  String oneSpecDesc = tokenizer.nextToken();
+	  // get the Display name
+	  StringTokenizer _tokenizer_2 = new StringTokenizer(oneSpecDesc, "\t");
+	  _tokenizer_2.nextToken();
+	  String dName = _tokenizer_2.nextToken();
+
+	  if ( dName.equals(spec.getDisplayName() ) )
+		continue;
+	  newValue += oneSpecDesc + "\n";
+	}
+	prefStore.setValue(ExtensionsSchemasRegistry.USER_ADDED_EXT_SCHEMAS, newValue);
+  }
+
+static class CategoryContentProvider implements IStructuredContentProvider
   {
     /*
      * (non-Javadoc)
@@ -427,7 +629,6 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
       }
       catch (Exception e)
       {
-        e.printStackTrace();
       }
       return extensionsSchemaSpecs;
     }
@@ -573,4 +774,11 @@ public class AddExtensionsComponentDialog extends SelectionDialog implements ISe
   {
     return super.close();
   }
+  
+  protected void enableButtons(boolean value)
+  {
+    editButton.setEnabled(value);
+    addButton.setEnabled(value);
+    removeButton.setEnabled(value);
+  }
 }
